/* Driver template for the LEMON parser generator.
** The author disclaims copyright to this source code.
**
** This version of "lempar.c" is modified, slightly, for use by SQLite.
** The only modifications are the addition of a couple of NEVER()
** macros to disable tests that are needed in the case of a general
** LALR(1) grammar but which are always false in the
** specific grammar used by SQLite.
*/
/* First off, code is included that follows the "include" declaration
** in the input grammar file. */
#include <stdio.h>

#include "token.h"
#include "parsercontext.h"
#include "parser_helper_stubs.h"
#include "common/utils_sql.h"
#include "common/global.h"
#include "common/unused.h"
#include "parser/ast/sqlitealtertable.h"
#include "parser/ast/sqliteanalyze.h"
#include "parser/ast/sqliteattach.h"
#include "parser/ast/sqlitebegintrans.h"
#include "parser/ast/sqlitecommittrans.h"
#include "parser/ast/sqlitecreateindex.h"
#include "parser/ast/sqlitecreatetable.h"
#include "parser/ast/sqlitecreatetrigger.h"
#include "parser/ast/sqlitecreateview.h"
#include "parser/ast/sqlitecreatevirtualtable.h"
#include "parser/ast/sqlitedelete.h"
#include "parser/ast/sqlitedetach.h"
#include "parser/ast/sqlitedropindex.h"
#include "parser/ast/sqlitedroptable.h"
#include "parser/ast/sqlitedroptrigger.h"
#include "parser/ast/sqlitedropview.h"
#include "parser/ast/sqliteemptyquery.h"
#include "parser/ast/sqliteinsert.h"
#include "parser/ast/sqlitepragma.h"
#include "parser/ast/sqlitereindex.h"
#include "parser/ast/sqliterelease.h"
#include "parser/ast/sqliterollback.h"
#include "parser/ast/sqlitesavepoint.h"
#include "parser/ast/sqliteselect.h"
#include "parser/ast/sqliteupdate.h"
#include "parser/ast/sqlitevacuum.h"
#include "parser/ast/sqliteexpr.h"
#include "parser/ast/sqlitecolumntype.h"
#include "parser/ast/sqliteconflictalgo.h"
#include "parser/ast/sqlitesortorder.h"
#include "parser/ast/sqliteindexedcolumn.h"
#include "parser/ast/sqliteforeignkey.h"
#include "parser/ast/sqlitewith.h"
#include "parser/ast/sqliteupsert.h"
#include "parser/ast/sqlitewindowdefinition.h"
#include "parser/ast/sqlitefilterover.h"
#include "parser/ast/sqlitenulls.h"
#include <QObject>
#include <QDebug>
#include <limits.h>

#define assert(X) Q_ASSERT(X)
#define UNUSED_PARAMETER(X) (void)(X)
#define DONT_INHERIT_TOKENS(X) noTokenInheritanceFields << X

/* Next is all token values, in a form suitable for use by makeheaders.
** This section will be null unless lemon is run with the -m switch.
*/
/*
** These constants (all generated automatically by the parser generator)
** specify the various kinds of tokens (terminals) that the parser
** understands.
**
** Each symbol here is a terminal symbol in the grammar.
*/
/* Make sure the INTERFACE macro is defined.
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/* The next thing included is series of defines which control
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 terminals
**                       and nonterminals.  "int" is used otherwise.
**    YYNOCODE           is a number of type YYCODETYPE which corresponds
**                       to no legal terminal or nonterminal number.  This
**                       number is used to fill in empty slots of the hash
**                       table.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       have fall-back values which should be used if the
**                       original value of the token will not parse.
**    YYACTIONTYPE       is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 rules and
**                       states combined.  "int" is used otherwise.
**    sqlite3_parseTOKENTYPE     is the data type used for minor tokens given
**                       directly to the parser from the tokenizer.
**    YYMINORTYPE        is the data type used for all minor tokens.
**                       This is typically a union of many types, one of
**                       which is sqlite3_parseTOKENTYPE.  The entry in the union
**                       for base tokens is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    sqlite3_parseARG_SDECL     A static variable declaration for the %extra_argument
**    sqlite3_parseARG_PDECL     A parameter declaration for the %extra_argument
**    sqlite3_parseARG_STORE     Code to store %extra_argument into yypParser
**    sqlite3_parseARG_FETCH     Code to extract %extra_argument from yypParser
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
*/
#define YYCODETYPE unsigned short int
#define YYNOCODE 331
#define YYACTIONTYPE unsigned short int
#define YYWILDCARD 79
#define sqlite3_parseTOKENTYPE Token*
typedef union {
  int yyinit;
  sqlite3_parseTOKENTYPE yy0;
  ParserOtherSourceList* yy11;
  SqliteWindowDefinition::Window::Frame* yy41;
  ParserCreateTableColumnList* yy42;
  ParserFullName* yy60;
  SqliteWindowDefinition::Window::Frame::Bound* yy81;
  SqliteSelect::Core::JoinSource* yy91;
  SqliteNulls* yy99;
  SqliteExpr::LikeOp* yy100;
  SqliteCreateTable::Constraint* yy106;
  ParserXFullName* yy116;
  ParserIndexedColumnList* yy123;
  SqliteForeignKey::Condition::Reaction* yy124;
  ParserCreateTableColumnConstraintList* yy131;
  SqliteInitially* yy192;
  QStringList* yy215;
  SqliteWindowDefinition::Window* yy234;
  SqliteFilterOver* yy247;
  QVariant* yy249;
  SqliteExpr* yy252;
  QString* yy259;
  ParserStubCreateTableOption* yy287;
  SqliteFilterOver::Over* yy288;
  bool* yy291;
  ParserIndexedBy* yy312;
  ParserSetValueList* yy321;
  SqliteCreateTrigger::Scope* yy323;
  ParserFkConditionList* yy324;
  ParserQueryList* yy330;
  SqliteCreateTrigger::Event* yy331;
  ParserCteList* yy332;
  SqliteSelect::Core::JoinConstraint* yy335;
  int* yy346;
  ParserTermOrLiteral* yy350;
  ParserExprList* yy351;
  SqliteWindowDefinition::Window::Frame::RangeOrRows* yy358;
  SqliteSelect::Core::SingleSource* yy361;
  SqliteCreateTrigger::Time* yy372;
  ParserCreateTableConstraintList* yy373;
  SqliteSelect::CompoundOperator* yy382;
  SqliteSortOrder* yy389;
  SqliteQuery* yy443;
  SqliteLimit* yy444;
  SqliteWith::CommonTableExpression* yy446;
  ParserDeferSubClause* yy449;
  SqliteSelect::Core* yy450;
  SqliteSelect* yy453;
  ParserStubAlias* yy460;
  ParserStubTransDetails* yy464;
  SqliteColumnType* yy477;
  SqliteConflictAlgo* yy478;
  SqliteUpsert* yy500;
  ParserStubExplain* yy511;
  SqliteSelect::Core::JoinOp* yy521;
  ParserCreateTableOptionList* yy533;
  ParserOrderByList* yy543;
  ParserExprNestedList* yy546;
  SqliteCreateTable::Column* yy567;
  ParserStubInsertOrReplace* yy584;
  SqliteWindowDefinition::Window::Frame::Exclude* yy603;
  SqliteCreateTable::Column::Constraint* yy604;
  SqliteForeignKey::Condition* yy607;
  SqliteIndexedColumn* yy608;
  ParserResultColumnList* yy633;
  ParserWindowDefList* yy639;
  SqliteWith::CommonTableExpression::AsMode* yy640;
  SqliteWith* yy641;
  SqliteWindowDefinition* yy646;
  SqliteFilterOver::Filter* yy657;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define sqlite3_parseARG_SDECL ParserContext* parserContext;
#define sqlite3_parseARG_PDECL ,ParserContext* parserContext
#define sqlite3_parseARG_FETCH ParserContext* parserContext = yypParser->parserContext
#define sqlite3_parseARG_STORE yypParser->parserContext = parserContext
#define YYNSTATE 883
#define YYNRULE 498
#define YYFALLBACK 1
#define YY_NO_ACTION      (YYNSTATE+YYNRULE+2)
#define YY_ACCEPT_ACTION  (YYNSTATE+YYNRULE+1)
#define YY_ERROR_ACTION   (YYNSTATE+YYNRULE)

#define GET_CONTEXT yyParser* yypParser = pParser; sqlite3_parseARG_FETCH

/* The yyzerominor constant is used to initialize instances of
** YYMINORTYPE objects to zero. */
static const YYMINORTYPE yyzerominor = { 0 };

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N < YYNSTATE                  Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   YYNSTATE <= N < YYNSTATE+YYNRULE   Reduce by rule N-YYNSTATE.
**
**   N == YYNSTATE+YYNRULE              A syntax error has occurred.
**
**   N == YYNSTATE+YYNRULE+1            The parser accepts its input.
**
**   N == YYNSTATE+YYNRULE+2            No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as
**
**      yy_action[ yy_shift_ofst[S] + X ]
**
** If the index value yy_shift_ofst[S]+X is out of range or if the value
** yy_lookahead[yy_shift_ofst[S]+X] is not equal to X or if yy_shift_ofst[S]
** is equal to YY_SHIFT_USE_DFLT, it means that the action is not in the table
** and that yy_default[S] should be used instead.
**
** The formula above is for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
*/
#define YY_ACTTAB_COUNT (2990)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */   875,  260,  719,  875,  479,  593,   27,   67,   68,  537,
 /*    10 */   285,  875,  529,  831,  831,   65,   65,   66,   66,   66,
 /*    20 */    66,  395,   64,   64,   64,   64,   63,   63,   62,   62,
 /*    30 */    62,   61,   59,  268,  363,  874,  440,   67,   68,  537,
 /*    40 */   285,  368,  595,  831,  831,   65,   65,   66,   66,   66,
 /*    50 */    66,  534,   64,   64,   64,   64,   63,   63,   62,   62,
 /*    60 */    62,   61,   59,  268,  411, 1304,   62,   62,   62,   61,
 /*    70 */    59,  268,  821,  764,   66,   66,   66,   66,   56,   64,
 /*    80 */    64,   64,   64,   63,   63,   62,   62,   62,   61,   59,
 /*    90 */   268,  340,  465,  195,  764,   53,   54,  727,   42,  696,
 /*   100 */   764,  875,  377,   55, 1055,  621,  808,  670,  266,  875,
 /*   110 */    51,    2, 1055,  529,    1,  695,  829, 1055,  495,  840,
 /*   120 */   526, 1129,  875,  843,  872,  875,  873,  872,  480,  846,
 /*   130 */   721,  720,  880,  875,  873,  872,  829,  845,  844,  843,
 /*   140 */   400, 1055,  288,   63,   63,   62,   62,   62,   61,   59,
 /*   150 */   268,   81,  534,  822, 1055,  734, 1055, 1055,  820,   44,
 /*   160 */  1055,  648,  167,   58,  264, 1055, 1055, 1055, 1055, 1055,
 /*   170 */  1055,  829,  669,  821,  829,  978,  819,   12,  822,   56,
 /*   180 */   289,   82,  853,   92,  700,  351,  874, 1275, 1055,  176,
 /*   190 */   126,  338,  470,  333,  469,  163,   53,   54,  875,  874,
 /*   200 */   733,  729,  875,  505,   55, 1129,  107,  699,  275,  331,
 /*   210 */   656,  822,    2, 1129,  529,  350,  296,  829, 1129,  298,
 /*   220 */   843,  526,  875,  875,  843,  872,  846,  834,  506,  874,
 /*   230 */   846,  875,  873,  872,  845,  844,  843,  829,  845,  844,
 /*   240 */   843,  323, 1129,  784,  325,  740,   78,  128,  200,  293,
 /*   250 */   771,  270,  783,  534,  405, 1129,  269, 1129, 1129,  510,
 /*   260 */   739,  292,  875,  299,  365,  875, 1129, 1129, 1129, 1129,
 /*   270 */   704, 1129,  829,  874,  821,  829,  871,  819,   12,  879,
 /*   280 */    56,  261,  161,  869,  542,  464,  461,  460,  361, 1129,
 /*   290 */   350,  132,  870,  251,  250,  645,  362,   53,   54,  804,
 /*   300 */   561,  364,  179,  459,  874,   55, 1114,  109,  795,   71,
 /*   310 */    81,  596,  127,    2, 1114,  875,  510,  138,  829, 1114,
 /*   320 */   875,  843,  526,  834,  875,  843,  872,  846,  876,  274,
 /*   330 */   874,  846,  578,   80,  297,  845,  844,  843,  829,  845,
 /*   340 */   844,  843,  875, 1114,  875,  873,  872,  369, 1331,  366,
 /*   350 */   834,  189,  847, 1331,  772,  848, 1114,  856, 1114, 1114,
 /*   360 */  1219, 1219,  833,  577,  539,  576,  854, 1114,  575, 1114,
 /*   370 */  1114,  874, 1114,  829,  511,  781,  829,  746,  819,   12,
 /*   380 */   745,  606,  472,  795,  875,  873,  872,  875,  873,  872,
 /*   390 */  1114,  379,  875,  593,  545,  875, 1224,  683,  828,   67,
 /*   400 */    68,  537,  285, 1219, 1219,  831,  831,   65,   65,   66,
 /*   410 */    66,   66,   66,  875,   64,   64,   64,   64,   63,   63,
 /*   420 */    62,   62,   62,   61,   59,  268,  468,  830,  413,  368,
 /*   430 */   594,  601,  780,  828,  716,  716,  169,  875,  873,  872,
 /*   440 */   847,  516,  682,  848, 1219, 1219,  834,  684,  685,  606,
 /*   450 */    67,   68,  537,  285,   69,  174,  831,  831,   65,   65,
 /*   460 */    66,   66,   66,   66,  875,   64,   64,   64,   64,   63,
 /*   470 */    63,   62,   62,   62,   61,   59,  268,   39,  139,  256,
 /*   480 */   255,  254,  747,   67,   68,  537,  285, 1219, 1219,  831,
 /*   490 */   831,   65,   65,   66,   66,   66,   66,  601,   64,   64,
 /*   500 */    64,   64,   63,   63,   62,   62,   62,   61,   59,  268,
 /*   510 */   801,  562,  259,  172,  875,  873,  872,  875,  873,  872,
 /*   520 */   622,  514,  800,  608,   45,  337,  850,  874,  609,  556,
 /*   530 */   568,  173,  398,  284,  283,  875,  873,  872,  406,  816,
 /*   540 */   815, 1219, 1219,  336,  874,   61,   59,  268,  557,  556,
 /*   550 */   569,  570, 1224,  825, 1224,  427,   66,   66,   66,   66,
 /*   560 */    40,   64,   64,   64,   64,   63,   63,   62,   62,   62,
 /*   570 */    61,   59,  268,  135,  875,  813,  812,  556,  562, 1225,
 /*   580 */    67,   68,  537,  285, 1219, 1219,  831,  831,   65,   65,
 /*   590 */    66,   66,   66,   66,  493,   64,   64,   64,   64,   63,
 /*   600 */    63,   62,   62,   62,   61,   59,  268,  305,  448,  315,
 /*   610 */   669, 1382,  192,  543,    3,  360,  811,  287,  481,  824,
 /*   620 */   655,   92, 1219, 1219,  874,   23,  571,  811,  153,  155,
 /*   630 */   508,  759,    4,   67,   68,  537,  285, 1290,  494,  831,
 /*   640 */   831,   65,   65,   66,   66,   66,   66,  875,   64,   64,
 /*   650 */    64,   64,   63,   63,   62,   62,   62,   61,   59,  268,
 /*   660 */   794,   67,   68,  537,  285, 1219, 1219,  831,  831,   65,
 /*   670 */    65,   66,   66,   66,   66,  823,   64,   64,   64,   64,
 /*   680 */    63,   63,   62,   62,   62,   61,   59,  268,  875,  592,
 /*   690 */   592,  748,  875,  610,  611,  429,  875,  873,  872,  523,
 /*   700 */   529,  153,  151,  605,   67,   68,  537,  285,   74,  423,
 /*   710 */   831,  831,   65,   65,   66,   66,   66,   66,   57,   64,
 /*   720 */    64,   64,   64,   63,   63,   62,   62,   62,   61,   59,
 /*   730 */   268,  115, 1290,  875,   73, 1225,  764, 1225,  728,  534,
 /*   740 */    64,   64,   64,   64,   63,   63,   62,   62,   62,   61,
 /*   750 */    59,  268,  875,  500,  693,  875,   81,  764,  841, 1228,
 /*   760 */   821,  261,  834,  764,  883,   52,   56,   50,  668,  875,
 /*   770 */   873,  872,  538,  600,  161,  764,  817,  464,  461,  460,
 /*   780 */   818,  842,  235,   53,   54,   90,  764,  284,  283,  875,
 /*   790 */   536,   55,  875,  410,  474,  459,  764,  852,  319,    2,
 /*   800 */  1231,  745,  764,  507,  829,  677,  467,  764,  526,  596,
 /*   810 */   875,  843,  872,  764,  875,  873,  872,  846,  491,  476,
 /*   820 */   565,  153,  150, 1239,  829,  845,  844,  843,  350,  813,
 /*   830 */   812,  806,  777,  567,  834,  566,  260,  719,  875,  479,
 /*   840 */  1339, 1339,  874,  378,   72,  369, 1330,  172,  439,  735,
 /*   850 */   162, 1330,  834,  171,  777,  875,  873,  872,  177,  829,
 /*   860 */   834,  874,  829,  805,  819,   12,  803,  651,  651,  736,
 /*   870 */   499,  115,  881,   91,  875,  873,  872,  875,  873,  872,
 /*   880 */    67,   68,  537,  285,  735,  834,  831,  831,   65,   65,
 /*   890 */    66,   66,   66,   66,  834,   64,   64,   64,   64,   63,
 /*   900 */    63,   62,   62,   62,   61,   59,  268,  875,  855,  165,
 /*   910 */   857,  875,  873,  872,  875,  873,  872,  875,  645,  529,
 /*   920 */   498,  802,  502,   68,  537,  285,  286,  875,  831,  831,
 /*   930 */    65,   65,   66,   66,   66,   66,   22,   64,   64,   64,
 /*   940 */    64,   63,   63,   62,   62,   62,   61,   59,  268,   72,
 /*   950 */   705,  822,  875,  383,  735,  616,   80,  834,  534,  849,
 /*   960 */   875,  873,  872,  715,  475,  759,    4,  875,  446,  797,
 /*   970 */   875,  501,  202,  169,  736,  834,  822,  807,   22,  821,
 /*   980 */   813,  812,  530,  834,  875,   56,  617,    6,  619,  735,
 /*   990 */   341,  618,  841,  528,  816,  815,  529,  339,  711,  758,
 /*  1000 */  1072, 1072,   53,   54,  874,    8,  538,  169,  875,  822,
 /*  1010 */    55,  875,   21,  432,  351,  842,  220,  834,    2,  747,
 /*  1020 */   808,  527,  266,  829,  536,  709,  435,  526,  874,  875,
 /*  1030 */   873,  872,  755,  647,  841,  534,  846,  171,  113,  875,
 /*  1040 */   873,  872,   79,  829,  845,  844,  843,  752,  538,  875,
 /*  1050 */   873,  872,   81,  747,  757,  373,  821,  842,  220,  339,
 /*  1060 */   711,  874,   56,  410,  726,  723,  536,  647,  553,  875,
 /*  1070 */    58,  811,  295,  801,  875,  873,  872,  788,  829,   53,
 /*  1080 */    54,  829,  752,  819,   12,  800,  874,   55,  553,  875,
 /*  1090 */   873,  872,  875,  873,  872,    2,  874,  455,  634,  659,
 /*  1100 */   829,  408,  689,  828,  526,  329,  875,  843,  872,  660,
 /*  1110 */   115,  874,  504,  846,  118,  766,  553,   14,  402,  788,
 /*  1120 */   829,  845,  844,  843,  638,  341,  520,  632,  791,  568,
 /*  1130 */   875,  873,  872,  875,  873,  872, 1339, 1339,  828,  874,
 /*  1140 */  1226,  457,  881,  874,  638,  445,  115,  632,  745,  569,
 /*  1150 */   414,  386,  252,  393,  875,  829,  342,  769,  829,  793,
 /*  1160 */   819,   12,   67,   68,  537,  285,  201,  574,  831,  831,
 /*  1170 */    65,   65,   66,   66,   66,   66,  792,   64,   64,   64,
 /*  1180 */    64,   63,   63,   62,   62,   62,   61,   59,  268,  875,
 /*  1190 */   278,  875,  873,  872,   67,   68,  537,  285,  789,  119,
 /*  1200 */   831,  831,   65,   65,   66,   66,   66,   66,  787,   64,
 /*  1210 */    64,   64,   64,   63,   63,   62,   62,   62,   61,   59,
 /*  1220 */   268,   67,   68,  537,  285,  415,  811,  831,  831,   65,
 /*  1230 */    65,   66,   66,   66,   66,  515,   64,   64,   64,   64,
 /*  1240 */    63,   63,   62,   62,   62,   61,   59,  268,   47,   67,
 /*  1250 */    68,  537,  285,  646,   46,  831,  831,   65,   65,   66,
 /*  1260 */    66,   66,   66,   81,   64,   64,   64,   64,   63,   63,
 /*  1270 */    62,   62,   62,   61,   59,  268,  875,  873,  872,  443,
 /*  1280 */    67,   68,  537,  285,  171,  710,  831,  831,   65,   65,
 /*  1290 */    66,   66,   66,   66,  513,   64,   64,   64,   64,   63,
 /*  1300 */    63,   62,   62,   62,   61,   59,  268,  748,  525,  441,
 /*  1310 */   307,  875,  873,  872,  171,   44,  708,   89,  743,   67,
 /*  1320 */    68,  537,  285,  434,   48,  831,  831,   65,   65,   66,
 /*  1330 */    66,   66,   66,   20,   64,   64,   64,   64,   63,   63,
 /*  1340 */    62,   62,   62,   61,   59,  268,  122,  875,  748,  436,
 /*  1350 */    67,   68,  537,  285,  741,  691,  831,  831,   65,   65,
 /*  1360 */    66,   66,   66,   66,  532,   64,   64,   64,   64,   63,
 /*  1370 */    63,   62,   62,   62,   61,   59,  268,  354,  627,  347,
 /*  1380 */    81,   67,   68,  537,  285,   44,  196,  831,  831,   65,
 /*  1390 */    65,   66,   66,   66,   66,  738,   64,   64,   64,   64,
 /*  1400 */    63,   63,   62,   62,   62,   61,   59,  268,  834,  702,
 /*  1410 */   875,  701,   67,   68,  537,  285,  614,  328,  831,  831,
 /*  1420 */    65,   65,   66,   66,   66,   66,  117,   64,   64,   64,
 /*  1430 */    64,   63,   63,   62,   62,   62,   61,   59,  268,  521,
 /*  1440 */  1254,   67,   68,  537,  285,  882,    3,  831,  831,   65,
 /*  1450 */    65,   66,   66,   66,   66,  875,   64,   64,   64,   64,
 /*  1460 */    63,   63,   62,   62,   62,   61,   59,  268,  509,  875,
 /*  1470 */   873,  872,   77,   67,   68,  537,  285,  122,   28,  831,
 /*  1480 */   831,   65,   65,   66,   66,   66,   66,   58,   64,   64,
 /*  1490 */    64,   64,   63,   63,   62,   62,   62,   61,   59,  268,
 /*  1500 */   654, 1305,   67,   68,  537,  285,  749,  875,  831,  831,
 /*  1510 */    65,   65,   66,   66,   66,   66,  864,   64,   64,   64,
 /*  1520 */    64,   63,   63,   62,   62,   62,   61,   59,  268,  875,
 /*  1530 */  1303,  834,  875,  873,  872,  513,  451,  302,  122,  779,
 /*  1540 */   324,  529,   44,  675,  502,   67,   68,  537,  285,   19,
 /*  1550 */   874,  831,  831,   65,   65,   66,   66,   66,   66,  841,
 /*  1560 */    64,   64,   64,   64,   63,   63,   62,   62,   62,   61,
 /*  1570 */    59,  268,  162,  538,  875,  649,  841,  875,  873,  872,
 /*  1580 */   534,  773,  842,  235,  477,  674,  673,  598,  774,  665,
 /*  1590 */   538,  536,  370,  501,    5,  309,  875,  442,  768,  842,
 /*  1600 */   235,  821,  350,  841,  767,  999,  875,   56,  536,  645,
 /*  1610 */   657,  874,  456,  122,  778,    4,  874,  538,  529,  491,
 /*  1620 */   492,  502,  122,  624,   53,   54,  842,  235,  669,  875,
 /*  1630 */   873,  872,   55,  122,  384,  536,  491,  478,  549,   92,
 /*  1640 */     2,  397,  874,  624,  378,  829,  616,   80,  841,  526,
 /*  1650 */   135,  875,  843,  872,  287,  481,  517,  534,  846,  765,
 /*  1660 */   752,  378,  538,  491,  482,  829,  845,  844,  843,  875,
 /*  1670 */   503,  842,  235,  875,  874,  383,  273,  617,  821,  619,
 /*  1680 */   536,  331,  618,   58,   56,  420,  763,    4,  378,  591,
 /*  1690 */   762,    4,   18,   79,  122,  795,  875,  873,  872,  874,
 /*  1700 */   829,   53,   54,  829,  433,  819,   12,  856,  407,   55,
 /*  1710 */   559,  418,  760,    4,   17,  587,  859,    2,  875,  873,
 /*  1720 */   872,  874,  829,   16,  426,  874,  526,  875,  875,  843,
 /*  1730 */   872,  392,  555,  378,  748,  846,  752,  875,  559,  529,
 /*  1740 */    11,   81,  829,  845,  844,  843,   67,   38,  537,  285,
 /*  1750 */   874,  748,  831,  831,   65,   65,   66,   66,   66,   66,
 /*  1760 */   555,   64,   64,   64,   64,   63,   63,   62,   62,   62,
 /*  1770 */    61,   59,  268,  761,    4,  862,  345,  829,  534,  114,
 /*  1780 */   829,  737,  819,   12,   72, 1065,  344,  752,  841,  735,
 /*  1790 */    87,  875,  873,  872,  350,  875,  873,  872,  197,  821,
 /*  1800 */   351,  874,  538,  394,  875,   56,  168,  272,  874,  736,
 /*  1810 */   742,  842,  220,  391,  874,  442,  529,  874,  186,  185,
 /*  1820 */   536,  841,   53,   54,  735, 1339, 1339,  874,  417,  874,
 /*  1830 */    55,  184,  583,  396,  421,  538,  261,  730,    2,  690,
 /*  1840 */   547,  725,  874,  829,  842,  123,  261,  526,  874,  875,
 /*  1850 */   843,  872,  790,  536,  874,  534,  846,  129,  428,  875,
 /*  1860 */   873,  872,  485,  829,  845,  844,  843,  637,    7,  701,
 /*  1870 */   416,  875,  483,  788,  580,  194,  821,  724,   15,  722,
 /*  1880 */   718,  875,   56,  341,  874,  310,   37,  795,  412,  717,
 /*  1890 */   121,  490,  380,  529,  271,  512,  713,  874,  829,   53,
 /*  1900 */    54,  829,  874,  819,   12,  875,  788,   55,  343,  877,
 /*  1910 */   120,  766,  524,  473,  791,    2,  327,  164,  277,   25,
 /*  1920 */   829,  875,  865,  874,  526,  863,  875,  843,  872,  122,
 /*  1930 */   861,  841,  534,  846,  681,  858,  874,  841,  851,  874,
 /*  1940 */   829,  845,  844,  843,  874,  538,  466,  489,  373,  874,
 /*  1950 */   839,  538,  874,  821,  842,  235,   36,  826,  875,   56,
 /*  1960 */   842,  123,  463,  536,  874,  531,  875,  672,   86,  536,
 /*  1970 */   529,  874,  754,  750,  744,  829,   53,   54,  829,  874,
 /*  1980 */   819,   12,  112,   85,   55,   24,  874,  874,  874,  330,
 /*  1990 */   458,  280,    2,  875,  873,  872,  875,  829,  166,  875,
 /*  2000 */   841,  526,  875,  875,  843,  872,   84,  336,  160,  534,
 /*  2010 */   846,  188,  874,  159,  538,  199,  378,  829,  845,  844,
 /*  2020 */   843,  589,  788,  842,  235,  488,  712,  875,  873,  872,
 /*  2030 */   821,  650,  536,  453,  332,  875,   56,  585,  158,  874,
 /*  2040 */   874,  589,  633,  875,  873,  872,   10,  529,  874,  688,
 /*  2050 */   156,  666,  829,   53,   54,  829,  105,  819,   12, 1229,
 /*  2060 */   279,   55,  326,  874,  154,  874,  758,   35,  103,    2,
 /*  2070 */  1231,   34,  585,   33,  829,   32,  874,  841,  526,  652,
 /*  2080 */   875,  843,  872, 1222,  102,  378,  534,  846,  875,  873,
 /*  2090 */   872,  538,  875,  874,  829,  845,  844,  843,  390,  388,
 /*  2100 */   842,  235,  838,  321,  626,  860,  101,  821,  430,  536,
 /*  2110 */   306,  620,  582,   56,  615,  613,  110,  874,  875,  873,
 /*  2120 */   872,  875,  873,  872,  875,  873,  872,  447,  171,  829,
 /*  2130 */    53,   54,  829,  304,  819,   12,  644,  401,   55,  641,
 /*  2140 */   424,  874,  875,  301,  607,   13,    2,  687,  183, 1233,
 /*  2150 */   874,  829,  551,  874,  874,  526,  148,  875,  843,  872,
 /*  2160 */   582,  359,  378,  203,  846,  146,  874,  588,  145,  875,
 /*  2170 */  1233,  829,  845,  844,  843,  874, 1233,  537,  285,  875,
 /*  2180 */   144,  831,  831,   65,   65,   66,   66,   66,   66,  143,
 /*  2190 */    64,   64,   64,   64,   63,   63,   62,   62,   62,   61,
 /*  2200 */    59,  268,  564,  535,  841,  563,  829,  322,  579,  829,
 /*  2210 */    96,  819,   12,  140,  875,  873,  872,  874,  538,  875,
 /*  2220 */   841,  874, 1233,  841,  444,  141,  841,  842,  123,  409,
 /*  2230 */  1233,  303,  544,  261,  538, 1233,  536,  538,  874,  841,
 /*  2240 */   538,   94,  257,  842,  123,  874,  842,  123,  276,  842,
 /*  2250 */   235,  116,  536,  538,  253,  536,  300,  382,  536, 1233,
 /*  2260 */   381,  878,  842,  235,  875,  873,  872,  294,  181,  875,
 /*  2270 */   874,  536, 1233,  290, 1233, 1233,  291,  579,  187,  868,
 /*  2280 */   867,  874,  866, 1233,  541, 1233, 1233,  874, 1233,  788,
 /*  2290 */   874,  875,  873,  872,  389,  546,  841,  387,  108,  496,
 /*  2300 */   454,  875,  873,  872,  732,  788, 1233,  180,  788,  875,
 /*  2310 */   538,  518,  178,  841,  348,  546,  841,   75,  540,  842,
 /*  2320 */   228,  837,  175,  836,  378,  287,  356,  538,  536,   23,
 /*  2330 */   538,  731,  355,  841,  653,  841,  842,  206,  841,  842,
 /*  2340 */   216,  875,  873,  872,  497,  536,  198,  538,  536,  538,
 /*  2350 */   841,  835,  538,   43,  268,  841,  842,  238,  842,  236,
 /*  2360 */   875,  842,  246,   70,  538,  536,   88,  536,  349,  538,
 /*  2370 */   536,  522,  265,  842,  245,  875,  841,  404,  842,  247,
 /*  2380 */   841,  788,  536,  841,  599,   49,  346,  536,  282,  281,
 /*  2390 */   538,  875,  873,  872,  538,  513,  785,  538,  788,  842,
 /*  2400 */   248,  788,  841,  842,  267,  841,  842,  353,  536,  786,
 /*  2410 */   403,  782,  536,  258,  170,  536,  538,  137,  788,  538,
 /*  2420 */   788,  484,  841,  788,  841,  842,  244,  841,  842,  352,
 /*  2430 */   875,  875,  873,  872,  536,  788,  538,  536,  538,  841,
 /*  2440 */   788,  538,  481,  841,  776,  842,  215,  842,  233,  770,
 /*  2450 */   842,  237,  714,  538,  536,  165,  536,  538,  703,  536,
 /*  2460 */   586,  788,  842,  376,  471,  788,  842,  375,  788,  698,
 /*  2470 */   697,  536,  399,  334,  694,  536,  693,  692,  841,  106,
 /*  2480 */   671,  841,  875,  873,  872,  372,   76,  788,  371,  664,
 /*  2490 */   788,  875,  538,  136,  452,  538,  875,  875,  873,  872,
 /*  2500 */   663,  842,  374,  841,  842,  232,  841,  788,  662,  788,
 /*  2510 */   536,  661,  788,  536,  157,  263,  320,  538,  841,  431,
 /*  2520 */   538,  449,   31,  841,  788,  318,  842,  218,  788,  842,
 /*  2530 */   231,  827,  538,  317,  204,  536,  316,  538,  536,  104,
 /*  2540 */   639,  842,  230,  875,  841,  152,  842,  217,  313,  312,
 /*  2550 */   536,  841,  875,  873,  872,  536,  311,  193,  538,  635,
 /*  2560 */   111,  438,  629,  788,  437,  538,  788,  842,  243,  625,
 /*  2570 */   308,  623,  134,  841,  842,  242,  536,  149,  841,  603,
 /*  2580 */   875,  425,  133,  536,  422,  147,  100,  538,  788,  643,
 /*  2590 */   419,  788,  538,   99,   98,  573,  842,  214,  841,   97,
 /*  2600 */    30,  842,  124,  788,   83,  536,  385,  142,  788,  841,
 /*  2610 */   536,  841,  538,  875,  873,  872,  560,   29,  875,  873,
 /*  2620 */   872,  842,  213,  538,  841,  538,  558,  678,  841,  788,
 /*  2630 */   536,   26,  842,  211,  842,  239,  788,  131,  538,  554,
 /*  2640 */   130,  536,  538,  536,  548,  841,  182,  842,  241,  357,
 /*  2650 */   841,  842,  234,  205,  519,  640,  536,  841,  788,  538,
 /*  2660 */   536,  841,   60,  788,  538,  875,  873,  872,  842,  240,
 /*  2670 */   799,  538,  814,  842,  229,  538,  756,  536,  810,  658,
 /*  2680 */   842,  226,  536,  788,  842,  210,  335,  191,  190,  536,
 /*  2690 */   249,  841,  689,  536,  788,  314,  788,  630,  875,  462,
 /*  2700 */   628,  367,  875,  873,  872,  538,    9,  875,  841,  788,
 /*  2710 */   832,  450,  809,  788,  842,  209,  612,  798,  875,  262,
 /*  2720 */   676,   41,  538,  536,  841,  358,  533,  841,  775,  707,
 /*  2730 */   788,  842,  208,   95,  686,  788,  875,  706,  538,  841,
 /*  2740 */   536,  538,  788,  680,  679,  597,  788,  842,  207,  667,
 /*  2750 */   842,  219,  875,  538,  841,   81,  536, 1383,  875,  536,
 /*  2760 */  1383,  875,  842,  224, 1383, 1383, 1383,  841,  538, 1383,
 /*  2770 */  1383,  536, 1383, 1383, 1383, 1383,  788,  842,  223, 1383,
 /*  2780 */  1383,  538,  841,  875, 1383, 1383,  536,  841,  875, 1383,
 /*  2790 */   842,  125,  875,  788, 1383, 1383,  538,  875, 1383,  536,
 /*  2800 */  1383,  538,  841, 1383,  875,  842,  222,  875, 1383,  788,
 /*  2810 */   842,  221,  788,  841,  536,  875,  538, 1383,  875,  536,
 /*  2820 */   875,  873,  872, 1383,  788,  842,  227,  538, 1383,  875,
 /*  2830 */   873,  872,  841, 1383,  536,  875,  842,  225, 1383,  788,
 /*  2840 */   875,  873,  872,  642,  875,  536,  538,  841, 1383, 1383,
 /*  2850 */  1383, 1383,  788, 1383,  636,  842,  212, 1383,  875,  873,
 /*  2860 */   872,  538, 1383, 1383,  536, 1383, 1383,  788, 1383,  753,
 /*  2870 */   842,   93,  788, 1383,  875,  873,  872, 1383, 1383,  487,
 /*  2880 */   875,  873,  872,  875,  873,  872, 1383,  788,  631, 1383,
 /*  2890 */  1383, 1383, 1383, 1383,  602, 1383, 1383,  590,  788, 1383,
 /*  2900 */  1383, 1383, 1383, 1383, 1383,  875,  873,  872, 1383, 1383,
 /*  2910 */   875,  873,  872, 1383,  875,  873,  872,  788,  604,  875,
 /*  2920 */   873,  872,  550, 1383, 1383, 1383,  875,  873,  872,  875,
 /*  2930 */   873,  872,  788,  552, 1383, 1383, 1383,  875,  873,  872,
 /*  2940 */   875,  873,  872, 1383, 1383, 1383, 1383,  584, 1383, 1383,
 /*  2950 */   790, 1383, 1383, 1383, 1383, 1383, 1383,  875,  873,  872,
 /*  2960 */  1383, 1383, 1383, 1383, 1383,  668,  875,  873,  872, 1383,
 /*  2970 */  1383, 1383, 1383,  581, 1383,  572,   30, 1383, 1383, 1383,
 /*  2980 */  1383, 1383, 1383, 1383, 1383, 1383,  796, 1383, 1383,  751,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */     4,  250,  251,    4,  253,   79,   49,   80,   81,   82,
 /*    10 */    83,    4,   16,   86,   87,   88,   89,   90,   91,   92,
 /*    20 */    93,  203,   95,   96,   97,   98,   99,  100,  101,  102,
 /*    30 */   103,  104,  105,  106,  112,  217,  285,   80,   81,   82,
 /*    40 */    83,  115,  116,   86,   87,   88,   89,   90,   91,   92,
 /*    50 */    93,   55,   95,   96,   97,   98,   99,  100,  101,  102,
 /*    60 */   103,  104,  105,  106,   75,  108,  101,  102,  103,  104,
 /*    70 */   105,  106,   76,   35,   90,   91,   92,   93,   82,   95,
 /*    80 */    96,   97,   98,   99,  100,  101,  102,  103,  104,  105,
 /*    90 */   106,  121,   34,  275,   56,   99,  100,  101,  145,   21,
 /*   100 */    62,    4,  215,  107,  108,   26,  219,  220,  221,    4,
 /*   110 */   183,  115,  116,   16,  115,   37,  120,  121,  165,  120,
 /*   120 */   124,   24,  126,  127,  128,  126,  127,  128,  158,  133,
 /*   130 */   160,  161,  108,  126,  127,  128,  140,  141,  142,  143,
 /*   140 */    82,  145,  153,   99,  100,  101,  102,  103,  104,  105,
 /*   150 */   106,   72,   55,    5,  158,  121,  160,  161,  116,  121,
 /*   160 */   164,  154,  128,  121,  106,  169,  170,  171,  172,  173,
 /*   170 */   174,  175,  203,   76,  178,  117,  180,  181,   30,   82,
 /*   180 */   191,  116,  213,  214,   36,  203,  217,  108,  192,  131,
 /*   190 */   132,  133,  134,  135,  136,  137,   99,  100,    4,  217,
 /*   200 */   166,  167,    4,   19,  107,  108,  121,   59,  239,  151,
 /*   210 */   241,   63,  115,  116,   16,  203,   67,  120,  121,   70,
 /*   220 */   127,  124,    4,  126,  127,  128,  133,    4,   44,  217,
 /*   230 */   133,  126,  127,  128,  141,  142,  143,  140,  141,  142,
 /*   240 */   143,   67,  145,   31,   70,  140,  115,    9,  117,   11,
 /*   250 */    66,   13,   40,   55,  242,  158,  115,  160,  161,  203,
 /*   260 */   155,   23,    4,  114,   26,    4,  169,  170,  171,  172,
 /*   270 */    76,  174,  175,  217,   76,  178,   21,  180,  181,  195,
 /*   280 */    82,  289,  131,   28,  200,  134,  135,  136,  114,  192,
 /*   290 */   203,   53,   37,   99,  100,  211,   58,   99,  100,  317,
 /*   300 */   308,   63,   64,  152,  217,  107,  108,   69,  296,  115,
 /*   310 */    72,   79,   74,  115,  116,    4,  203,  118,  120,  121,
 /*   320 */   126,  127,  124,    4,  126,  127,  128,  133,  110,  242,
 /*   330 */   217,  133,  248,  249,  185,  141,  142,  143,  140,  141,
 /*   340 */   142,  143,    4,  145,  126,  127,  128,  115,  116,  111,
 /*   350 */   127,  113,  159,  121,  170,  162,  158,  203,  160,  161,
 /*   360 */    41,   42,  139,  279,  210,  281,  212,  169,  284,  171,
 /*   370 */   172,  217,  174,  175,  318,  319,  178,  273,  180,  181,
 /*   380 */   276,  120,  101,  296,  126,  127,  128,  126,  127,  128,
 /*   390 */   192,  153,    4,   79,  310,    4,   26,   15,  140,   80,
 /*   400 */    81,   82,   83,   84,   85,   86,   87,   88,   89,   90,
 /*   410 */    91,   92,   93,    4,   95,   96,   97,   98,   99,  100,
 /*   420 */   101,  102,  103,  104,  105,  106,   44,  133,  190,  115,
 /*   430 */   116,  120,  319,  175,   41,   42,  117,  126,  127,  128,
 /*   440 */   159,   82,   60,  162,   41,   42,  127,  132,  133,  188,
 /*   450 */    80,   81,   82,   83,   51,  118,   86,   87,   88,   89,
 /*   460 */    90,   91,   92,   93,  126,   95,   96,   97,   98,   99,
 /*   470 */   100,  101,  102,  103,  104,  105,  106,   84,   85,  146,
 /*   480 */   147,  148,  163,   80,   81,   82,   83,   84,   85,   86,
 /*   490 */    87,   88,   89,   90,   91,   92,   93,  186,   95,   96,
 /*   500 */    97,   98,   99,  100,  101,  102,  103,  104,  105,  106,
 /*   510 */    10,  120,  115,  203,  126,  127,  128,  126,  127,  128,
 /*   520 */    59,  162,   22,    7,  121,  133,  138,  217,   12,  120,
 /*   530 */   203,  121,  150,   99,  100,  126,  127,  128,  222,  223,
 /*   540 */   224,   41,   42,  151,  217,  104,  105,  106,  139,  140,
 /*   550 */   223,  224,  182,  116,  184,   39,   90,   91,   92,   93,
 /*   560 */    94,   95,   96,   97,   98,   99,  100,  101,  102,  103,
 /*   570 */   104,  105,  106,  121,    4,  141,  142,  168,  187,   26,
 /*   580 */    80,   81,   82,   83,   84,   85,   86,   87,   88,   89,
 /*   590 */    90,   91,   92,   93,   82,   95,   96,   97,   98,   99,
 /*   600 */   100,  101,  102,  103,  104,  105,  106,  146,  147,  148,
 /*   610 */   203,  196,  197,  198,  199,  208,  300,  156,  157,  116,
 /*   620 */   213,  214,   41,   42,  217,  173,  299,  300,  117,  118,
 /*   630 */   320,  321,  322,   80,   81,   82,   83,   13,  126,   86,
 /*   640 */    87,   88,   89,   90,   91,   92,   93,    4,   95,   96,
 /*   650 */    97,   98,   99,  100,  101,  102,  103,  104,  105,  106,
 /*   660 */    43,   80,   81,   82,   83,   84,   85,   86,   87,   88,
 /*   670 */    89,   90,   91,   92,   93,  116,   95,   96,   97,   98,
 /*   680 */    99,  100,  101,  102,  103,  104,  105,  106,    4,  119,
 /*   690 */   120,  219,    4,  146,  147,  148,  126,  127,  128,   82,
 /*   700 */    16,  117,  118,   65,   80,   81,   82,   83,   89,   71,
 /*   710 */    86,   87,   88,   89,   90,   91,   92,   93,  115,   95,
 /*   720 */    96,   97,   98,   99,  100,  101,  102,  103,  104,  105,
 /*   730 */   106,  121,  108,    4,  115,  182,   35,  184,  266,   55,
 /*   740 */    95,   96,   97,   98,   99,  100,  101,  102,  103,  104,
 /*   750 */   105,  106,    4,   52,  144,    4,   72,   56,  203,  182,
 /*   760 */    76,  289,    4,   62,    0,  182,   82,  184,  125,  126,
 /*   770 */   127,  128,  217,  135,  131,   35,  116,  134,  135,  136,
 /*   780 */   116,  226,  227,   99,  100,  121,   35,   99,  100,    4,
 /*   790 */   235,  107,    4,   29,   78,  152,   56,  225,  273,  115,
 /*   800 */   116,  276,   62,   52,  120,  233,  234,   56,  124,   79,
 /*   810 */   126,  127,  128,   62,  126,  127,  128,  133,  263,  264,
 /*   820 */   132,  117,  118,  185,  140,  141,  142,  143,  203,  141,
 /*   830 */   142,  116,   32,  145,    4,  147,  250,  251,    4,  253,
 /*   840 */   156,  157,  217,  288,  115,  115,  116,  203,  116,  120,
 /*   850 */    42,  121,    4,  121,   54,  126,  127,  128,   73,  175,
 /*   860 */     4,  217,  178,  116,  180,  181,  116,  119,  120,  140,
 /*   870 */   169,  121,  108,  115,  126,  127,  128,  126,  127,  128,
 /*   880 */    80,   81,   82,   83,  155,  127,   86,   87,   88,   89,
 /*   890 */    90,   91,   92,   93,    4,   95,   96,   97,   98,   99,
 /*   900 */   100,  101,  102,  103,  104,  105,  106,    4,  123,  193,
 /*   910 */   122,  126,  127,  128,  126,  127,  128,    4,  211,   16,
 /*   920 */   169,  296,   19,   81,   82,   83,  255,    4,   86,   87,
 /*   930 */    88,   89,   90,   91,   92,   93,  265,   95,   96,   97,
 /*   940 */    98,   99,  100,  101,  102,  103,  104,  105,  106,  115,
 /*   950 */   217,    5,    4,  145,  120,  248,  249,  127,   55,  226,
 /*   960 */   126,  127,  128,  294,  320,  321,  322,    4,  255,  139,
 /*   970 */     4,   68,  115,  117,  140,  127,   30,  129,  265,   76,
 /*   980 */   141,  142,   36,  127,    4,   82,  279,   84,  281,  155,
 /*   990 */   203,  284,  203,  222,  223,  224,   16,  328,  329,  121,
 /*  1000 */   166,  167,   99,  100,  217,  115,  217,  117,    4,   63,
 /*  1010 */   107,    4,  305,  306,  203,  226,  227,  127,  115,  163,
 /*  1020 */   219,  220,  221,  120,  235,  294,   24,  124,  217,  126,
 /*  1030 */   127,  128,  116,  120,  203,   55,  133,  121,  115,  126,
 /*  1040 */   127,  128,  164,  140,  141,  142,  143,  203,  217,  126,
 /*  1050 */   127,  128,   72,  163,  267,  268,   76,  226,  227,  328,
 /*  1060 */   329,  217,   82,   29,  101,  116,  235,  154,  120,    4,
 /*  1070 */   121,  300,  203,   10,  126,  127,  128,  288,  175,   99,
 /*  1080 */   100,  178,  203,  180,  181,   22,  217,  107,  140,  126,
 /*  1090 */   127,  128,  126,  127,  128,  115,  217,  203,  175,  233,
 /*  1100 */   120,  207,  236,  140,  124,  116,  126,  127,  128,  243,
 /*  1110 */   121,  217,  323,  133,  121,  326,  168,  115,  274,  288,
 /*  1120 */   140,  141,  142,  143,  120,  203,  315,  120,  317,  203,
 /*  1130 */   126,  127,  128,  126,  127,  128,  156,  157,  175,  217,
 /*  1140 */    26,  116,  108,  217,  140,  273,  121,  140,  276,  223,
 /*  1150 */   224,  311,  312,  274,    4,  175,  325,  326,  178,   43,
 /*  1160 */   180,  181,   80,   81,   82,   83,  115,  298,   86,   87,
 /*  1170 */    88,   89,   90,   91,   92,   93,  116,   95,   96,   97,
 /*  1180 */    98,   99,  100,  101,  102,  103,  104,  105,  106,    4,
 /*  1190 */   268,  126,  127,  128,   80,   81,   82,   83,   26,  117,
 /*  1200 */    86,   87,   88,   89,   90,   91,   92,   93,  116,   95,
 /*  1210 */    96,   97,   98,   99,  100,  101,  102,  103,  104,  105,
 /*  1220 */   106,   80,   81,   82,   83,  299,  300,   86,   87,   88,
 /*  1230 */    89,   90,   91,   92,   93,  162,   95,   96,   97,   98,
 /*  1240 */    99,  100,  101,  102,  103,  104,  105,  106,  164,   80,
 /*  1250 */    81,   82,   83,  188,  164,   86,   87,   88,   89,   90,
 /*  1260 */    91,   92,   93,   72,   95,   96,   97,   98,   99,  100,
 /*  1270 */   101,  102,  103,  104,  105,  106,  126,  127,  128,  116,
 /*  1280 */    80,   81,   82,   83,  121,  116,   86,   87,   88,   89,
 /*  1290 */    90,   91,   92,   93,  169,   95,   96,   97,   98,   99,
 /*  1300 */   100,  101,  102,  103,  104,  105,  106,  219,  211,  116,
 /*  1310 */   116,  126,  127,  128,  121,  121,  116,  192,  168,   80,
 /*  1320 */    81,   82,   83,  132,  183,   86,   87,   88,   89,   90,
 /*  1330 */    91,   92,   93,   14,   95,   96,   97,   98,   99,  100,
 /*  1340 */   101,  102,  103,  104,  105,  106,  249,    4,  219,  148,
 /*  1350 */    80,   81,   82,   83,  266,  116,   86,   87,   88,   89,
 /*  1360 */    90,   91,   92,   93,  179,   95,   96,   97,   98,   99,
 /*  1370 */   100,  101,  102,  103,  104,  105,  106,  260,  177,  262,
 /*  1380 */    72,   80,   81,   82,   83,  121,  116,   86,   87,   88,
 /*  1390 */    89,   90,   91,   92,   93,  266,   95,   96,   97,   98,
 /*  1400 */    99,  100,  101,  102,  103,  104,  105,  106,    4,  244,
 /*  1410 */     4,  246,   80,   81,   82,   83,  108,  116,   86,   87,
 /*  1420 */    88,   89,   90,   91,   92,   93,  121,   95,   96,   97,
 /*  1430 */    98,   99,  100,  101,  102,  103,  104,  105,  106,  211,
 /*  1440 */   108,   80,   81,   82,   83,  198,  199,   86,   87,   88,
 /*  1450 */    89,   90,   91,   92,   93,    4,   95,   96,   97,   98,
 /*  1460 */    99,  100,  101,  102,  103,  104,  105,  106,  117,  126,
 /*  1470 */   127,  128,  115,   80,   81,   82,   83,  249,  117,   86,
 /*  1480 */    87,   88,   89,   90,   91,   92,   93,  121,   95,   96,
 /*  1490 */    97,   98,   99,  100,  101,  102,  103,  104,  105,  106,
 /*  1500 */   211,  108,   80,   81,   82,   83,  163,    4,   86,   87,
 /*  1510 */    88,   89,   90,   91,   92,   93,  110,   95,   96,   97,
 /*  1520 */    98,   99,  100,  101,  102,  103,  104,  105,  106,    4,
 /*  1530 */   108,  127,  126,  127,  128,  169,  203,  116,  249,  116,
 /*  1540 */   207,   16,  121,  139,   19,   80,   81,   82,   83,   14,
 /*  1550 */   217,   86,   87,   88,   89,   90,   91,   92,   93,  203,
 /*  1560 */    95,   96,   97,   98,   99,  100,  101,  102,  103,  104,
 /*  1570 */   105,  106,   42,  217,    4,  211,  203,  126,  127,  128,
 /*  1580 */    55,   61,  226,  227,  211,  217,  218,  116,   46,  138,
 /*  1590 */   217,  235,  121,   68,   81,  211,    4,  203,   32,  226,
 /*  1600 */   227,   76,  203,  203,   61,  116,    4,   82,  235,  211,
 /*  1610 */   121,  217,   82,  249,  321,  322,  217,  217,   16,  263,
 /*  1620 */   264,   19,  249,  120,   99,  100,  226,  227,  203,  126,
 /*  1630 */   127,  128,  107,  249,  205,  235,  263,  264,  213,  214,
 /*  1640 */   115,  242,  217,  140,  288,  120,  248,  249,  203,  124,
 /*  1650 */   121,  126,  127,  128,  156,  157,  211,   55,  133,   54,
 /*  1660 */   203,  288,  217,  263,  264,  140,  141,  142,  143,    4,
 /*  1670 */    68,  226,  227,    4,  217,  145,  282,  279,   76,  281,
 /*  1680 */   235,  151,  284,  121,   82,  203,  321,  322,  288,  207,
 /*  1690 */   321,  322,   14,  164,  249,  296,  126,  127,  128,  217,
 /*  1700 */   175,   99,  100,  178,  306,  180,  181,  203,  263,  107,
 /*  1710 */   140,  203,  321,  322,   14,  207,  212,  115,  126,  127,
 /*  1720 */   128,  217,  120,   14,  295,  217,  124,    4,  126,  127,
 /*  1730 */   128,  274,  140,  288,  219,  133,  203,    4,  168,   16,
 /*  1740 */    14,   72,  140,  141,  142,  143,   80,   81,   82,   83,
 /*  1750 */   217,  219,   86,   87,   88,   89,   90,   91,   92,   93,
 /*  1760 */   168,   95,   96,   97,   98,   99,  100,  101,  102,  103,
 /*  1770 */   104,  105,  106,  321,  322,  110,  229,  175,   55,  115,
 /*  1780 */   178,  266,  180,  181,  115,  116,  229,  203,  203,  120,
 /*  1790 */    57,  126,  127,  128,  203,  126,  127,  128,  266,   76,
 /*  1800 */   203,  217,  217,  203,    4,   82,   14,  274,  217,  140,
 /*  1810 */   126,  226,  227,  203,  217,  203,   16,  217,  116,  116,
 /*  1820 */   235,  203,   99,  100,  155,  156,  157,  217,  203,  217,
 /*  1830 */   107,  116,  207,  242,  203,  217,  289,  166,  115,  116,
 /*  1840 */   203,  101,  217,  120,  226,  227,  289,  124,  217,  126,
 /*  1850 */   127,  128,  119,  235,  217,   55,  133,  118,  274,  126,
 /*  1860 */   127,  128,  118,  140,  141,  142,  143,  244,  115,  246,
 /*  1870 */   203,    4,  121,  288,  207,  275,   76,  116,  115,  159,
 /*  1880 */   116,    4,   82,  203,  217,  275,  173,  296,  203,  116,
 /*  1890 */   116,  211,  207,   16,  282,  277,  116,  217,  175,   99,
 /*  1900 */   100,  178,  217,  180,  181,    4,  288,  107,  323,  203,
 /*  1910 */   116,  326,  315,  115,  317,  115,  116,   18,   49,  115,
 /*  1920 */   120,    4,  203,  217,  124,  203,  126,  127,  128,  249,
 /*  1930 */   203,  203,   55,  133,    6,  203,  217,  203,  203,  217,
 /*  1940 */   140,  141,  142,  143,  217,  217,  117,  267,  268,  217,
 /*  1950 */   203,  217,  217,   76,  226,  227,  115,  203,    4,   82,
 /*  1960 */   226,  227,   49,  235,  217,  203,    4,    8,  115,  235,
 /*  1970 */    16,  217,  203,  203,  203,  175,   99,  100,  178,  217,
 /*  1980 */   180,  181,  115,  115,  107,  115,  217,  217,  217,  116,
 /*  1990 */    49,  263,  115,  126,  127,  128,    4,  120,  203,    4,
 /*  2000 */   203,  124,    4,  126,  127,  128,  115,  151,  137,   55,
 /*  2010 */   133,  277,  217,  118,  217,  117,  288,  140,  141,  142,
 /*  2020 */   143,  120,  288,  226,  227,  203,  203,  126,  127,  128,
 /*  2030 */    76,  124,  235,   82,  203,    4,   82,  120,  118,  217,
 /*  2040 */   217,  140,  175,  126,  127,  128,   13,   16,  217,  203,
 /*  2050 */   145,  203,  175,   99,  100,  178,  164,  180,  181,  182,
 /*  2060 */   263,  107,  203,  217,  117,  217,  121,   89,  150,  115,
 /*  2070 */   116,   89,  155,   89,  120,   89,  217,  203,  124,  203,
 /*  2080 */   126,  127,  128,  108,  176,  288,   55,  133,  126,  127,
 /*  2090 */   128,  217,    4,  217,  140,  141,  142,  143,   18,   24,
 /*  2100 */   226,  227,  140,  203,  177,  110,  150,   76,   25,  235,
 /*  2110 */   157,  108,  120,   82,  108,   61,   50,  217,  126,  127,
 /*  2120 */   128,  126,  127,  128,  126,  127,  128,  203,  121,  175,
 /*  2130 */    99,  100,  178,  185,  180,  181,  203,  263,  107,  203,
 /*  2140 */   203,  217,    4,  114,   50,  115,  115,  149,  165,   35,
 /*  2150 */   217,  120,  203,  217,  217,  124,  145,  126,  127,  128,
 /*  2160 */   168,  203,  288,  115,  133,  118,  217,  124,  118,    4,
 /*  2170 */    56,  140,  141,  142,  143,  217,   62,   82,   83,    4,
 /*  2180 */   118,   86,   87,   88,   89,   90,   91,   92,   93,  118,
 /*  2190 */    95,   96,   97,   98,   99,  100,  101,  102,  103,  104,
 /*  2200 */   105,  106,  116,  203,  203,  116,  175,  203,  120,  178,
 /*  2210 */   114,  180,  181,  112,  126,  127,  128,  217,  217,    4,
 /*  2220 */   203,  217,  108,  203,  203,  118,  203,  226,  227,   48,
 /*  2230 */   116,  203,   47,  289,  217,  121,  235,  217,  217,  203,
 /*  2240 */   217,  216,  269,  226,  227,  217,  226,  227,  232,  226,
 /*  2250 */   227,  232,  235,  217,  312,  235,  203,  314,  235,  145,
 /*  2260 */   314,  202,  226,  227,  126,  127,  128,  203,  109,    4,
 /*  2270 */   217,  235,  158,  203,  160,  161,  203,  189,  277,  202,
 /*  2280 */   202,  217,   64,  169,  202,  171,  172,  217,  174,  288,
 /*  2290 */   217,  126,  127,  128,  277,  120,  203,  277,  206,  263,
 /*  2300 */    77,  126,  127,  128,  166,  288,  192,  204,  288,    4,
 /*  2310 */   217,  288,  204,  203,  291,  140,  203,  121,  209,  226,
 /*  2320 */   227,  272,  118,  251,  288,  156,  257,  217,  235,  173,
 /*  2330 */   217,  166,  258,  203,  119,  203,  226,  227,  203,  226,
 /*  2340 */   227,  126,  127,  128,  170,  235,  259,  217,  235,  217,
 /*  2350 */   203,  261,  217,  171,  106,  203,  226,  227,  226,  227,
 /*  2360 */     4,  226,  227,  172,  217,  235,  115,  235,  231,  217,
 /*  2370 */   235,  316,  106,  226,  227,    4,  203,  117,  226,  227,
 /*  2380 */   203,  288,  235,  203,  119,  182,  260,  235,  297,  292,
 /*  2390 */   217,  126,  127,  128,  217,  169,  278,  217,  288,  226,
 /*  2400 */   227,  288,  203,  226,  227,  203,  226,  227,  235,  261,
 /*  2410 */    45,  278,  235,   27,  272,  235,  217,  118,  288,  217,
 /*  2420 */   288,  253,  203,  288,  203,  226,  227,  203,  226,  227,
 /*  2430 */     4,  126,  127,  128,  235,  288,  217,  235,  217,  203,
 /*  2440 */   288,  217,  157,  203,  324,  226,  227,  226,  227,  324,
 /*  2450 */   226,  227,  329,  217,  235,  193,  235,  217,  228,  235,
 /*  2460 */   155,  288,  226,  227,  145,  288,  226,  227,  288,  228,
 /*  2470 */   238,  235,   38,  228,  230,  235,  144,  228,  203,  206,
 /*  2480 */   238,  203,  126,  127,  128,  231,  115,  288,  231,  228,
 /*  2490 */   288,    4,  217,  206,  231,  217,    4,  126,  127,  128,
 /*  2500 */   228,  226,  227,  203,  226,  227,  203,  288,  228,  288,
 /*  2510 */   235,  228,  288,  235,  118,  272,  303,  217,  203,   33,
 /*  2520 */   217,  304,  182,  203,  288,  257,  226,  227,  288,  226,
 /*  2530 */   227,  175,  217,  280,  174,  235,  260,  217,  235,  245,
 /*  2540 */   261,  226,  227,    4,  203,   80,  226,  227,  257,  280,
 /*  2550 */   235,  203,  126,  127,  128,  235,  260,  283,  217,  261,
 /*  2560 */   115,  145,  280,  288,  257,  217,  288,  226,  227,  280,
 /*  2570 */   286,  245,  206,  203,  226,  227,  235,  118,  203,  257,
 /*  2580 */     4,  272,  206,  235,  272,  118,  247,  217,  288,  163,
 /*  2590 */    77,  288,  217,  247,  247,  298,  226,  227,  203,  247,
 /*  2600 */   176,  226,  227,  288,  309,  235,  272,  118,  288,  203,
 /*  2610 */   235,  203,  217,  126,  127,  128,   20,  307,  126,  127,
 /*  2620 */   128,  226,  227,  217,  203,  217,  272,  140,  203,  288,
 /*  2630 */   235,  307,  226,  227,  226,  227,  288,  118,  217,  272,
 /*  2640 */   118,  235,  217,  235,   17,  203,  309,  226,  227,  256,
 /*  2650 */   203,  226,  227,  254,  293,  163,  235,  203,  288,  217,
 /*  2660 */   235,  203,  289,  288,  217,  126,  127,  128,  226,  227,
 /*  2670 */   229,  217,  300,  226,  227,  217,  271,  235,  300,  140,
 /*  2680 */   226,  227,  235,  288,  226,  227,  229,  260,  260,  235,
 /*  2690 */   240,  203,  236,  235,  288,  256,  288,  287,    4,  230,
 /*  2700 */   257,  201,  126,  127,  128,  217,  254,    4,  203,  288,
 /*  2710 */   219,  302,  219,  288,  226,  227,  140,  219,    4,  301,
 /*  2720 */   219,  290,  217,  235,  203,  252,  246,  203,  327,  226,
 /*  2730 */   288,  226,  227,  270,  237,  288,    4,  226,  217,  203,
 /*  2740 */   235,  217,  288,  237,  237,  313,  288,  226,  227,  241,
 /*  2750 */   226,  227,    4,  217,  203,   72,  235,  330,    4,  235,
 /*  2760 */   330,    4,  226,  227,  330,  330,  330,  203,  217,  330,
 /*  2770 */   330,  235,  330,  330,  330,  330,  288,  226,  227,  330,
 /*  2780 */   330,  217,  203,    4,  330,  330,  235,  203,    4,  330,
 /*  2790 */   226,  227,    4,  288,  330,  330,  217,    4,  330,  235,
 /*  2800 */   330,  217,  203,  330,    4,  226,  227,    4,  330,  288,
 /*  2810 */   226,  227,  288,  203,  235,    4,  217,  330,    4,  235,
 /*  2820 */   126,  127,  128,  330,  288,  226,  227,  217,  330,  126,
 /*  2830 */   127,  128,  203,  330,  235,    4,  226,  227,  330,  288,
 /*  2840 */   126,  127,  128,  140,    4,  235,  217,  203,  330,  330,
 /*  2850 */   330,  330,  288,  330,  140,  226,  227,  330,  126,  127,
 /*  2860 */   128,  217,  330,  330,  235,  330,  330,  288,  330,  175,
 /*  2870 */   226,  227,  288,  330,  126,  127,  128,  330,  330,  235,
 /*  2880 */   126,  127,  128,  126,  127,  128,  330,  288,  140,  330,
 /*  2890 */   330,  330,  330,  330,  140,  330,  330,  140,  288,  330,
 /*  2900 */   330,  330,  330,  330,  330,  126,  127,  128,  330,  330,
 /*  2910 */   126,  127,  128,  330,  126,  127,  128,  288,  186,  126,
 /*  2920 */   127,  128,  119,  330,  330,  330,  126,  127,  128,  126,
 /*  2930 */   127,  128,  288,  140,  330,  330,  330,  126,  127,  128,
 /*  2940 */   126,  127,  128,  330,  330,  330,  330,  168,  330,  330,
 /*  2950 */   119,  330,  330,  330,  330,  330,  330,  126,  127,  128,
 /*  2960 */   330,  330,  330,  330,  330,  125,  126,  127,  128,  330,
 /*  2970 */   330,  330,  330,  189,  330,  187,  176,  330,  330,  330,
 /*  2980 */   330,  330,  330,  330,  330,  330,  175,  330,  330,  175,
};
#define YY_SHIFT_USE_DFLT (-79)
#define YY_SHIFT_COUNT (542)
#define YY_SHIFT_MIN   (-78)
#define YY_SHIFT_MAX   (2840)
static const short yy_shift_ofst[] = {
 /*     0 */  1034,  684,  980,  238,  903, 1602, 1525, 1954, 1954, 1954,
 /*    10 */  1308,  198, 1877, 2031, 2031, 2031, 2031, 2031, 2031, 2031,
 /*    20 */  2031,   79,   -4,   97, 1800, 1723, 2031, 2031, 2031, 2031,
 /*    30 */  2031, 2031, 2031, 2031, 2031, 2031, 2031, 2031, 2031, 2031,
 /*    40 */  2031, 2031, 2031, 2031, 2031, 2031, 2031, 2031, 2031, 2031,
 /*    50 */  2031, 2031, 2031, 2031, 2031, 2031, 2031, 2031, 2031, 2031,
 /*    60 */  2031, 2031, 2031, 2031, 2031, 2031, 2031, 2031, 2031, 2031,
 /*    70 */  2031, 2031, 1669,  688,  688,  643,  751,  751, 2840,  834,
 /*    80 */   461, 1733,  785, 2840, 2811, 2811, 2811, 2831, 2811,  966,
 /*    90 */   434,  434,  848,  319,   58,  729, 2175, 2088, 1992, 1917,
 /*   100 */  1901, 1867, 1503, 1867, 1007, 1004,  913,  785,  748, 2800,
 /*   110 */  2814, 2814, 2814, 2814, 2814, 2811, 1530,  966,  966,  848,
 /*   120 */   716,  716, 1498,  500,  500,  -43,  194,  409,  948,  963,
 /*   130 */  1592, 1570,  391,  570,  311,  923,  261,  105,  258,   -1,
 /*   140 */  2803, 2793, 2788, 2784, 2779, 2305, 2757, 2265, 2754, 2732,
 /*   150 */  2748, 2714,  148, 2492, 2426, 2703, 2576, 1065,    7, 2215,
 /*   160 */  2539, 1451, 1998, 2487,  148, 2371, 2165, 2138, 1150, 1343,
 /*   170 */   890, 2694,  701, 1185, 2356, 1962,  388,  788, 1995, 1665,
 /*   180 */  1406,  218,  966,  966,  856,  856,  856,   38,   38,  638,
 /*   190 */   740,  740,  764, 1191,  512,  512,  338,  512, 1125, 2683,
 /*   200 */  2683, 2683, 2683,  -79,  -79,  -79,  403,  581,  581,  581,
 /*   210 */   581,  581,  581,  581,  581,  581,  581,  553,  370,  624,
 /*   220 */   800, 1422, 1393, 1361, 1332, 1301, 1270, 1239, 1200, 1169,
 /*   230 */  1141, 1114,  -73, 1082, 1666, 1465,  842, 2095, 2095,  466,
 /*   240 */   -16,  -16,  -16,  -16,  -16,  -16,  645,   44,  -35,  151,
 /*   250 */    93,   93,  730,  232,  382,  382,  382,   34,  184,  946,
 /*   260 */   -30,  393,  547,  516, 1404,  830,  758,  441,  223,  281,
 /*   270 */   255,  452,  732, 1529,  610, 1489,  808, 1063,  -47, 1366,
 /*   280 */  1366,  583, 1063,  839,  839,  359,  878,  193, 2627, 2627,
 /*   290 */  2522, 2519, 2596, 2596, 2489, 2424, 2513, 2513, 2513, 2513,
 /*   300 */  2467, 2223, 2156, 2459, 2223, 2465, 2360, 2156, 2360, 2416,
 /*   310 */  2445, 2191, 2226, 2360, 2156, 2465, 2191, 2226, 2360, 2156,
 /*   320 */  2340, 2486, 2396, 2223, 2251, 2223, 2251, 2319, 2319, 2319,
 /*   330 */  2319, 2434, 2251, 2319, 2332, 2319, 2434, 2319, 2319, 2262,
 /*   340 */  2285, 2299, 2386, 2386, 2365, 2365, 2191, 2226, 2203, 2260,
 /*   350 */  2266, 2251, 2248, 2248, 2191, 2182, 2174, 2156, 2169, 2204,
 /*   360 */  2196, 2223, 2218, 2218, 2159, 2159, 2159, 2159,  -79,  -79,
 /*   370 */   -79,  -79,  -79,  -79,  -79,  -79,  -79,  -79, 2114,  149,
 /*   380 */   -11,  314,  -74,  333,  174,  619, 1471, 1421, 1201, 1194,
 /*   390 */  1002,  704, 1193, 1163,  584,  511, 1025,  989,  315,   78,
 /*   400 */   392,  949,  916,  212,  617,  750,  664,   42,  131, 2185,
 /*   410 */  2181, 2101, 2107, 2096, 2089, 2086, 2071, 2062, 2050, 2043,
 /*   420 */  2047, 2048, 1983, 2029, 2030, 2011, 1948, 2094, 2007, 2066,
 /*   430 */  2054, 2083, 2006, 2003, 1953, 1927, 1956, 2075, 2080, 1975,
 /*   440 */  1908, 1986, 1984, 1982, 1978, 1918, 1945, 1947, 1892, 2033,
 /*   450 */  1905, 1920, 1898, 1907, 1951, 1895, 1856, 1871, 1891, 1941,
 /*   460 */  1870, 1868, 1873, 1853, 1913, 1959, 1841, 1829, 1928, 1804,
 /*   470 */  1869, 1899, 1794, 1713, 1798, 1780, 1774, 1773, 1764, 1751,
 /*   480 */  1720, 1763, 1761, 1753, 1751, 1740, 1744, 1739, 1671, 1715,
 /*   490 */  1703, 1562, 1702, 1684, 1792, 1664, 1562, 1726, 1709, 1700,
 /*   500 */  1678, 1605, 1543, 1566, 1513, 1520, 1542, 1535, 1423, 1357,
 /*   510 */  1351, 1305, 1264, 1319, 1090, 1084, 1073, 1092,  577, 1172,
 /*   520 */   993, 1060, 1051, 1116,  993,  747,  857,  715,  660,  603,
 /*   530 */   559,  503,  437,  410,  397,  337,  199,  294,  141,   85,
 /*   540 */    65,  -78,   24,
};
#define YY_REDUCE_USE_DFLT (-250)
#define YY_REDUCE_COUNT (377)
#define YY_REDUCE_MIN   (-249)
#define YY_REDUCE_MAX   (2644)
static const short yy_reduce_ofst[] = {
 /*     0 */   415, 1373, 1445,   84, 1585,  831,  789, 1400, 1356,  555,
 /*    10 */   707, 2036, 2023, 2020, 2017, 1874, 2001, 1734, 1797, 1728,
 /*    20 */  1618, 1398, 2644, 2629, 2610, 2599, 2584, 2579, 2564, 2551,
 /*    30 */  2536, 2524, 2521, 2505, 2488, 2458, 2454, 2447, 2442, 2425,
 /*    40 */  2421, 2408, 2406, 2395, 2375, 2370, 2348, 2341, 2320, 2315,
 /*    50 */  2303, 2300, 2278, 2275, 2240, 2236, 2224, 2221, 2219, 2202,
 /*    60 */  2199, 2180, 2177, 2173, 2152, 2147, 2135, 2132, 2130, 2113,
 /*    70 */  2110, 2093, 1680,  926,  327,  -31,  644,  310,  407,  787,
 /*    80 */  -249, 1597,  154, 1425, 1591, 1399,   87,  811,   12,   56,
 /*    90 */   771,  316, -113,  472,  572,  922, 1685, 1667, 1625, 1508,
 /*   100 */  1482, 1612, 1610, 1394, 1600, -182, 1333, 1504,  894,  869,
 /*   110 */  1584, 1533, 1457,  879,  844,  625,  866,  113,  -18,  801,
 /*   120 */   731,  669,  586, 1557, 1547,   -8,  733, 2073, 2070, 2000,
 /*   130 */  1747, 1747, 2064, 2053, 2028, 2021, 2004, 1747, 2000, 1958,
 /*   140 */  1949, 1876, 1747, 1876, 1876, 1876, 1876, 1747, 1937, 1747,
 /*   150 */  1924, 1924, 1623, 1936, 1933, 1924, 1900, 1747, 1876, 1876,
 /*   160 */  1859, 1848, 1846, 1831, 1165, 1823, 1822, 1795, 1771, 1770,
 /*   170 */  1532, 1769, 1452, 1762, 1754, 1747, 1735, 1732, 1727, 1722,
 /*   180 */  1719, 1706, 1637, 1631, 1515, 1129, 1088, 1391, 1369, 1429,
 /*   190 */  1365, 1293, 1247, 1384,  872,  525, 1368,  104, 1117, 1364,
 /*   200 */  1289, 1228, 1097,  840,  713,  671, 1944, 1944, 1944, 1944,
 /*   210 */  1944, 1944, 1944, 1944, 1944, 1944, 1944, 1944, 1944, 1944,
 /*   220 */  1944, 1944, 1944, 1944, 1944, 1944, 1944, 1944, 1944, 1944,
 /*   230 */  1944, 1944, 1944, 1944, 1944, 1944, 1944, 1944, 1944, 1944,
 /*   240 */  1944, 1944, 1944, 1944, 1944, 1944, 1944, 1944, 1944, 2508,
 /*   250 */  2511, 2503, 2432, 2432, 2507, 2506, 2497, 2463, 2401, 2480,
 /*   260 */  2473, 2431, 2409, 2418, 2501, 2498, 2493, 1944, 2491, 2452,
 /*   270 */  2500, 2443, 2410, 2439, 2469, 2450, 2456, 2457, 2405, 2428,
 /*   280 */  2427, 2361, 2441, 2378, 2372, 2373, 2393, 2399, 2337, 2295,
 /*   290 */  2367, 2354, 2324, 2310, 2334, 2297, 2352, 2347, 2346, 2339,
 /*   300 */  2312, 2376, 2322, 2309, 2366, 2326, 2289, 2307, 2282, 2284,
 /*   310 */  2274, 2298, 2296, 2269, 2291, 2294, 2279, 2276, 2253, 2268,
 /*   320 */  2217, 2213, 2243, 2287, 2263, 2273, 2257, 2283, 2280, 2272,
 /*   330 */  2261, 2242, 2254, 2249, 2244, 2245, 2232, 2241, 2230, 2123,
 /*   340 */  2168, 2142, 2125, 2120, 2133, 2118, 2148, 2126, 2097, 2055,
 /*   350 */  2091, 2137, 1944, 1944, 2090, 2087, 2074, 2069, 2072, 2049,
 /*   360 */  2109, 2092, 2108, 2103, 2082, 2078, 2077, 2059, 1946, 1943,
 /*   370 */  1942, 2019, 2016, 1973, 1944, 1944, 1944, 2025,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */   888, 1217, 1217, 1339, 1217, 1217, 1217, 1217, 1217, 1217,
 /*    10 */  1339, 1217, 1217, 1217, 1217, 1217, 1217, 1217, 1217, 1217,
 /*    20 */  1217, 1339, 1217, 1217, 1217, 1217, 1217, 1217, 1217, 1217,
 /*    30 */  1217, 1217, 1217, 1217, 1217, 1217, 1217, 1217, 1217, 1217,
 /*    40 */  1217, 1217, 1217, 1217, 1217, 1217, 1217, 1217, 1217, 1217,
 /*    50 */  1217, 1217, 1217, 1217, 1217, 1217, 1217, 1217, 1217, 1217,
 /*    60 */  1217, 1217, 1217, 1217, 1217, 1217, 1217, 1217, 1217, 1217,
 /*    70 */  1217, 1217, 1072, 1381, 1381, 1381, 1358, 1358, 1381, 1065,
 /*    80 */  1381, 1381,  916, 1381, 1381, 1381, 1381, 1381, 1381, 1381,
 /*    90 */  1381, 1381,  939, 1061,  929, 1072, 1381, 1381, 1381, 1381,
 /*   100 */  1381, 1142, 1157, 1142, 1134, 1123, 1381, 1381, 1381, 1255,
 /*   110 */  1150, 1150, 1150, 1150, 1150, 1381, 1012, 1381, 1381, 1381,
 /*   120 */  1185, 1184, 1381, 1108, 1108, 1219, 1381, 1308, 1313, 1178,
 /*   130 */  1381, 1381, 1381, 1381, 1381, 1143, 1381, 1073, 1178, 1381,
 /*   140 */  1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,
 /*   150 */  1158, 1135, 1381, 1381, 1381, 1124, 1381, 1381, 1381, 1381,
 /*   160 */  1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,
 /*   170 */  1061, 1381, 1358, 1381, 1180, 1381, 1381, 1381, 1381, 1381,
 /*   180 */  1381,  894, 1381, 1381, 1061, 1061, 1061, 1358, 1358,  926,
 /*   190 */  1358, 1358,  888, 1339, 1097, 1097,  934, 1097, 1102, 1339,
 /*   200 */  1339, 1339, 1339, 1332, 1051, 1051, 1118, 1141, 1140, 1139,
 /*   210 */  1138, 1078, 1128, 1116, 1120, 1232, 1119, 1219, 1219, 1219,
 /*   220 */  1219, 1219, 1219, 1219, 1219, 1219, 1219, 1219, 1219, 1219,
 /*   230 */  1219, 1219, 1219, 1219, 1219, 1219, 1187, 1201, 1186, 1194,
 /*   240 */  1206, 1195, 1200, 1199, 1198, 1189, 1188, 1190, 1191, 1381,
 /*   250 */  1381, 1381, 1381, 1381, 1381, 1381, 1381, 1064, 1381, 1381,
 /*   260 */  1034, 1381, 1381, 1282, 1381, 1381,  941, 1192, 1381, 1049,
 /*   270 */   897, 1127, 1221, 1062,  979, 1003,  963, 1108, 1080, 1102,
 /*   280 */  1102, 1227, 1108, 1381, 1381, 1219, 1062, 1049, 1323, 1323,
 /*   290 */  1081, 1081, 1307, 1307, 1081, 1255, 1025, 1025, 1025, 1025,
 /*   300 */  1081,  923, 1127, 1081,  923, 1016, 1130, 1127, 1130, 1163,
 /*   310 */  1146, 1117, 1102, 1130, 1127, 1016, 1117, 1102, 1130, 1127,
 /*   320 */  1289, 1287, 1081,  923, 1240,  923, 1240, 1014, 1014, 1014,
 /*   330 */  1014,  995, 1240, 1014,  979, 1014,  995, 1014, 1014, 1377,
 /*   340 */  1381, 1081, 1368, 1368, 1111, 1111, 1117, 1102, 1381, 1381,
 /*   350 */  1246, 1240, 1205, 1193, 1117, 1115, 1112, 1127, 1381, 1081,
 /*   360 */   998,  923,  905,  905,  893,  893,  893,  893, 1336, 1336,
 /*   370 */  1332,  981,  981, 1067, 1204, 1203, 1202,  950, 1218, 1381,
 /*   380 */  1381, 1381, 1381, 1381, 1381, 1256, 1381, 1381, 1381, 1381,
 /*   390 */  1381, 1085, 1381, 1381, 1085, 1085, 1381, 1381, 1381, 1381,
 /*   400 */  1381, 1381, 1381, 1381, 1342, 1381, 1381, 1381, 1381, 1381,
 /*   410 */   889, 1381, 1083, 1381, 1381, 1381, 1083, 1083, 1083, 1381,
 /*   420 */  1083, 1326, 1381, 1381, 1381, 1381, 1381, 1381, 1286, 1285,
 /*   430 */  1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1147,
 /*   440 */  1381, 1381, 1381, 1381, 1381, 1381, 1131, 1086, 1381, 1274,
 /*   450 */  1381, 1083, 1381, 1381, 1381, 1083, 1381, 1381, 1381, 1381,
 /*   460 */  1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,
 /*   470 */  1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1037,
 /*   480 */  1043, 1381, 1381, 1381, 1038, 1381, 1381, 1176, 1381, 1381,
 /*   490 */  1381, 1230, 1381, 1381, 1381, 1381, 1113, 1381, 1381, 1381,
 /*   500 */  1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,
 /*   510 */  1381, 1374, 1103, 1381, 1381, 1381, 1220, 1381, 1218, 1381,
 /*   520 */  1341, 1381, 1381, 1381, 1340, 1381, 1381, 1381, 1381, 1381,
 /*   530 */  1381, 1381, 1381, 1381, 1381, 1177, 1176, 1220,  936,  912,
 /*   540 */  1381,  903, 1381,  885,  890, 1325, 1322, 1319, 1324, 1318,
 /*   550 */  1320, 1317, 1321, 1316, 1314, 1315, 1312, 1310, 1309, 1311,
 /*   560 */  1306, 1302, 1262, 1260, 1258, 1267, 1266, 1265, 1264, 1263,
 /*   570 */  1259, 1257, 1261, 1253, 1252, 1153, 1132, 1121, 1032, 1301,
 /*   580 */  1299, 1300, 1251, 1249, 1250, 1031, 1030, 1029, 1024, 1023,
 /*   590 */  1022, 1021, 1329, 1338, 1337, 1335, 1334, 1333, 1327, 1328,
 /*   600 */  1238, 1237, 1235, 1234, 1236,  925, 1278, 1281, 1280, 1279,
 /*   610 */  1284, 1283, 1276, 1288, 1293, 1292, 1297, 1296, 1295, 1294,
 /*   620 */  1291, 1273, 1162, 1161, 1159, 1155, 1166, 1165, 1164, 1154,
 /*   630 */  1156, 1160, 1137, 1145, 1144, 1133, 1136, 1017, 1126, 1122,
 /*   640 */  1090, 1088, 1125, 1089, 1087, 1033, 1277, 1028, 1027, 1026,
 /*   650 */   924,  915, 1084,  914,  913,  928, 1001, 1002, 1010, 1013,
 /*   660 */  1008, 1011, 1007, 1006, 1005, 1009, 1004, 1000,  931,  930,
 /*   670 */   940,  994,  977,  966,  933,  968,  965,  964,  969,  986,
 /*   680 */   985,  992,  991,  990,  989,  988,  984,  987,  983,  982,
 /*   690 */   970,  962,  961,  980,  960,  997,  996,  993,  959, 1020,
 /*   700 */  1019, 1018, 1015,  958,  957,  956,  955,  954,  953, 1216,
 /*   710 */  1380, 1376, 1379, 1378, 1375, 1215, 1223, 1209, 1207, 1035,
 /*   720 */  1046, 1045, 1044, 1041, 1042, 1056, 1054, 1053, 1052, 1096,
 /*   730 */  1095, 1094, 1093, 1092, 1091, 1077, 1075, 1070, 1069, 1076,
 /*   740 */  1074, 1071, 1100, 1101, 1099, 1098, 1068, 1060, 1058, 1059,
 /*   750 */  1057, 1152, 1149, 1151, 1148, 1079, 1066, 1063, 1050, 1356,
 /*   760 */  1354, 1357, 1355, 1353, 1361, 1363, 1362, 1367, 1365, 1364,
 /*   770 */  1360, 1373, 1372, 1371, 1370, 1369, 1359, 1366, 1352, 1351,
 /*   780 */  1350, 1349, 1105, 1110, 1109, 1104, 1040, 1208, 1218, 1212,
 /*   790 */  1347, 1345, 1348, 1344, 1343, 1243, 1245, 1248, 1247, 1244,
 /*   800 */  1107, 1106, 1242, 1241, 1346, 1211, 1183,  946,  944,  945,
 /*   810 */  1270, 1269, 1272, 1271, 1268,  948,  947,  943,  942, 1181,
 /*   820 */  1175, 1174, 1298, 1213, 1214, 1173, 1179, 1171, 1170, 1169,
 /*   830 */  1197, 1196, 1182, 1172,  935, 1039, 1036, 1210, 1168, 1082,
 /*   840 */  1167,  976,  975,  974,  973,  972,  971, 1048, 1047,  952,
 /*   850 */   967,  951,  949,  927,  917,  922,  920,  921,  919,  918,
 /*   860 */   910,  907,  909,  906,  911,  908,  904,  902,  901,  900,
 /*   870 */   899,  898,  938,  937,  936,  932,  896,  895,  892,  891,
 /*   880 */   887,  886,  884,
};

/* The next table maps tokens into fallback tokens.  If a construct
** like the following:
**
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*    ILLEGAL => nothing */
    0,  /*    COMMENT => nothing */
    0,  /*      SPACE => nothing */
    0,  /*         ID => nothing */
    4,  /*      ABORT => ID */
    4,  /*     ACTION => ID */
    4,  /*      AFTER => ID */
    4,  /*     ALWAYS => ID */
    4,  /*    ANALYZE => ID */
    4,  /*        ASC => ID */
    4,  /*     ATTACH => ID */
    4,  /*     BEFORE => ID */
    4,  /*      BEGIN => ID */
    4,  /*         BY => ID */
    4,  /*    CASCADE => ID */
    4,  /*       CAST => ID */
    4,  /*   COLUMNKW => ID */
    4,  /*   CONFLICT => ID */
    4,  /*    CURRENT => ID */
    4,  /*   DATABASE => ID */
    4,  /*   DEFERRED => ID */
    4,  /*       DESC => ID */
    4,  /*     DETACH => ID */
    4,  /*         DO => ID */
    4,  /*       EACH => ID */
    4,  /*        END => ID */
    4,  /*    EXCLUDE => ID */
    4,  /*  EXCLUSIVE => ID */
    4,  /*    EXPLAIN => ID */
    4,  /*       FAIL => ID */
    4,  /*      FIRST => ID */
    4,  /*  FOLLOWING => ID */
    4,  /*        FOR => ID */
    4,  /*  GENERATED => ID */
    4,  /*     GROUPS => ID */
    4,  /*     IGNORE => ID */
    4,  /*  IMMEDIATE => ID */
    4,  /*  INITIALLY => ID */
    4,  /*    INSTEAD => ID */
    4,  /*       LAST => ID */
    4,  /*    LIKE_KW => ID */
    4,  /*      MATCH => ID */
    4,  /* MATERIALIZED => ID */
    4,  /*         NO => ID */
    4,  /*      NULLS => ID */
    4,  /*     OTHERS => ID */
    4,  /*       PLAN => ID */
    4,  /*      QUERY => ID */
    4,  /*        KEY => ID */
    4,  /*         OF => ID */
    4,  /*     OFFSET => ID */
    4,  /*  PARTITION => ID */
    4,  /*     PRAGMA => ID */
    4,  /*  PRECEDING => ID */
    4,  /*      RAISE => ID */
    4,  /*      RANGE => ID */
    4,  /*  RECURSIVE => ID */
    4,  /*    RELEASE => ID */
    4,  /*    REPLACE => ID */
    4,  /*   RESTRICT => ID */
    4,  /*        ROW => ID */
    4,  /*       ROWS => ID */
    4,  /*   ROLLBACK => ID */
    4,  /*  SAVEPOINT => ID */
    4,  /*       TEMP => ID */
    4,  /*       TIES => ID */
    4,  /*    TRIGGER => ID */
    4,  /*  UNBOUNDED => ID */
    4,  /*     VACUUM => ID */
    4,  /*       VIEW => ID */
    4,  /*    VIRTUAL => ID */
    4,  /*       WITH => ID */
    4,  /*    WITHOUT => ID */
    4,  /*    REINDEX => ID */
    4,  /*     RENAME => ID */
    4,  /*   CTIME_KW => ID */
    4,  /*         IF => ID */
    4,  /*     FILTER => ID */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
  QList<Token*>* tokens = nullptr;
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  int yyidx;                    /* Index of top element in stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyidxMax;                 /* Maximum value of yyidx */
#endif
  int yyerrcnt;                 /* Shifts left before out of the error */
  sqlite3_parseARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

void *sqlite3_parseCopyParserState(void* other)
{
  yyParser *pParser;
  yyParser *otherParser = (yyParser*)other;

  // Copy parser
  pParser = (yyParser*)malloc((size_t)sizeof(yyParser));
  memcpy(pParser, other, (size_t)sizeof(yyParser));

#if YYSTACKDEPTH<=0
  // Copy stack
  int stackSize = sizeof(yyStackEntry) * pParser->yystksz;
  pParser->yystack = malloc((size_t)stackSize);
  memcpy(pParser->yystack, ((yyParser*)other)->yystack, (size_t)stackSize);
#endif

  for (int i = 0; i <= pParser->yyidx; i++)
  {
      pParser->yystack[i].tokens = new QList<Token*>();
      *(pParser->yystack[i].tokens) = *(otherParser->yystack[i].tokens);
  }

  return pParser;
}

void sqlite3_parseAddToken(void* other, Token* token)
{
    yyParser *otherParser = (yyParser*)other;
    if (otherParser->yyidx < 0)
        return; // Nothing on stack yet. Might happen when parsing just whitespaces, nothing else.

    otherParser->yystack[otherParser->yyidx].tokens->append(token);
}

void sqlite3_parseRestoreParserState(void* saved, void* target)
{
  yyParser *pParser = (yyParser*)target;
  yyParser *savedParser = (yyParser*)saved;

  for (int i = 0; i <= pParser->yyidx; i++)
      delete pParser->yystack[i].tokens;

  memcpy(pParser, saved, (size_t)sizeof(yyParser));

  for (int i = 0; i <= savedParser->yyidx; i++)
  {
      pParser->yystack[i].tokens = new QList<Token*>();
      *(pParser->yystack[i].tokens) = *(savedParser->yystack[i].tokens);
  }

#if YYSTACKDEPTH<=0
  // Copy stack
  int stackSize = sizeof(yyStackEntry) * pParser->yystksz;
  pParser->yystack = relloc(pParser->yystack, (size_t)stackSize);
  memcpy(pParser->yystack, ((yyParser*)saved)->yystack, (size_t)stackSize);
#endif
}

void sqlite3_parseFreeSavedState(void* other)
{
    yyParser *pParser = (yyParser*)other;
    for (int i = 0; i <= pParser->yyidx; i++)
        delete pParser->yystack[i].tokens;

#if YYSTACKDEPTH<=0
    free(pParser->yystack);
#endif
    free(other);
}

#ifndef NDEBUG
/*
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void sqlite3_parseTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = {
  "$",             "ILLEGAL",       "COMMENT",       "SPACE",       
  "ID",            "ABORT",         "ACTION",        "AFTER",       
  "ALWAYS",        "ANALYZE",       "ASC",           "ATTACH",      
  "BEFORE",        "BEGIN",         "BY",            "CASCADE",     
  "CAST",          "COLUMNKW",      "CONFLICT",      "CURRENT",     
  "DATABASE",      "DEFERRED",      "DESC",          "DETACH",      
  "DO",            "EACH",          "END",           "EXCLUDE",     
  "EXCLUSIVE",     "EXPLAIN",       "FAIL",          "FIRST",       
  "FOLLOWING",     "FOR",           "GENERATED",     "GROUPS",      
  "IGNORE",        "IMMEDIATE",     "INITIALLY",     "INSTEAD",     
  "LAST",          "LIKE_KW",       "MATCH",         "MATERIALIZED",
  "NO",            "NULLS",         "OTHERS",        "PLAN",        
  "QUERY",         "KEY",           "OF",            "OFFSET",      
  "PARTITION",     "PRAGMA",        "PRECEDING",     "RAISE",       
  "RANGE",         "RECURSIVE",     "RELEASE",       "REPLACE",     
  "RESTRICT",      "ROW",           "ROWS",          "ROLLBACK",    
  "SAVEPOINT",     "TEMP",          "TIES",          "TRIGGER",     
  "UNBOUNDED",     "VACUUM",        "VIEW",          "VIRTUAL",     
  "WITH",          "WITHOUT",       "REINDEX",       "RENAME",      
  "CTIME_KW",      "IF",            "FILTER",        "ANY",         
  "OR",            "AND",           "NOT",           "IS",          
  "BETWEEN",       "IN",            "ISNULL",        "NOTNULL",     
  "NE",            "EQ",            "GT",            "LE",          
  "LT",            "GE",            "ESCAPE",        "BITAND",      
  "BITOR",         "LSHIFT",        "RSHIFT",        "PLUS",        
  "MINUS",         "STAR",          "SLASH",         "REM",         
  "CONCAT",        "PTR",           "COLLATE",       "BITNOT",      
  "SEMI",          "TRANSACTION",   "ID_TRANS",      "COMMIT",      
  "TO",            "CREATE",        "TABLE",         "LP",          
  "RP",            "AS",            "DOT",           "ID_TAB_NEW",  
  "ID_DB",         "COMMA",         "CTX_ROWID_KW",  "CTX_STRICT_KW",
  "EXISTS",        "ID_COL_NEW",    "INDEXED",       "STRING",      
  "JOIN_KW",       "ID_COL_TYPE",   "RIGHT_ASSOC",   "CONSTRAINT",  
  "DEFAULT",       "NULL",          "PRIMARY",       "UNIQUE",      
  "CHECK",         "REFERENCES",    "ID_CONSTR",     "ID_COLLATE",  
  "ID_TAB",        "INTEGER",       "FLOAT",         "BLOB",        
  "AUTOINCR",      "ON",            "INSERT",        "DELETE",      
  "UPDATE",        "ID_FK_MATCH",   "SET",           "DEFERRABLE",  
  "FOREIGN",       "DROP",          "ID_VIEW_NEW",   "ID_VIEW",     
  "SELECT",        "VALUES",        "UNION",         "ALL",         
  "EXCEPT",        "INTERSECT",     "DISTINCT",      "ID_ALIAS",    
  "FROM",          "USING",         "JOIN",          "ID_JOIN_OPTS",
  "ID_IDX",        "ORDER",         "GROUP",         "HAVING",      
  "LIMIT",         "WHERE",         "RETURNING",     "ID_COL",      
  "INTO",          "NOTHING",       "ID_FN",         "ID_ERR_MSG",  
  "VARIABLE",      "CASE",          "WHEN",          "THEN",        
  "ELSE",          "INDEX",         "ID_IDX_NEW",    "ID_PRAGMA",   
  "ID_TRIG_NEW",   "ID_TRIG",       "ALTER",         "ADD",         
  "WINDOW",        "OVER",          "error",         "cmd",         
  "input",         "cmdlist",       "ecmd",          "explain",     
  "cmdx",          "transtype",     "trans_opt",     "nm",          
  "savepoint_opt",  "temp",          "ifnotexists",   "fullname",    
  "columnlist",    "conslist_opt",  "table_options",  "select",      
  "table_option",  "column",        "columnid",      "type",        
  "carglist",      "id",            "id_opt",        "ids",         
  "typetoken",     "typename",      "signed",        "plus_num",    
  "minus_num",     "ccons",         "term",          "expr",        
  "onconf",        "sortorder",     "autoinc",       "idxlist_opt", 
  "refargs",       "defer_subclause",  "gen_always",    "tnm",         
  "refarg",        "refact",        "init_deferred_pred_opt",  "conslist",    
  "tconscomma",    "tcons",         "idxlist",       "defer_subclause_opt",
  "resolvetype",   "orconf",        "raisetype",     "ifexists",    
  "select_stmt",   "with",          "selectnowith",  "oneselect",   
  "multiselect_op",  "values",        "distinct",      "selcollist",  
  "from",          "where_opt",     "groupby_opt",   "having_opt",  
  "orderby_opt",   "limit_opt",     "window_clause",  "nexprlist",   
  "exprlist",      "sclp",          "as",            "joinsrc",     
  "singlesrc",     "seltablist",    "joinop",        "joinconstr_opt",
  "dbnm",          "indexed_opt",   "idlist",        "xfullname",   
  "indexed_by",    "sortlist",      "nulls",         "delete_stmt", 
  "returning",     "update_stmt",   "setlist",       "idlist_opt",  
  "insert_stmt",   "insert_cmd",    "upsert",        "rp_opt",      
  "exprx",         "not_opt",       "likeop",        "case_operand",
  "case_exprlist",  "case_else",     "filter_over",   "uniqueflag",  
  "idxlist_single",  "collate",       "vinto",         "nmnum",       
  "number",        "trigger_time",  "trigger_event",  "foreach_clause",
  "when_clause",   "trigger_cmd_list",  "trigger_cmd",   "database_kw_opt",
  "key_opt",       "kwcolumn_opt",  "create_vtab",   "vtabarglist", 
  "vtabarg",       "vtabargtoken",  "anylist",       "wqlist",      
  "wqas",          "wqcte",         "windowdefn_list",  "windowdefn",  
  "window",        "frame_opt",     "range_or_rows",  "frame_bound_s",
  "frame_exclude_opt",  "frame_bound_e",  "frame_bound",   "frame_exclude",
  "filter_clause",  "over_clause", 
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "input ::= cmdlist",
 /*   1 */ "cmdlist ::= cmdlist ecmd",
 /*   2 */ "cmdlist ::= ecmd",
 /*   3 */ "ecmd ::= SEMI",
 /*   4 */ "ecmd ::= explain cmdx SEMI",
 /*   5 */ "explain ::=",
 /*   6 */ "explain ::= EXPLAIN",
 /*   7 */ "explain ::= EXPLAIN QUERY PLAN",
 /*   8 */ "cmdx ::= cmd",
 /*   9 */ "cmd ::= BEGIN transtype trans_opt",
 /*  10 */ "trans_opt ::=",
 /*  11 */ "trans_opt ::= TRANSACTION",
 /*  12 */ "trans_opt ::= TRANSACTION nm",
 /*  13 */ "trans_opt ::= TRANSACTION ID_TRANS",
 /*  14 */ "transtype ::=",
 /*  15 */ "transtype ::= DEFERRED",
 /*  16 */ "transtype ::= IMMEDIATE",
 /*  17 */ "transtype ::= EXCLUSIVE",
 /*  18 */ "cmd ::= COMMIT trans_opt",
 /*  19 */ "cmd ::= END trans_opt",
 /*  20 */ "cmd ::= ROLLBACK trans_opt",
 /*  21 */ "savepoint_opt ::= SAVEPOINT",
 /*  22 */ "savepoint_opt ::=",
 /*  23 */ "cmd ::= SAVEPOINT nm",
 /*  24 */ "cmd ::= RELEASE savepoint_opt nm",
 /*  25 */ "cmd ::= ROLLBACK trans_opt TO savepoint_opt nm",
 /*  26 */ "cmd ::= SAVEPOINT ID_TRANS",
 /*  27 */ "cmd ::= RELEASE savepoint_opt ID_TRANS",
 /*  28 */ "cmd ::= ROLLBACK trans_opt TO savepoint_opt ID_TRANS",
 /*  29 */ "cmd ::= CREATE temp TABLE ifnotexists fullname LP columnlist conslist_opt RP table_options",
 /*  30 */ "cmd ::= CREATE temp TABLE ifnotexists fullname AS select",
 /*  31 */ "cmd ::= CREATE temp TABLE ifnotexists nm DOT ID_TAB_NEW",
 /*  32 */ "cmd ::= CREATE temp TABLE ifnotexists ID_DB|ID_TAB_NEW",
 /*  33 */ "table_options ::=",
 /*  34 */ "table_options ::= table_option",
 /*  35 */ "table_options ::= table_options COMMA table_option",
 /*  36 */ "table_option ::= WITHOUT nm",
 /*  37 */ "table_option ::= nm",
 /*  38 */ "table_option ::= WITHOUT CTX_ROWID_KW",
 /*  39 */ "table_option ::= CTX_STRICT_KW",
 /*  40 */ "ifnotexists ::=",
 /*  41 */ "ifnotexists ::= IF NOT EXISTS",
 /*  42 */ "temp ::= TEMP",
 /*  43 */ "temp ::=",
 /*  44 */ "columnlist ::= columnlist COMMA column",
 /*  45 */ "columnlist ::= column",
 /*  46 */ "column ::= columnid type carglist",
 /*  47 */ "columnid ::= nm",
 /*  48 */ "columnid ::= ID_COL_NEW",
 /*  49 */ "id ::= ID|INDEXED",
 /*  50 */ "id_opt ::= id",
 /*  51 */ "id_opt ::=",
 /*  52 */ "ids ::= ID|STRING",
 /*  53 */ "nm ::= id",
 /*  54 */ "nm ::= STRING",
 /*  55 */ "nm ::= JOIN_KW",
 /*  56 */ "type ::=",
 /*  57 */ "type ::= typetoken",
 /*  58 */ "typetoken ::= typename",
 /*  59 */ "typetoken ::= typename LP signed RP",
 /*  60 */ "typetoken ::= typename LP signed COMMA signed RP",
 /*  61 */ "typename ::= ids",
 /*  62 */ "typename ::= typename ids",
 /*  63 */ "typename ::= ID_COL_TYPE",
 /*  64 */ "signed ::= plus_num",
 /*  65 */ "signed ::= minus_num",
 /*  66 */ "carglist ::= carglist ccons",
 /*  67 */ "carglist ::=",
 /*  68 */ "ccons ::= CONSTRAINT nm",
 /*  69 */ "ccons ::= DEFAULT term",
 /*  70 */ "ccons ::= DEFAULT LP expr RP",
 /*  71 */ "ccons ::= DEFAULT PLUS term",
 /*  72 */ "ccons ::= DEFAULT MINUS term",
 /*  73 */ "ccons ::= DEFAULT id",
 /*  74 */ "ccons ::= DEFAULT CTIME_KW",
 /*  75 */ "ccons ::= NULL onconf",
 /*  76 */ "ccons ::= NOT NULL onconf",
 /*  77 */ "ccons ::= PRIMARY KEY sortorder onconf autoinc",
 /*  78 */ "ccons ::= UNIQUE onconf",
 /*  79 */ "ccons ::= CHECK LP expr RP",
 /*  80 */ "ccons ::= REFERENCES nm idxlist_opt refargs",
 /*  81 */ "ccons ::= defer_subclause",
 /*  82 */ "ccons ::= COLLATE ids",
 /*  83 */ "ccons ::= gen_always AS LP expr RP id_opt",
 /*  84 */ "ccons ::= CONSTRAINT ID_CONSTR",
 /*  85 */ "ccons ::= COLLATE ID_COLLATE",
 /*  86 */ "ccons ::= REFERENCES ID_TAB",
 /*  87 */ "ccons ::= CHECK LP RP",
 /*  88 */ "term ::= NULL",
 /*  89 */ "term ::= INTEGER",
 /*  90 */ "term ::= FLOAT",
 /*  91 */ "term ::= STRING|BLOB",
 /*  92 */ "tnm ::= term",
 /*  93 */ "tnm ::= nm",
 /*  94 */ "gen_always ::= GENERATED ALWAYS",
 /*  95 */ "gen_always ::=",
 /*  96 */ "autoinc ::=",
 /*  97 */ "autoinc ::= AUTOINCR",
 /*  98 */ "refargs ::=",
 /*  99 */ "refargs ::= refargs refarg",
 /* 100 */ "refarg ::= MATCH nm",
 /* 101 */ "refarg ::= ON INSERT refact",
 /* 102 */ "refarg ::= ON DELETE refact",
 /* 103 */ "refarg ::= ON UPDATE refact",
 /* 104 */ "refarg ::= MATCH ID_FK_MATCH",
 /* 105 */ "refact ::= SET NULL",
 /* 106 */ "refact ::= SET DEFAULT",
 /* 107 */ "refact ::= CASCADE",
 /* 108 */ "refact ::= RESTRICT",
 /* 109 */ "refact ::= NO ACTION",
 /* 110 */ "defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt",
 /* 111 */ "defer_subclause ::= DEFERRABLE init_deferred_pred_opt",
 /* 112 */ "init_deferred_pred_opt ::=",
 /* 113 */ "init_deferred_pred_opt ::= INITIALLY DEFERRED",
 /* 114 */ "init_deferred_pred_opt ::= INITIALLY IMMEDIATE",
 /* 115 */ "conslist_opt ::=",
 /* 116 */ "conslist_opt ::= COMMA conslist",
 /* 117 */ "conslist ::= conslist tconscomma tcons",
 /* 118 */ "conslist ::= tcons",
 /* 119 */ "tconscomma ::= COMMA",
 /* 120 */ "tconscomma ::=",
 /* 121 */ "tcons ::= CONSTRAINT nm",
 /* 122 */ "tcons ::= PRIMARY KEY LP idxlist autoinc RP onconf",
 /* 123 */ "tcons ::= UNIQUE LP idxlist RP onconf",
 /* 124 */ "tcons ::= CHECK LP expr RP onconf",
 /* 125 */ "tcons ::= FOREIGN KEY LP idxlist RP REFERENCES nm idxlist_opt refargs defer_subclause_opt",
 /* 126 */ "tcons ::= CONSTRAINT ID_CONSTR",
 /* 127 */ "tcons ::= FOREIGN KEY LP idxlist RP REFERENCES ID_TAB",
 /* 128 */ "tcons ::= CHECK LP RP onconf",
 /* 129 */ "defer_subclause_opt ::=",
 /* 130 */ "defer_subclause_opt ::= defer_subclause",
 /* 131 */ "onconf ::=",
 /* 132 */ "onconf ::= ON CONFLICT resolvetype",
 /* 133 */ "orconf ::=",
 /* 134 */ "orconf ::= OR resolvetype",
 /* 135 */ "resolvetype ::= raisetype",
 /* 136 */ "resolvetype ::= IGNORE",
 /* 137 */ "resolvetype ::= REPLACE",
 /* 138 */ "cmd ::= DROP TABLE ifexists fullname",
 /* 139 */ "cmd ::= DROP TABLE ifexists nm DOT ID_TAB",
 /* 140 */ "cmd ::= DROP TABLE ifexists ID_DB|ID_TAB",
 /* 141 */ "ifexists ::= IF EXISTS",
 /* 142 */ "ifexists ::=",
 /* 143 */ "cmd ::= CREATE temp VIEW ifnotexists fullname idxlist_opt AS select",
 /* 144 */ "cmd ::= CREATE temp VIEW ifnotexists nm DOT ID_VIEW_NEW",
 /* 145 */ "cmd ::= CREATE temp VIEW ifnotexists ID_DB|ID_VIEW_NEW",
 /* 146 */ "cmd ::= DROP VIEW ifexists fullname",
 /* 147 */ "cmd ::= DROP VIEW ifexists nm DOT ID_VIEW",
 /* 148 */ "cmd ::= DROP VIEW ifexists ID_DB|ID_VIEW",
 /* 149 */ "cmd ::= select_stmt",
 /* 150 */ "select_stmt ::= select",
 /* 151 */ "select ::= with selectnowith",
 /* 152 */ "selectnowith ::= oneselect",
 /* 153 */ "selectnowith ::= selectnowith multiselect_op oneselect",
 /* 154 */ "selectnowith ::= values",
 /* 155 */ "selectnowith ::= selectnowith COMMA values",
 /* 156 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt",
 /* 157 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt window_clause orderby_opt limit_opt",
 /* 158 */ "values ::= VALUES LP nexprlist RP",
 /* 159 */ "values ::= values COMMA LP exprlist RP",
 /* 160 */ "multiselect_op ::= UNION",
 /* 161 */ "multiselect_op ::= UNION ALL",
 /* 162 */ "multiselect_op ::= EXCEPT",
 /* 163 */ "multiselect_op ::= INTERSECT",
 /* 164 */ "distinct ::= DISTINCT",
 /* 165 */ "distinct ::= ALL",
 /* 166 */ "distinct ::=",
 /* 167 */ "sclp ::= selcollist COMMA",
 /* 168 */ "sclp ::=",
 /* 169 */ "selcollist ::= sclp expr as",
 /* 170 */ "selcollist ::= sclp STAR",
 /* 171 */ "selcollist ::= sclp tnm DOT STAR",
 /* 172 */ "selcollist ::= sclp",
 /* 173 */ "selcollist ::= sclp ID_TAB DOT STAR",
 /* 174 */ "as ::= AS nm",
 /* 175 */ "as ::= ids",
 /* 176 */ "as ::= AS ID_ALIAS",
 /* 177 */ "as ::= ID_ALIAS",
 /* 178 */ "as ::=",
 /* 179 */ "from ::=",
 /* 180 */ "from ::= FROM joinsrc",
 /* 181 */ "joinsrc ::= singlesrc seltablist",
 /* 182 */ "joinsrc ::=",
 /* 183 */ "seltablist ::= seltablist joinop singlesrc joinconstr_opt",
 /* 184 */ "seltablist ::=",
 /* 185 */ "singlesrc ::= nm dbnm as indexed_opt",
 /* 186 */ "singlesrc ::= LP select RP as",
 /* 187 */ "singlesrc ::= LP joinsrc RP as",
 /* 188 */ "singlesrc ::= nm dbnm LP exprlist RP as",
 /* 189 */ "singlesrc ::=",
 /* 190 */ "singlesrc ::= nm DOT",
 /* 191 */ "singlesrc ::= nm DOT ID_TAB",
 /* 192 */ "singlesrc ::= ID_DB|ID_TAB",
 /* 193 */ "singlesrc ::= nm DOT ID_VIEW",
 /* 194 */ "singlesrc ::= ID_DB|ID_VIEW",
 /* 195 */ "joinconstr_opt ::= ON expr",
 /* 196 */ "joinconstr_opt ::= USING LP idlist RP",
 /* 197 */ "joinconstr_opt ::=",
 /* 198 */ "dbnm ::=",
 /* 199 */ "dbnm ::= DOT nm",
 /* 200 */ "fullname ::= nm",
 /* 201 */ "fullname ::= nm DOT nm",
 /* 202 */ "xfullname ::= nm",
 /* 203 */ "xfullname ::= nm DOT nm",
 /* 204 */ "xfullname ::= nm DOT nm AS nm",
 /* 205 */ "xfullname ::= nm AS nm",
 /* 206 */ "xfullname ::= nm DOT nm AS ID_ALIAS",
 /* 207 */ "xfullname ::= nm AS ID_ALIAS",
 /* 208 */ "joinop ::= COMMA",
 /* 209 */ "joinop ::= JOIN",
 /* 210 */ "joinop ::= JOIN_KW JOIN",
 /* 211 */ "joinop ::= JOIN_KW nm JOIN",
 /* 212 */ "joinop ::= JOIN_KW nm nm JOIN",
 /* 213 */ "joinop ::= ID_JOIN_OPTS",
 /* 214 */ "indexed_opt ::=",
 /* 215 */ "indexed_opt ::= indexed_by",
 /* 216 */ "indexed_by ::= INDEXED BY nm",
 /* 217 */ "indexed_by ::= NOT INDEXED",
 /* 218 */ "indexed_by ::= INDEXED BY ID_IDX",
 /* 219 */ "orderby_opt ::=",
 /* 220 */ "orderby_opt ::= ORDER BY sortlist",
 /* 221 */ "sortlist ::= sortlist COMMA expr sortorder nulls",
 /* 222 */ "sortlist ::= expr sortorder nulls",
 /* 223 */ "sortorder ::= ASC",
 /* 224 */ "sortorder ::= DESC",
 /* 225 */ "sortorder ::=",
 /* 226 */ "nulls ::= NULLS FIRST",
 /* 227 */ "nulls ::= NULLS LAST",
 /* 228 */ "nulls ::=",
 /* 229 */ "groupby_opt ::=",
 /* 230 */ "groupby_opt ::= GROUP BY nexprlist",
 /* 231 */ "groupby_opt ::= GROUP BY",
 /* 232 */ "having_opt ::=",
 /* 233 */ "having_opt ::= HAVING expr",
 /* 234 */ "limit_opt ::=",
 /* 235 */ "limit_opt ::= LIMIT expr",
 /* 236 */ "limit_opt ::= LIMIT expr OFFSET expr",
 /* 237 */ "limit_opt ::= LIMIT expr COMMA expr",
 /* 238 */ "cmd ::= delete_stmt",
 /* 239 */ "delete_stmt ::= with DELETE FROM xfullname indexed_opt where_opt returning orderby_opt limit_opt",
 /* 240 */ "delete_stmt ::= with DELETE FROM",
 /* 241 */ "delete_stmt ::= with DELETE FROM nm DOT",
 /* 242 */ "delete_stmt ::= with DELETE FROM nm DOT ID_TAB",
 /* 243 */ "delete_stmt ::= with DELETE FROM ID_DB|ID_TAB",
 /* 244 */ "where_opt ::=",
 /* 245 */ "where_opt ::= WHERE expr",
 /* 246 */ "where_opt ::= WHERE",
 /* 247 */ "returning ::=",
 /* 248 */ "returning ::= RETURNING selcollist",
 /* 249 */ "cmd ::= update_stmt",
 /* 250 */ "update_stmt ::= with UPDATE orconf xfullname indexed_opt SET setlist from where_opt returning orderby_opt limit_opt",
 /* 251 */ "update_stmt ::= with UPDATE orconf",
 /* 252 */ "update_stmt ::= with UPDATE orconf nm DOT",
 /* 253 */ "update_stmt ::= with UPDATE orconf nm DOT ID_TAB",
 /* 254 */ "update_stmt ::= with UPDATE orconf ID_DB|ID_TAB",
 /* 255 */ "setlist ::= setlist COMMA nm EQ expr",
 /* 256 */ "setlist ::= setlist COMMA LP idlist RP EQ expr",
 /* 257 */ "setlist ::= nm EQ expr",
 /* 258 */ "setlist ::= LP idlist RP EQ expr",
 /* 259 */ "setlist ::=",
 /* 260 */ "setlist ::= setlist COMMA",
 /* 261 */ "setlist ::= setlist COMMA ID_COL",
 /* 262 */ "setlist ::= ID_COL",
 /* 263 */ "idlist_opt ::=",
 /* 264 */ "idlist_opt ::= LP idlist RP",
 /* 265 */ "idlist ::= idlist COMMA nm",
 /* 266 */ "idlist ::= nm",
 /* 267 */ "idlist ::=",
 /* 268 */ "idlist ::= idlist COMMA ID_COL",
 /* 269 */ "idlist ::= ID_COL",
 /* 270 */ "cmd ::= insert_stmt",
 /* 271 */ "insert_stmt ::= with insert_cmd INTO xfullname idlist_opt select upsert returning",
 /* 272 */ "insert_stmt ::= with insert_cmd INTO xfullname idlist_opt DEFAULT VALUES returning",
 /* 273 */ "insert_stmt ::= with insert_cmd INTO xfullname LP idlist rp_opt",
 /* 274 */ "insert_stmt ::= with insert_cmd INTO",
 /* 275 */ "insert_stmt ::= with insert_cmd INTO nm DOT",
 /* 276 */ "insert_stmt ::= with insert_cmd INTO ID_DB|ID_TAB",
 /* 277 */ "insert_stmt ::= with insert_cmd INTO nm DOT ID_TAB",
 /* 278 */ "insert_cmd ::= INSERT orconf",
 /* 279 */ "insert_cmd ::= REPLACE",
 /* 280 */ "upsert ::=",
 /* 281 */ "upsert ::= ON CONFLICT LP sortlist RP where_opt DO UPDATE SET setlist where_opt",
 /* 282 */ "upsert ::= ON CONFLICT LP sortlist RP where_opt DO NOTHING",
 /* 283 */ "upsert ::= ON CONFLICT DO NOTHING",
 /* 284 */ "exprx ::= expr not_opt IN ID_DB",
 /* 285 */ "exprx ::= expr not_opt IN nm DOT ID_TAB",
 /* 286 */ "exprx ::= ID_DB|ID_TAB|ID_COL|ID_FN",
 /* 287 */ "exprx ::= tnm DOT ID_TAB|ID_COL",
 /* 288 */ "exprx ::= tnm DOT nm DOT ID_COL",
 /* 289 */ "exprx ::= expr COLLATE ID_COLLATE",
 /* 290 */ "exprx ::= RAISE LP raisetype COMMA ID_ERR_MSG RP",
 /* 291 */ "exprx ::= CTIME_KW",
 /* 292 */ "exprx ::= LP nexprlist RP",
 /* 293 */ "exprx ::= tnm",
 /* 294 */ "exprx ::= tnm DOT nm",
 /* 295 */ "exprx ::= tnm DOT",
 /* 296 */ "exprx ::= tnm DOT nm DOT nm",
 /* 297 */ "exprx ::= tnm DOT nm DOT",
 /* 298 */ "exprx ::= VARIABLE",
 /* 299 */ "exprx ::= expr COLLATE ids",
 /* 300 */ "exprx ::= CAST LP expr AS typetoken RP",
 /* 301 */ "exprx ::= id LP distinct exprlist RP",
 /* 302 */ "exprx ::= id LP STAR RP",
 /* 303 */ "exprx ::= expr AND expr",
 /* 304 */ "exprx ::= expr OR expr",
 /* 305 */ "exprx ::= expr LT|GT|GE|LE expr",
 /* 306 */ "exprx ::= expr EQ|NE expr",
 /* 307 */ "exprx ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr",
 /* 308 */ "exprx ::= expr PLUS|MINUS expr",
 /* 309 */ "exprx ::= expr STAR|SLASH|REM expr",
 /* 310 */ "exprx ::= expr CONCAT expr",
 /* 311 */ "exprx ::= expr not_opt likeop expr",
 /* 312 */ "exprx ::= expr not_opt likeop expr ESCAPE expr",
 /* 313 */ "exprx ::= expr ISNULL|NOTNULL",
 /* 314 */ "exprx ::= expr NOT NULL",
 /* 315 */ "exprx ::= expr IS not_opt expr",
 /* 316 */ "exprx ::= expr IS NOT DISTINCT FROM expr",
 /* 317 */ "exprx ::= expr IS DISTINCT FROM expr",
 /* 318 */ "exprx ::= NOT expr",
 /* 319 */ "exprx ::= BITNOT expr",
 /* 320 */ "exprx ::= MINUS expr",
 /* 321 */ "exprx ::= PLUS expr",
 /* 322 */ "exprx ::= expr PTR expr",
 /* 323 */ "exprx ::= expr not_opt BETWEEN expr AND expr",
 /* 324 */ "exprx ::= expr not_opt IN LP exprlist RP",
 /* 325 */ "exprx ::= LP select RP",
 /* 326 */ "exprx ::= expr not_opt IN LP select RP",
 /* 327 */ "exprx ::= expr not_opt IN nm dbnm",
 /* 328 */ "exprx ::= EXISTS LP select RP",
 /* 329 */ "exprx ::= CASE case_operand case_exprlist case_else END",
 /* 330 */ "exprx ::= RAISE LP IGNORE RP",
 /* 331 */ "exprx ::= RAISE LP raisetype COMMA nm RP",
 /* 332 */ "exprx ::= id LP distinct exprlist RP filter_over",
 /* 333 */ "exprx ::= id LP STAR RP filter_over",
 /* 334 */ "expr ::=",
 /* 335 */ "expr ::= exprx",
 /* 336 */ "not_opt ::=",
 /* 337 */ "not_opt ::= NOT",
 /* 338 */ "rp_opt ::=",
 /* 339 */ "rp_opt ::= RP",
 /* 340 */ "likeop ::= LIKE_KW|MATCH",
 /* 341 */ "case_exprlist ::= case_exprlist WHEN expr THEN expr",
 /* 342 */ "case_exprlist ::= WHEN expr THEN expr",
 /* 343 */ "case_else ::= ELSE expr",
 /* 344 */ "case_else ::=",
 /* 345 */ "case_operand ::= exprx",
 /* 346 */ "case_operand ::=",
 /* 347 */ "exprlist ::= nexprlist",
 /* 348 */ "exprlist ::=",
 /* 349 */ "nexprlist ::= nexprlist COMMA expr",
 /* 350 */ "nexprlist ::= exprx",
 /* 351 */ "cmd ::= CREATE uniqueflag INDEX ifnotexists nm dbnm ON nm LP sortlist RP where_opt",
 /* 352 */ "cmd ::= CREATE uniqueflag INDEX ifnotexists nm dbnm ON ID_TAB",
 /* 353 */ "cmd ::= CREATE uniqueflag INDEX ifnotexists nm DOT ID_IDX_NEW",
 /* 354 */ "cmd ::= CREATE uniqueflag INDEX ifnotexists ID_DB|ID_IDX_NEW",
 /* 355 */ "uniqueflag ::= UNIQUE",
 /* 356 */ "uniqueflag ::=",
 /* 357 */ "idxlist_opt ::=",
 /* 358 */ "idxlist_opt ::= LP idxlist RP",
 /* 359 */ "idxlist ::= idxlist COMMA idxlist_single",
 /* 360 */ "idxlist ::= idxlist_single",
 /* 361 */ "idxlist_single ::= nm collate sortorder",
 /* 362 */ "idxlist_single ::= ID_COL",
 /* 363 */ "collate ::=",
 /* 364 */ "collate ::= COLLATE ids",
 /* 365 */ "collate ::= COLLATE ID_COLLATE",
 /* 366 */ "cmd ::= DROP INDEX ifexists fullname",
 /* 367 */ "cmd ::= DROP INDEX ifexists nm DOT ID_IDX",
 /* 368 */ "cmd ::= DROP INDEX ifexists ID_DB|ID_IDX",
 /* 369 */ "cmd ::= VACUUM vinto",
 /* 370 */ "cmd ::= VACUUM nm vinto",
 /* 371 */ "vinto ::= INTO expr",
 /* 372 */ "vinto ::=",
 /* 373 */ "cmd ::= PRAGMA nm dbnm",
 /* 374 */ "cmd ::= PRAGMA nm dbnm EQ nmnum",
 /* 375 */ "cmd ::= PRAGMA nm dbnm LP nmnum RP",
 /* 376 */ "cmd ::= PRAGMA nm dbnm EQ minus_num",
 /* 377 */ "cmd ::= PRAGMA nm dbnm LP minus_num RP",
 /* 378 */ "cmd ::= PRAGMA nm DOT ID_PRAGMA",
 /* 379 */ "cmd ::= PRAGMA ID_DB|ID_PRAGMA",
 /* 380 */ "nmnum ::= plus_num",
 /* 381 */ "nmnum ::= nm",
 /* 382 */ "nmnum ::= ON",
 /* 383 */ "nmnum ::= DELETE",
 /* 384 */ "nmnum ::= DEFAULT",
 /* 385 */ "plus_num ::= PLUS number",
 /* 386 */ "plus_num ::= number",
 /* 387 */ "minus_num ::= MINUS number",
 /* 388 */ "number ::= INTEGER",
 /* 389 */ "number ::= FLOAT",
 /* 390 */ "cmd ::= CREATE temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON nm foreach_clause when_clause BEGIN trigger_cmd_list END",
 /* 391 */ "cmd ::= CREATE temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON nm foreach_clause when_clause",
 /* 392 */ "cmd ::= CREATE temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON nm foreach_clause when_clause BEGIN trigger_cmd_list",
 /* 393 */ "cmd ::= CREATE temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON ID_TAB",
 /* 394 */ "cmd ::= CREATE temp TRIGGER ifnotexists nm DOT ID_TRIG_NEW",
 /* 395 */ "cmd ::= CREATE temp TRIGGER ifnotexists ID_DB|ID_TRIG_NEW",
 /* 396 */ "trigger_time ::= BEFORE",
 /* 397 */ "trigger_time ::= AFTER",
 /* 398 */ "trigger_time ::= INSTEAD OF",
 /* 399 */ "trigger_time ::=",
 /* 400 */ "trigger_event ::= DELETE",
 /* 401 */ "trigger_event ::= INSERT",
 /* 402 */ "trigger_event ::= UPDATE",
 /* 403 */ "trigger_event ::= UPDATE OF idlist",
 /* 404 */ "foreach_clause ::=",
 /* 405 */ "foreach_clause ::= FOR EACH ROW",
 /* 406 */ "when_clause ::=",
 /* 407 */ "when_clause ::= WHEN expr",
 /* 408 */ "trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI",
 /* 409 */ "trigger_cmd_list ::= trigger_cmd SEMI",
 /* 410 */ "trigger_cmd_list ::= SEMI",
 /* 411 */ "trigger_cmd ::= update_stmt",
 /* 412 */ "trigger_cmd ::= insert_stmt",
 /* 413 */ "trigger_cmd ::= delete_stmt",
 /* 414 */ "trigger_cmd ::= select_stmt",
 /* 415 */ "raisetype ::= ROLLBACK|ABORT|FAIL",
 /* 416 */ "cmd ::= DROP TRIGGER ifexists fullname",
 /* 417 */ "cmd ::= DROP TRIGGER ifexists nm DOT ID_TRIG",
 /* 418 */ "cmd ::= DROP TRIGGER ifexists ID_DB|ID_TRIG",
 /* 419 */ "cmd ::= ATTACH database_kw_opt expr AS expr key_opt",
 /* 420 */ "cmd ::= DETACH database_kw_opt expr",
 /* 421 */ "key_opt ::=",
 /* 422 */ "key_opt ::= KEY expr",
 /* 423 */ "database_kw_opt ::= DATABASE",
 /* 424 */ "database_kw_opt ::=",
 /* 425 */ "cmd ::= REINDEX",
 /* 426 */ "cmd ::= REINDEX nm dbnm",
 /* 427 */ "cmd ::= REINDEX ID_COLLATE",
 /* 428 */ "cmd ::= REINDEX nm DOT ID_TAB|ID_IDX",
 /* 429 */ "cmd ::= REINDEX ID_DB|ID_IDX|ID_TAB",
 /* 430 */ "cmd ::= ANALYZE",
 /* 431 */ "cmd ::= ANALYZE nm dbnm",
 /* 432 */ "cmd ::= ANALYZE nm DOT ID_TAB|ID_IDX",
 /* 433 */ "cmd ::= ANALYZE ID_DB|ID_IDX|ID_TAB",
 /* 434 */ "cmd ::= ALTER TABLE fullname RENAME TO nm",
 /* 435 */ "cmd ::= ALTER TABLE fullname ADD kwcolumn_opt column",
 /* 436 */ "cmd ::= ALTER TABLE fullname DROP kwcolumn_opt nm",
 /* 437 */ "cmd ::= ALTER TABLE fullname RENAME TO ID_TAB_NEW",
 /* 438 */ "cmd ::= ALTER TABLE nm DOT ID_TAB",
 /* 439 */ "cmd ::= ALTER TABLE ID_DB|ID_TAB",
 /* 440 */ "kwcolumn_opt ::=",
 /* 441 */ "kwcolumn_opt ::= COLUMNKW",
 /* 442 */ "cmd ::= create_vtab",
 /* 443 */ "create_vtab ::= CREATE VIRTUAL TABLE ifnotexists nm dbnm USING nm",
 /* 444 */ "create_vtab ::= CREATE VIRTUAL TABLE ifnotexists nm dbnm USING nm LP vtabarglist RP",
 /* 445 */ "create_vtab ::= CREATE VIRTUAL TABLE ifnotexists nm DOT ID_TAB_NEW",
 /* 446 */ "create_vtab ::= CREATE VIRTUAL TABLE ifnotexists ID_DB|ID_TAB_NEW",
 /* 447 */ "vtabarglist ::= vtabarg",
 /* 448 */ "vtabarglist ::= vtabarglist COMMA vtabarg",
 /* 449 */ "vtabarg ::=",
 /* 450 */ "vtabarg ::= vtabarg vtabargtoken",
 /* 451 */ "vtabargtoken ::= ANY",
 /* 452 */ "vtabargtoken ::= LP anylist RP",
 /* 453 */ "anylist ::=",
 /* 454 */ "anylist ::= anylist LP anylist RP",
 /* 455 */ "anylist ::= anylist ANY",
 /* 456 */ "with ::=",
 /* 457 */ "with ::= WITH wqlist",
 /* 458 */ "with ::= WITH RECURSIVE wqlist",
 /* 459 */ "wqas ::= AS",
 /* 460 */ "wqas ::= AS MATERIALIZED",
 /* 461 */ "wqas ::= AS NOT MATERIALIZED",
 /* 462 */ "wqlist ::= wqcte",
 /* 463 */ "wqlist ::= wqlist COMMA wqcte",
 /* 464 */ "wqlist ::= ID_TAB_NEW",
 /* 465 */ "wqcte ::= nm idxlist_opt wqas LP select RP",
 /* 466 */ "windowdefn_list ::= windowdefn",
 /* 467 */ "windowdefn_list ::= windowdefn_list COMMA windowdefn",
 /* 468 */ "windowdefn ::= nm AS LP window RP",
 /* 469 */ "window ::= PARTITION BY nexprlist orderby_opt frame_opt",
 /* 470 */ "window ::= nm PARTITION BY nexprlist orderby_opt frame_opt",
 /* 471 */ "window ::= ORDER BY sortlist frame_opt",
 /* 472 */ "window ::= nm ORDER BY sortlist frame_opt",
 /* 473 */ "window ::= frame_opt",
 /* 474 */ "window ::= nm frame_opt",
 /* 475 */ "frame_opt ::=",
 /* 476 */ "frame_opt ::= range_or_rows frame_bound_s frame_exclude_opt",
 /* 477 */ "frame_opt ::= range_or_rows BETWEEN frame_bound_s AND frame_bound_e frame_exclude_opt",
 /* 478 */ "range_or_rows ::= RANGE|ROWS|GROUPS",
 /* 479 */ "frame_bound_s ::= frame_bound",
 /* 480 */ "frame_bound_s ::= UNBOUNDED PRECEDING",
 /* 481 */ "frame_bound_e ::= frame_bound",
 /* 482 */ "frame_bound_e ::= UNBOUNDED FOLLOWING",
 /* 483 */ "frame_bound ::= expr PRECEDING|FOLLOWING",
 /* 484 */ "frame_bound ::= CURRENT ROW",
 /* 485 */ "frame_exclude_opt ::=",
 /* 486 */ "frame_exclude_opt ::= EXCLUDE frame_exclude",
 /* 487 */ "frame_exclude ::= NO OTHERS",
 /* 488 */ "frame_exclude ::= CURRENT ROW",
 /* 489 */ "frame_exclude ::= GROUP",
 /* 490 */ "frame_exclude ::= TIES",
 /* 491 */ "window_clause ::= WINDOW windowdefn_list",
 /* 492 */ "filter_over ::= filter_clause over_clause",
 /* 493 */ "filter_over ::= over_clause",
 /* 494 */ "filter_over ::= filter_clause",
 /* 495 */ "over_clause ::= OVER LP window RP",
 /* 496 */ "over_clause ::= OVER nm",
 /* 497 */ "filter_clause ::= FILTER LP WHERE expr RP",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.
*/
static void yyGrowStack(yyParser *p){
  int newSize;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  if( pNew ){
    p->yystack = pNew;
    p->yystksz = newSize;
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows to %d entries!\n",
              yyTracePrompt, p->yystksz);
    }
#endif
  }
}
#endif

/*
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to sqlite3_parse and sqlite3_parseFree.
*/
void *sqlite3_parseAlloc(void *(*mallocProc)(size_t)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (size_t)sizeof(yyParser) );
  if( pParser ){
    pParser->yyidx = -1;
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyidxMax = 0;
#endif
#if YYSTACKDEPTH<=0
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    yyGrowStack(pParser);
#endif
  }
  return pParser;
}

/* The following function deletes the value associated with a
** symbol.  The symbol can be either a terminal or nonterminal.
** "yymajor" is the symbol code, and "yypminor" is a pointer to
** the value.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  sqlite3_parseARG_FETCH;
  if (parserContext->executeRules)
  {
      switch( yymajor ){
        /* Here is inserted the actions which take place when a
        ** terminal or non-terminal is destroyed.  This can happen
        ** when the symbol is popped from the stack during a
        ** reduce or during error processing or when a parser is
        ** being destroyed before it is finished parsing.
        **
        ** Note: during a reduce, the only symbols destroyed are those
        ** which appear on the RHS of the rule, but which are not used
        ** inside the C code.
        */
    case 195: /* cmd */
    case 198: /* ecmd */
    case 200: /* cmdx */
    case 248: /* select_stmt */
    case 279: /* delete_stmt */
    case 281: /* update_stmt */
    case 284: /* insert_stmt */
    case 306: /* trigger_cmd */
    case 310: /* create_vtab */
{
parser_safe_delete((yypminor->yy443));
}
      break;
    case 199: /* explain */
{
parser_safe_delete((yypminor->yy511));
}
      break;
    case 201: /* transtype */
    case 202: /* trans_opt */
{
parser_safe_delete((yypminor->yy464));
}
      break;
    case 203: /* nm */
    case 214: /* columnid */
    case 217: /* id */
    case 218: /* id_opt */
    case 219: /* ids */
    case 221: /* typename */
    case 272: /* dbnm */
    case 297: /* collate */
    case 312: /* vtabarg */
    case 313: /* vtabargtoken */
    case 314: /* anylist */
{
parser_safe_delete((yypminor->yy259));
}
      break;
    case 204: /* savepoint_opt */
    case 206: /* ifnotexists */
    case 230: /* autoinc */
    case 234: /* gen_always */
    case 240: /* tconscomma */
    case 247: /* ifexists */
    case 287: /* rp_opt */
    case 289: /* not_opt */
    case 295: /* uniqueflag */
    case 307: /* database_kw_opt */
    case 309: /* kwcolumn_opt */
{
parser_safe_delete((yypminor->yy291));
}
      break;
    case 205: /* temp */
    case 254: /* distinct */
{
parser_safe_delete((yypminor->yy346));
}
      break;
    case 207: /* fullname */
{
parser_safe_delete((yypminor->yy60));
}
      break;
    case 208: /* columnlist */
{
parser_safe_delete((yypminor->yy42));
}
      break;
    case 209: /* conslist_opt */
    case 239: /* conslist */
{
parser_safe_delete((yypminor->yy373));
}
      break;
    case 210: /* table_options */
{
parser_safe_delete((yypminor->yy533));
}
      break;
    case 211: /* select */
    case 250: /* selectnowith */
{
parser_safe_delete((yypminor->yy453));
}
      break;
    case 212: /* table_option */
{
parser_safe_delete((yypminor->yy287));
}
      break;
    case 213: /* column */
{
parser_safe_delete((yypminor->yy567));
}
      break;
    case 215: /* type */
    case 220: /* typetoken */
{
parser_safe_delete((yypminor->yy477));
}
      break;
    case 216: /* carglist */
{
parser_safe_delete((yypminor->yy131));
}
      break;
    case 222: /* signed */
    case 223: /* plus_num */
    case 224: /* minus_num */
    case 226: /* term */
    case 299: /* nmnum */
    case 300: /* number */
{
parser_safe_delete((yypminor->yy249));
}
      break;
    case 225: /* ccons */
{
parser_safe_delete((yypminor->yy604));
}
      break;
    case 227: /* expr */
    case 257: /* where_opt */
    case 259: /* having_opt */
    case 288: /* exprx */
    case 291: /* case_operand */
    case 293: /* case_else */
    case 298: /* vinto */
    case 304: /* when_clause */
    case 308: /* key_opt */
{
parser_safe_delete((yypminor->yy252));
}
      break;
    case 228: /* onconf */
    case 244: /* resolvetype */
    case 245: /* orconf */
{
parser_safe_delete((yypminor->yy478));
}
      break;
    case 229: /* sortorder */
{
parser_safe_delete((yypminor->yy389));
}
      break;
    case 231: /* idxlist_opt */
    case 242: /* idxlist */
{
parser_safe_delete((yypminor->yy123));
}
      break;
    case 232: /* refargs */
{
parser_safe_delete((yypminor->yy324));
}
      break;
    case 233: /* defer_subclause */
    case 243: /* defer_subclause_opt */
{
parser_safe_delete((yypminor->yy449));
}
      break;
    case 235: /* tnm */
{
parser_safe_delete((yypminor->yy350));
}
      break;
    case 236: /* refarg */
{
parser_safe_delete((yypminor->yy607));
}
      break;
    case 237: /* refact */
{
parser_safe_delete((yypminor->yy124));
}
      break;
    case 238: /* init_deferred_pred_opt */
{
parser_safe_delete((yypminor->yy192));
}
      break;
    case 241: /* tcons */
{
parser_safe_delete((yypminor->yy106));
}
      break;
    case 249: /* with */
{
parser_safe_delete((yypminor->yy641));
}
      break;
    case 251: /* oneselect */
{
parser_safe_delete((yypminor->yy450));
}
      break;
    case 252: /* multiselect_op */
{
parser_safe_delete((yypminor->yy382));
}
      break;
    case 253: /* values */
{
parser_safe_delete((yypminor->yy546));
}
      break;
    case 255: /* selcollist */
    case 265: /* sclp */
    case 280: /* returning */
{
parser_safe_delete((yypminor->yy633));
}
      break;
    case 256: /* from */
    case 267: /* joinsrc */
{
parser_safe_delete((yypminor->yy91));
}
      break;
    case 258: /* groupby_opt */
    case 263: /* nexprlist */
    case 264: /* exprlist */
    case 292: /* case_exprlist */
{
parser_safe_delete((yypminor->yy351));
}
      break;
    case 260: /* orderby_opt */
    case 277: /* sortlist */
{
parser_safe_delete((yypminor->yy543));
}
      break;
    case 261: /* limit_opt */
{
parser_safe_delete((yypminor->yy444));
}
      break;
    case 262: /* window_clause */
    case 318: /* windowdefn_list */
{
parser_safe_delete((yypminor->yy639));
}
      break;
    case 266: /* as */
{
parser_safe_delete((yypminor->yy460));
}
      break;
    case 268: /* singlesrc */
{
parser_safe_delete((yypminor->yy361));
}
      break;
    case 269: /* seltablist */
{
parser_safe_delete((yypminor->yy11));
}
      break;
    case 270: /* joinop */
{
parser_safe_delete((yypminor->yy521));
}
      break;
    case 271: /* joinconstr_opt */
{
parser_safe_delete((yypminor->yy335));
}
      break;
    case 273: /* indexed_opt */
    case 276: /* indexed_by */
{
parser_safe_delete((yypminor->yy312));
}
      break;
    case 274: /* idlist */
    case 283: /* idlist_opt */
    case 311: /* vtabarglist */
{
parser_safe_delete((yypminor->yy215));
}
      break;
    case 275: /* xfullname */
{
parser_safe_delete((yypminor->yy116));
}
      break;
    case 278: /* nulls */
{
parser_safe_delete((yypminor->yy99));
}
      break;
    case 282: /* setlist */
{
parser_safe_delete((yypminor->yy321));
}
      break;
    case 285: /* insert_cmd */
{
parser_safe_delete((yypminor->yy584));
}
      break;
    case 286: /* upsert */
{
parser_safe_delete((yypminor->yy500));
}
      break;
    case 290: /* likeop */
{
parser_safe_delete((yypminor->yy100));
}
      break;
    case 294: /* filter_over */
{
parser_safe_delete((yypminor->yy247));
}
      break;
    case 296: /* idxlist_single */
{
parser_safe_delete((yypminor->yy608));
}
      break;
    case 301: /* trigger_time */
{
parser_safe_delete((yypminor->yy372));
}
      break;
    case 302: /* trigger_event */
{
parser_safe_delete((yypminor->yy331));
}
      break;
    case 303: /* foreach_clause */
{
parser_safe_delete((yypminor->yy323));
}
      break;
    case 305: /* trigger_cmd_list */
{
parser_safe_delete((yypminor->yy330));
}
      break;
    case 315: /* wqlist */
{
parser_safe_delete((yypminor->yy332));
}
      break;
    case 316: /* wqas */
{
parser_safe_delete((yypminor->yy640));
}
      break;
    case 317: /* wqcte */
{
parser_safe_delete((yypminor->yy446));
}
      break;
    case 319: /* windowdefn */
{
parser_safe_delete((yypminor->yy646));
}
      break;
    case 320: /* window */
{
parser_safe_delete((yypminor->yy234));
}
      break;
    case 321: /* frame_opt */
{
parser_safe_delete((yypminor->yy41));
}
      break;
    case 322: /* range_or_rows */
{
parser_safe_delete((yypminor->yy358));
}
      break;
    case 323: /* frame_bound_s */
    case 325: /* frame_bound_e */
{
parser_safe_delete((yypminor->yy81));
}
      break;
    case 326: /* frame_bound */
{
parser_safe_delete((yypminor->yy81));parser_safe_delete((yypminor->yy81));parser_safe_delete((yypminor->yy81));
}
      break;
    case 328: /* filter_clause */
{
parser_safe_delete((yypminor->yy657));
}
      break;
    case 329: /* over_clause */
{
parser_safe_delete((yypminor->yy288));
}
      break;
        default:  break;   /* If no destructor action specified: do nothing */
      }
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
**
** Return the major token number for the symbol popped.
*/
static int yy_pop_parser_stack(yyParser *pParser){
  YYCODETYPE yymajor;
  yyStackEntry *yytos = &pParser->yystack[pParser->yyidx];

  /* There is no mechanism by which the parser stack can be popped below
  ** empty in SQLite.  */
  if( pParser->yyidx<0 ) return 0;
#ifndef NDEBUG
  if( yyTraceFILE && pParser->yyidx>=0 ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yymajor = yytos->major;
  yy_destructor(pParser, yymajor, &yytos->minor);
  delete yytos->tokens;
  yytos->tokens = nullptr;
  pParser->yyidx--;
  return yymajor;
}

/*
** Deallocate and destroy a parser.  Destructors are all called for
** all stack elements before shutting the parser down.
**
** Inputs:
** <ul>
** <li>  A pointer to the parser.  This should be a pointer
**       obtained from sqlite3_parseAlloc.
** <li>  A pointer to a function used to reclaim memory obtained
**       from malloc.
** </ul>
*/
void sqlite3_parseFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
  /* In SQLite, we never try to destroy a parser that was not successfully
  ** created in the first place. */
  if( pParser==0 ) return;
  while( pParser->yyidx>=0 ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int sqlite3_parseStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyidxMax;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yystack[pParser->yyidx].stateno;
  GET_CONTEXT;

  if( stateno>YY_SHIFT_COUNT
   || (i = yy_shift_ofst[stateno])==YY_SHIFT_USE_DFLT ){
    return yy_default[stateno];
  }
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    if( iLookAhead>0 ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0
             && parserContext->doFallbacks ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        return yy_find_shift_action(pParser, iFallback);
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if(
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
    }
    return yy_default[stateno];
  }else{
    return yy_action[i];
  }
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser, YYMINORTYPE *yypMinor){
   UNUSED(yypMinor);
   sqlite3_parseARG_FETCH;
   yypParser->yyidx--;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */

    parserContext->error(QObject::tr("Parser stack overflow"));
   sqlite3_parseARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  YYMINORTYPE *yypMinor         /* Pointer to the minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yyidx++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( yypParser->yyidx>yypParser->yyidxMax ){
    yypParser->yyidxMax = yypParser->yyidx;
  }
#endif
#if YYSTACKDEPTH>0
  if( yypParser->yyidx>=YYSTACKDEPTH ){
    yyStackOverflow(yypParser, yypMinor);
    return;
  }
#else
  if( yypParser->yyidx>=yypParser->yystksz ){
    yyGrowStack(yypParser);
    if( yypParser->yyidx>=yypParser->yystksz ){
      yyStackOverflow(yypParser, yypMinor);
      return;
    }
  }
#endif
  yytos = &yypParser->yystack[yypParser->yyidx];
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor = *yypMinor;
  yytos->tokens = new QList<Token*>();
#ifndef NDEBUG
  if( yyTraceFILE && yypParser->yyidx>0 ){
    int i;
    fprintf(yyTraceFILE,"%sShift %d\n",yyTracePrompt,yyNewState);
    fprintf(yyTraceFILE,"%sStack:",yyTracePrompt);
    for(i=1; i<=yypParser->yyidx; i++)
      fprintf(yyTraceFILE," %s",yyTokenName[yypParser->yystack[i].major]);
    fprintf(yyTraceFILE,"\n");
  }
#endif
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 196, 1 },
  { 197, 2 },
  { 197, 1 },
  { 198, 1 },
  { 198, 3 },
  { 199, 0 },
  { 199, 1 },
  { 199, 3 },
  { 200, 1 },
  { 195, 3 },
  { 202, 0 },
  { 202, 1 },
  { 202, 2 },
  { 202, 2 },
  { 201, 0 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 195, 2 },
  { 195, 2 },
  { 195, 2 },
  { 204, 1 },
  { 204, 0 },
  { 195, 2 },
  { 195, 3 },
  { 195, 5 },
  { 195, 2 },
  { 195, 3 },
  { 195, 5 },
  { 195, 10 },
  { 195, 7 },
  { 195, 7 },
  { 195, 5 },
  { 210, 0 },
  { 210, 1 },
  { 210, 3 },
  { 212, 2 },
  { 212, 1 },
  { 212, 2 },
  { 212, 1 },
  { 206, 0 },
  { 206, 3 },
  { 205, 1 },
  { 205, 0 },
  { 208, 3 },
  { 208, 1 },
  { 213, 3 },
  { 214, 1 },
  { 214, 1 },
  { 217, 1 },
  { 218, 1 },
  { 218, 0 },
  { 219, 1 },
  { 203, 1 },
  { 203, 1 },
  { 203, 1 },
  { 215, 0 },
  { 215, 1 },
  { 220, 1 },
  { 220, 4 },
  { 220, 6 },
  { 221, 1 },
  { 221, 2 },
  { 221, 1 },
  { 222, 1 },
  { 222, 1 },
  { 216, 2 },
  { 216, 0 },
  { 225, 2 },
  { 225, 2 },
  { 225, 4 },
  { 225, 3 },
  { 225, 3 },
  { 225, 2 },
  { 225, 2 },
  { 225, 2 },
  { 225, 3 },
  { 225, 5 },
  { 225, 2 },
  { 225, 4 },
  { 225, 4 },
  { 225, 1 },
  { 225, 2 },
  { 225, 6 },
  { 225, 2 },
  { 225, 2 },
  { 225, 2 },
  { 225, 3 },
  { 226, 1 },
  { 226, 1 },
  { 226, 1 },
  { 226, 1 },
  { 235, 1 },
  { 235, 1 },
  { 234, 2 },
  { 234, 0 },
  { 230, 0 },
  { 230, 1 },
  { 232, 0 },
  { 232, 2 },
  { 236, 2 },
  { 236, 3 },
  { 236, 3 },
  { 236, 3 },
  { 236, 2 },
  { 237, 2 },
  { 237, 2 },
  { 237, 1 },
  { 237, 1 },
  { 237, 2 },
  { 233, 3 },
  { 233, 2 },
  { 238, 0 },
  { 238, 2 },
  { 238, 2 },
  { 209, 0 },
  { 209, 2 },
  { 239, 3 },
  { 239, 1 },
  { 240, 1 },
  { 240, 0 },
  { 241, 2 },
  { 241, 7 },
  { 241, 5 },
  { 241, 5 },
  { 241, 10 },
  { 241, 2 },
  { 241, 7 },
  { 241, 4 },
  { 243, 0 },
  { 243, 1 },
  { 228, 0 },
  { 228, 3 },
  { 245, 0 },
  { 245, 2 },
  { 244, 1 },
  { 244, 1 },
  { 244, 1 },
  { 195, 4 },
  { 195, 6 },
  { 195, 4 },
  { 247, 2 },
  { 247, 0 },
  { 195, 8 },
  { 195, 7 },
  { 195, 5 },
  { 195, 4 },
  { 195, 6 },
  { 195, 4 },
  { 195, 1 },
  { 248, 1 },
  { 211, 2 },
  { 250, 1 },
  { 250, 3 },
  { 250, 1 },
  { 250, 3 },
  { 251, 9 },
  { 251, 10 },
  { 253, 4 },
  { 253, 5 },
  { 252, 1 },
  { 252, 2 },
  { 252, 1 },
  { 252, 1 },
  { 254, 1 },
  { 254, 1 },
  { 254, 0 },
  { 265, 2 },
  { 265, 0 },
  { 255, 3 },
  { 255, 2 },
  { 255, 4 },
  { 255, 1 },
  { 255, 4 },
  { 266, 2 },
  { 266, 1 },
  { 266, 2 },
  { 266, 1 },
  { 266, 0 },
  { 256, 0 },
  { 256, 2 },
  { 267, 2 },
  { 267, 0 },
  { 269, 4 },
  { 269, 0 },
  { 268, 4 },
  { 268, 4 },
  { 268, 4 },
  { 268, 6 },
  { 268, 0 },
  { 268, 2 },
  { 268, 3 },
  { 268, 1 },
  { 268, 3 },
  { 268, 1 },
  { 271, 2 },
  { 271, 4 },
  { 271, 0 },
  { 272, 0 },
  { 272, 2 },
  { 207, 1 },
  { 207, 3 },
  { 275, 1 },
  { 275, 3 },
  { 275, 5 },
  { 275, 3 },
  { 275, 5 },
  { 275, 3 },
  { 270, 1 },
  { 270, 1 },
  { 270, 2 },
  { 270, 3 },
  { 270, 4 },
  { 270, 1 },
  { 273, 0 },
  { 273, 1 },
  { 276, 3 },
  { 276, 2 },
  { 276, 3 },
  { 260, 0 },
  { 260, 3 },
  { 277, 5 },
  { 277, 3 },
  { 229, 1 },
  { 229, 1 },
  { 229, 0 },
  { 278, 2 },
  { 278, 2 },
  { 278, 0 },
  { 258, 0 },
  { 258, 3 },
  { 258, 2 },
  { 259, 0 },
  { 259, 2 },
  { 261, 0 },
  { 261, 2 },
  { 261, 4 },
  { 261, 4 },
  { 195, 1 },
  { 279, 9 },
  { 279, 3 },
  { 279, 5 },
  { 279, 6 },
  { 279, 4 },
  { 257, 0 },
  { 257, 2 },
  { 257, 1 },
  { 280, 0 },
  { 280, 2 },
  { 195, 1 },
  { 281, 12 },
  { 281, 3 },
  { 281, 5 },
  { 281, 6 },
  { 281, 4 },
  { 282, 5 },
  { 282, 7 },
  { 282, 3 },
  { 282, 5 },
  { 282, 0 },
  { 282, 2 },
  { 282, 3 },
  { 282, 1 },
  { 283, 0 },
  { 283, 3 },
  { 274, 3 },
  { 274, 1 },
  { 274, 0 },
  { 274, 3 },
  { 274, 1 },
  { 195, 1 },
  { 284, 8 },
  { 284, 8 },
  { 284, 7 },
  { 284, 3 },
  { 284, 5 },
  { 284, 4 },
  { 284, 6 },
  { 285, 2 },
  { 285, 1 },
  { 286, 0 },
  { 286, 11 },
  { 286, 8 },
  { 286, 4 },
  { 288, 4 },
  { 288, 6 },
  { 288, 1 },
  { 288, 3 },
  { 288, 5 },
  { 288, 3 },
  { 288, 6 },
  { 288, 1 },
  { 288, 3 },
  { 288, 1 },
  { 288, 3 },
  { 288, 2 },
  { 288, 5 },
  { 288, 4 },
  { 288, 1 },
  { 288, 3 },
  { 288, 6 },
  { 288, 5 },
  { 288, 4 },
  { 288, 3 },
  { 288, 3 },
  { 288, 3 },
  { 288, 3 },
  { 288, 3 },
  { 288, 3 },
  { 288, 3 },
  { 288, 3 },
  { 288, 4 },
  { 288, 6 },
  { 288, 2 },
  { 288, 3 },
  { 288, 4 },
  { 288, 6 },
  { 288, 5 },
  { 288, 2 },
  { 288, 2 },
  { 288, 2 },
  { 288, 2 },
  { 288, 3 },
  { 288, 6 },
  { 288, 6 },
  { 288, 3 },
  { 288, 6 },
  { 288, 5 },
  { 288, 4 },
  { 288, 5 },
  { 288, 4 },
  { 288, 6 },
  { 288, 6 },
  { 288, 5 },
  { 227, 0 },
  { 227, 1 },
  { 289, 0 },
  { 289, 1 },
  { 287, 0 },
  { 287, 1 },
  { 290, 1 },
  { 292, 5 },
  { 292, 4 },
  { 293, 2 },
  { 293, 0 },
  { 291, 1 },
  { 291, 0 },
  { 264, 1 },
  { 264, 0 },
  { 263, 3 },
  { 263, 1 },
  { 195, 12 },
  { 195, 8 },
  { 195, 7 },
  { 195, 5 },
  { 295, 1 },
  { 295, 0 },
  { 231, 0 },
  { 231, 3 },
  { 242, 3 },
  { 242, 1 },
  { 296, 3 },
  { 296, 1 },
  { 297, 0 },
  { 297, 2 },
  { 297, 2 },
  { 195, 4 },
  { 195, 6 },
  { 195, 4 },
  { 195, 2 },
  { 195, 3 },
  { 298, 2 },
  { 298, 0 },
  { 195, 3 },
  { 195, 5 },
  { 195, 6 },
  { 195, 5 },
  { 195, 6 },
  { 195, 4 },
  { 195, 2 },
  { 299, 1 },
  { 299, 1 },
  { 299, 1 },
  { 299, 1 },
  { 299, 1 },
  { 223, 2 },
  { 223, 1 },
  { 224, 2 },
  { 300, 1 },
  { 300, 1 },
  { 195, 15 },
  { 195, 12 },
  { 195, 14 },
  { 195, 10 },
  { 195, 7 },
  { 195, 5 },
  { 301, 1 },
  { 301, 1 },
  { 301, 2 },
  { 301, 0 },
  { 302, 1 },
  { 302, 1 },
  { 302, 1 },
  { 302, 3 },
  { 303, 0 },
  { 303, 3 },
  { 304, 0 },
  { 304, 2 },
  { 305, 3 },
  { 305, 2 },
  { 305, 1 },
  { 306, 1 },
  { 306, 1 },
  { 306, 1 },
  { 306, 1 },
  { 246, 1 },
  { 195, 4 },
  { 195, 6 },
  { 195, 4 },
  { 195, 6 },
  { 195, 3 },
  { 308, 0 },
  { 308, 2 },
  { 307, 1 },
  { 307, 0 },
  { 195, 1 },
  { 195, 3 },
  { 195, 2 },
  { 195, 4 },
  { 195, 2 },
  { 195, 1 },
  { 195, 3 },
  { 195, 4 },
  { 195, 2 },
  { 195, 6 },
  { 195, 6 },
  { 195, 6 },
  { 195, 6 },
  { 195, 5 },
  { 195, 3 },
  { 309, 0 },
  { 309, 1 },
  { 195, 1 },
  { 310, 8 },
  { 310, 11 },
  { 310, 7 },
  { 310, 5 },
  { 311, 1 },
  { 311, 3 },
  { 312, 0 },
  { 312, 2 },
  { 313, 1 },
  { 313, 3 },
  { 314, 0 },
  { 314, 4 },
  { 314, 2 },
  { 249, 0 },
  { 249, 2 },
  { 249, 3 },
  { 316, 1 },
  { 316, 2 },
  { 316, 3 },
  { 315, 1 },
  { 315, 3 },
  { 315, 1 },
  { 317, 6 },
  { 318, 1 },
  { 318, 3 },
  { 319, 5 },
  { 320, 5 },
  { 320, 6 },
  { 320, 4 },
  { 320, 5 },
  { 320, 1 },
  { 320, 2 },
  { 321, 0 },
  { 321, 3 },
  { 321, 6 },
  { 322, 1 },
  { 323, 1 },
  { 323, 2 },
  { 325, 1 },
  { 325, 2 },
  { 326, 2 },
  { 326, 2 },
  { 324, 0 },
  { 324, 2 },
  { 327, 2 },
  { 327, 2 },
  { 327, 1 },
  { 327, 1 },
  { 262, 2 },
  { 294, 2 },
  { 294, 1 },
  { 294, 1 },
  { 329, 4 },
  { 329, 2 },
  { 328, 5 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  int yyruleno                 /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  YYMINORTYPE yygotominor;        /* The LHS of the rule reduced */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  sqlite3_parseARG_FETCH;
  SqliteStatement* objectForTokens = 0;
  QStringList noTokenInheritanceFields;
  yymsp = &yypParser->yystack[yypParser->yyidx];
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno>=0
        && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    fprintf(yyTraceFILE, "%sReduce [%s].\n", yyTracePrompt,
      yyRuleName[yyruleno]);
  }
#endif /* NDEBUG */

  /* Silence complaints from purify about yygotominor being uninitialized
  ** in some cases when it is copied into the stack after the following
  ** switch.  yygotominor is uninitialized when a rule reduces that does
  ** not set the value of its left-hand side nonterminal.  Leaving the
  ** value of the nonterminal uninitialized is utterly harmless as long
  ** as the value is never used.  So really the only thing this code
  ** accomplishes is to quieten purify.
  **
  ** 2007-01-16:  The wireshark project (www.wireshark.org) reports that
  ** without this code, their parser segfaults.  I'm not sure what there
  ** parser is doing to make this happen.  This is the second bug report
  ** from wireshark this week.  Clearly they are stressing Lemon in ways
  ** that it has not been previously stressed...  (SQLite ticket #2172)
  */
  /*memset(&yygotominor, 0, sizeof(yygotominor));*/
  yygotominor = yyzerominor;


  if (parserContext->executeRules)
  {
      switch( yyruleno ){
      /* Beginning here are the reduction cases.  A typical example
      ** follows:
      **   case 0:
      **  #line <lineno> <grammarfile>
      **     { ... }           // User supplied code
      **  #line <lineno> <thisfile>
      **     break;
      */
      case 1: /* cmdlist ::= cmdlist ecmd */
{parserContext->addQuery(yymsp[0].minor.yy443); DONT_INHERIT_TOKENS("cmdlist");}
        break;
      case 2: /* cmdlist ::= ecmd */
{parserContext->addQuery(yymsp[0].minor.yy443);}
        break;
      case 3: /* ecmd ::= SEMI */
{yygotominor.yy443 = new SqliteEmptyQuery();}
        break;
      case 4: /* ecmd ::= explain cmdx SEMI */
{
                                                yygotominor.yy443 = yymsp[-1].minor.yy443;
                                                yygotominor.yy443->explain = yymsp[-2].minor.yy511->explain;
                                                yygotominor.yy443->queryPlan = yymsp[-2].minor.yy511->queryPlan;
                                                delete yymsp[-2].minor.yy511;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 5: /* explain ::= */
{yygotominor.yy511 = new ParserStubExplain(false, false);}
        break;
      case 6: /* explain ::= EXPLAIN */
{yygotominor.yy511 = new ParserStubExplain(true, false);}
        break;
      case 7: /* explain ::= EXPLAIN QUERY PLAN */
{yygotominor.yy511 = new ParserStubExplain(true, true);}
        break;
      case 8: /* cmdx ::= cmd */
      case 411: /* trigger_cmd ::= update_stmt */ yytestcase(yyruleno==411);
      case 412: /* trigger_cmd ::= insert_stmt */ yytestcase(yyruleno==412);
      case 413: /* trigger_cmd ::= delete_stmt */ yytestcase(yyruleno==413);
      case 414: /* trigger_cmd ::= select_stmt */ yytestcase(yyruleno==414);
      case 442: /* cmd ::= create_vtab */ yytestcase(yyruleno==442);
{yygotominor.yy443 = yymsp[0].minor.yy443;}
        break;
      case 9: /* cmd ::= BEGIN transtype trans_opt */
{
                                                yygotominor.yy443 = new SqliteBeginTrans(
                                                        yymsp[-1].minor.yy464->type,
                                                        yymsp[0].minor.yy464->transactionKw,
                                                        yymsp[0].minor.yy464->name
                                                    );
                                                delete yymsp[0].minor.yy464;
                                                delete yymsp[-1].minor.yy464;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 10: /* trans_opt ::= */
      case 14: /* transtype ::= */ yytestcase(yyruleno==14);
{yygotominor.yy464 = new ParserStubTransDetails();}
        break;
      case 11: /* trans_opt ::= TRANSACTION */
{
                                                yygotominor.yy464 = new ParserStubTransDetails();
                                                yygotominor.yy464->transactionKw = true;
                                            }
        break;
      case 12: /* trans_opt ::= TRANSACTION nm */
      case 13: /* trans_opt ::= TRANSACTION ID_TRANS */ yytestcase(yyruleno==13);
{
                                                yygotominor.yy464 = new ParserStubTransDetails();
                                                yygotominor.yy464->transactionKw = true;
                                                yygotominor.yy464->name = *(yymsp[0].minor.yy259);
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 15: /* transtype ::= DEFERRED */
{
                                                yygotominor.yy464 = new ParserStubTransDetails();
                                                yygotominor.yy464->type = SqliteBeginTrans::Type::DEFERRED;
                                            }
        break;
      case 16: /* transtype ::= IMMEDIATE */
{
                                                yygotominor.yy464 = new ParserStubTransDetails();
                                                yygotominor.yy464->type = SqliteBeginTrans::Type::IMMEDIATE;
                                            }
        break;
      case 17: /* transtype ::= EXCLUSIVE */
{
                                                yygotominor.yy464 = new ParserStubTransDetails();
                                                yygotominor.yy464->type = SqliteBeginTrans::Type::EXCLUSIVE;
                                            }
        break;
      case 18: /* cmd ::= COMMIT trans_opt */
{
                                                yygotominor.yy443 = new SqliteCommitTrans(
                                                        yymsp[0].minor.yy464->transactionKw,
                                                        yymsp[0].minor.yy464->name,
                                                        false
                                                    );
                                                delete yymsp[0].minor.yy464;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 19: /* cmd ::= END trans_opt */
{
                                                yygotominor.yy443 = new SqliteCommitTrans(
                                                        yymsp[0].minor.yy464->transactionKw,
                                                        yymsp[0].minor.yy464->name,
                                                        true
                                                    );
                                                delete yymsp[0].minor.yy464;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 20: /* cmd ::= ROLLBACK trans_opt */
{
                                                yygotominor.yy443 = new SqliteRollback(
                                                        yymsp[0].minor.yy464->transactionKw,
                                                        yymsp[0].minor.yy464->name
                                                    );
                                                delete yymsp[0].minor.yy464;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 21: /* savepoint_opt ::= SAVEPOINT */
      case 41: /* ifnotexists ::= IF NOT EXISTS */ yytestcase(yyruleno==41);
      case 94: /* gen_always ::= GENERATED ALWAYS */ yytestcase(yyruleno==94);
      case 97: /* autoinc ::= AUTOINCR */ yytestcase(yyruleno==97);
      case 119: /* tconscomma ::= COMMA */ yytestcase(yyruleno==119);
      case 141: /* ifexists ::= IF EXISTS */ yytestcase(yyruleno==141);
      case 337: /* not_opt ::= NOT */ yytestcase(yyruleno==337);
      case 339: /* rp_opt ::= RP */ yytestcase(yyruleno==339);
      case 355: /* uniqueflag ::= UNIQUE */ yytestcase(yyruleno==355);
      case 423: /* database_kw_opt ::= DATABASE */ yytestcase(yyruleno==423);
      case 440: /* kwcolumn_opt ::= */ yytestcase(yyruleno==440);
{yygotominor.yy291 = new bool(true);}
        break;
      case 22: /* savepoint_opt ::= */
      case 40: /* ifnotexists ::= */ yytestcase(yyruleno==40);
      case 95: /* gen_always ::= */ yytestcase(yyruleno==95);
      case 96: /* autoinc ::= */ yytestcase(yyruleno==96);
      case 120: /* tconscomma ::= */ yytestcase(yyruleno==120);
      case 142: /* ifexists ::= */ yytestcase(yyruleno==142);
      case 336: /* not_opt ::= */ yytestcase(yyruleno==336);
      case 338: /* rp_opt ::= */ yytestcase(yyruleno==338);
      case 356: /* uniqueflag ::= */ yytestcase(yyruleno==356);
      case 424: /* database_kw_opt ::= */ yytestcase(yyruleno==424);
      case 441: /* kwcolumn_opt ::= COLUMNKW */ yytestcase(yyruleno==441);
{yygotominor.yy291 = new bool(false);}
        break;
      case 23: /* cmd ::= SAVEPOINT nm */
{
                                                yygotominor.yy443 = new SqliteSavepoint(*(yymsp[0].minor.yy259));
                                                delete yymsp[0].minor.yy259;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 24: /* cmd ::= RELEASE savepoint_opt nm */
{
                                                yygotominor.yy443 = new SqliteRelease(*(yymsp[-1].minor.yy291), *(yymsp[0].minor.yy259));
                                                delete yymsp[0].minor.yy259;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 25: /* cmd ::= ROLLBACK trans_opt TO savepoint_opt nm */
      case 26: /* cmd ::= SAVEPOINT ID_TRANS */ yytestcase(yyruleno==26);
{
                                                yygotominor.yy443 = new SqliteRollback(
                                                        yymsp[-3].minor.yy464->transactionKw,
                                                        *(yymsp[-1].minor.yy291),
                                                        *(yymsp[0].minor.yy259)
                                                    );
                                                delete yymsp[-1].minor.yy291;
                                                delete yymsp[-3].minor.yy464;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 27: /* cmd ::= RELEASE savepoint_opt ID_TRANS */
      case 28: /* cmd ::= ROLLBACK trans_opt TO savepoint_opt ID_TRANS */ yytestcase(yyruleno==28);
{  yy_destructor(yypParser,204,&yymsp[-1].minor);
}
        break;
      case 29: /* cmd ::= CREATE temp TABLE ifnotexists fullname LP columnlist conslist_opt RP table_options */
{
                                                yygotominor.yy443 = new SqliteCreateTable(
                                                        *(yymsp[-6].minor.yy291),
                                                        *(yymsp[-8].minor.yy346),
                                                        yymsp[-5].minor.yy60->name1,
                                                        yymsp[-5].minor.yy60->name2,
                                                        *(yymsp[-3].minor.yy42),
                                                        *(yymsp[-2].minor.yy373),
                                                        *(yymsp[0].minor.yy533)
                                                    );
                                                delete yymsp[-6].minor.yy291;
                                                delete yymsp[-8].minor.yy346;
                                                delete yymsp[-3].minor.yy42;
                                                delete yymsp[-2].minor.yy373;
                                                delete yymsp[-5].minor.yy60;
                                                delete yymsp[0].minor.yy533;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 30: /* cmd ::= CREATE temp TABLE ifnotexists fullname AS select */
{
                                                yygotominor.yy443 = new SqliteCreateTable(
                                                        *(yymsp[-3].minor.yy291),
                                                        *(yymsp[-5].minor.yy346),
                                                        yymsp[-2].minor.yy60->name1,
                                                        yymsp[-2].minor.yy60->name2,
                                                        yymsp[0].minor.yy453
                                                    );
                                                delete yymsp[-3].minor.yy291;
                                                delete yymsp[-5].minor.yy346;
                                                delete yymsp[-2].minor.yy60;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 31: /* cmd ::= CREATE temp TABLE ifnotexists nm DOT ID_TAB_NEW */
      case 144: /* cmd ::= CREATE temp VIEW ifnotexists nm DOT ID_VIEW_NEW */ yytestcase(yyruleno==144);
      case 394: /* cmd ::= CREATE temp TRIGGER ifnotexists nm DOT ID_TRIG_NEW */ yytestcase(yyruleno==394);
{  yy_destructor(yypParser,205,&yymsp[-5].minor);
  yy_destructor(yypParser,203,&yymsp[-2].minor);
}
        break;
      case 32: /* cmd ::= CREATE temp TABLE ifnotexists ID_DB|ID_TAB_NEW */
      case 145: /* cmd ::= CREATE temp VIEW ifnotexists ID_DB|ID_VIEW_NEW */ yytestcase(yyruleno==145);
      case 395: /* cmd ::= CREATE temp TRIGGER ifnotexists ID_DB|ID_TRIG_NEW */ yytestcase(yyruleno==395);
{  yy_destructor(yypParser,205,&yymsp[-3].minor);
}
        break;
      case 33: /* table_options ::= */
{yygotominor.yy533 = new ParserCreateTableOptionList();}
        break;
      case 34: /* table_options ::= table_option */
{
                                                yygotominor.yy533 = new ParserCreateTableOptionList();
                                                yygotominor.yy533->append(yymsp[0].minor.yy287);
                                            }
        break;
      case 35: /* table_options ::= table_options COMMA table_option */
{
                                                yymsp[-2].minor.yy533->append(yymsp[0].minor.yy287);
                                                yygotominor.yy533 = yymsp[-2].minor.yy533;
                                                DONT_INHERIT_TOKENS("table_options");
                                            }
        break;
      case 36: /* table_option ::= WITHOUT nm */
{
                                                if (yymsp[0].minor.yy259->toLower() != "rowid")
                                                    parserContext->errorAtToken(QString("Invalid table option: %1").arg(*(yymsp[0].minor.yy259)));

                                                yygotominor.yy287 = new ParserStubCreateTableOption(ParserStubCreateTableOption::WITHOUT_ROWID);
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 37: /* table_option ::= nm */
      case 38: /* table_option ::= WITHOUT CTX_ROWID_KW */ yytestcase(yyruleno==38);
      case 39: /* table_option ::= CTX_STRICT_KW */ yytestcase(yyruleno==39);
{
                                                if (yymsp[0].minor.yy259->toLower() != "strict")
                                                    parserContext->errorAtToken(QString("Invalid table option: %1").arg(*(yymsp[0].minor.yy259)));

                                                yygotominor.yy287 = new ParserStubCreateTableOption(ParserStubCreateTableOption::STRICT);
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 42: /* temp ::= TEMP */
{yygotominor.yy346 = new int( (yymsp[0].minor.yy0->value.length() > 4) ? 2 : 1 );}
        break;
      case 43: /* temp ::= */
      case 166: /* distinct ::= */ yytestcase(yyruleno==166);
{yygotominor.yy346 = new int(0);}
        break;
      case 44: /* columnlist ::= columnlist COMMA column */
{
                                                yymsp[-2].minor.yy42->append(yymsp[0].minor.yy567);
                                                yygotominor.yy42 = yymsp[-2].minor.yy42;
                                                DONT_INHERIT_TOKENS("columnlist");
                                            }
        break;
      case 45: /* columnlist ::= column */
{
                                                yygotominor.yy42 = new ParserCreateTableColumnList();
                                                yygotominor.yy42->append(yymsp[0].minor.yy567);
                                            }
        break;
      case 46: /* column ::= columnid type carglist */
{
                                                yygotominor.yy567 = new SqliteCreateTable::Column(*(yymsp[-2].minor.yy259), yymsp[-1].minor.yy477, *(yymsp[0].minor.yy131));
                                                delete yymsp[-2].minor.yy259;
                                                delete yymsp[0].minor.yy131;
                                                objectForTokens = yygotominor.yy567;
                                            }
        break;
      case 47: /* columnid ::= nm */
      case 48: /* columnid ::= ID_COL_NEW */ yytestcase(yyruleno==48);
      case 53: /* nm ::= id */ yytestcase(yyruleno==53);
      case 61: /* typename ::= ids */ yytestcase(yyruleno==61);
      case 199: /* dbnm ::= DOT nm */ yytestcase(yyruleno==199);
      case 364: /* collate ::= COLLATE ids */ yytestcase(yyruleno==364);
      case 365: /* collate ::= COLLATE ID_COLLATE */ yytestcase(yyruleno==365);
{yygotominor.yy259 = yymsp[0].minor.yy259;}
        break;
      case 49: /* id ::= ID|INDEXED */
{
                                                yygotominor.yy259 = new QString(
                                                    stripObjName(
                                                        yymsp[0].minor.yy0->value
                                                    )
                                                );
                                            }
        break;
      case 50: /* id_opt ::= id */
{
                                                yygotominor.yy259 = yymsp[0].minor.yy259;
                                            }
        break;
      case 51: /* id_opt ::= */
{
                                                yygotominor.yy259 = new QString();
                                            }
        break;
      case 52: /* ids ::= ID|STRING */
      case 55: /* nm ::= JOIN_KW */ yytestcase(yyruleno==55);
{yygotominor.yy259 = new QString(yymsp[0].minor.yy0->value);}
        break;
      case 54: /* nm ::= STRING */
{yygotominor.yy259 = new QString(stripString(yymsp[0].minor.yy0->value));}
        break;
      case 56: /* type ::= */
{yygotominor.yy477 = nullptr;}
        break;
      case 57: /* type ::= typetoken */
{yygotominor.yy477 = yymsp[0].minor.yy477;}
        break;
      case 58: /* typetoken ::= typename */
{
                                                yygotominor.yy477 = new SqliteColumnType(*(yymsp[0].minor.yy259));
                                                delete yymsp[0].minor.yy259;
                                                objectForTokens = yygotominor.yy477;
                                            }
        break;
      case 59: /* typetoken ::= typename LP signed RP */
{
                                                yygotominor.yy477 = new SqliteColumnType(*(yymsp[-3].minor.yy259), *(yymsp[-1].minor.yy249));
                                                delete yymsp[-3].minor.yy259;
                                                delete yymsp[-1].minor.yy249;
                                                objectForTokens = yygotominor.yy477;
                                            }
        break;
      case 60: /* typetoken ::= typename LP signed COMMA signed RP */
{
                                                yygotominor.yy477 = new SqliteColumnType(*(yymsp[-5].minor.yy259), *(yymsp[-3].minor.yy249), *(yymsp[-1].minor.yy249));
                                                delete yymsp[-5].minor.yy259;
                                                delete yymsp[-3].minor.yy249;
                                                delete yymsp[-1].minor.yy249;
                                                objectForTokens = yygotominor.yy477;
                                            }
        break;
      case 62: /* typename ::= typename ids */
      case 63: /* typename ::= ID_COL_TYPE */ yytestcase(yyruleno==63);
{
                                                yymsp[-1].minor.yy259->append(" " + *(yymsp[0].minor.yy259));
                                                delete yymsp[0].minor.yy259;
                                                yygotominor.yy259 = yymsp[-1].minor.yy259;
                                            }
        break;
      case 64: /* signed ::= plus_num */
      case 65: /* signed ::= minus_num */ yytestcase(yyruleno==65);
      case 380: /* nmnum ::= plus_num */ yytestcase(yyruleno==380);
      case 385: /* plus_num ::= PLUS number */ yytestcase(yyruleno==385);
      case 386: /* plus_num ::= number */ yytestcase(yyruleno==386);
{yygotominor.yy249 = yymsp[0].minor.yy249;}
        break;
      case 66: /* carglist ::= carglist ccons */
{
                                                yymsp[-1].minor.yy131->append(yymsp[0].minor.yy604);
                                                yygotominor.yy131 = yymsp[-1].minor.yy131;
                                                DONT_INHERIT_TOKENS("carglist");
                                            }
        break;
      case 67: /* carglist ::= */
{yygotominor.yy131 = new ParserCreateTableColumnConstraintList();}
        break;
      case 68: /* ccons ::= CONSTRAINT nm */
{
                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy604->initDefNameOnly(*(yymsp[0].minor.yy259));
                                                delete yymsp[0].minor.yy259;
                                                objectForTokens = yygotominor.yy604;
                                            }
        break;
      case 69: /* ccons ::= DEFAULT term */
{
                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy604->initDefTerm(*(yymsp[0].minor.yy249));
                                                delete yymsp[0].minor.yy249;
                                                objectForTokens = yygotominor.yy604;
                                            }
        break;
      case 70: /* ccons ::= DEFAULT LP expr RP */
{
                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy604->initDefExpr(yymsp[-1].minor.yy252);
                                                objectForTokens = yygotominor.yy604;
                                            }
        break;
      case 71: /* ccons ::= DEFAULT PLUS term */
{
                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy604->initDefTerm(*(yymsp[0].minor.yy249), false);
                                                delete yymsp[0].minor.yy249;
                                                objectForTokens = yygotominor.yy604;
                                            }
        break;
      case 72: /* ccons ::= DEFAULT MINUS term */
{
                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy604->initDefTerm(*(yymsp[0].minor.yy249), true);
                                                delete yymsp[0].minor.yy249;
                                                objectForTokens = yygotominor.yy604;
                                            }
        break;
      case 73: /* ccons ::= DEFAULT id */
{
                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy604->initDefId(*(yymsp[0].minor.yy259));
                                                delete yymsp[0].minor.yy259;
                                                objectForTokens = yygotominor.yy604;
                                            }
        break;
      case 74: /* ccons ::= DEFAULT CTIME_KW */
{
                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy604->initDefCTime(yymsp[0].minor.yy0->value);
                                                objectForTokens = yygotominor.yy604;
                                            }
        break;
      case 75: /* ccons ::= NULL onconf */
{
                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy604->initNull(*(yymsp[0].minor.yy478));
                                                delete yymsp[0].minor.yy478;
                                                objectForTokens = yygotominor.yy604;
                                            }
        break;
      case 76: /* ccons ::= NOT NULL onconf */
{
                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy604->initNotNull(*(yymsp[0].minor.yy478));
                                                delete yymsp[0].minor.yy478;
                                                objectForTokens = yygotominor.yy604;
                                            }
        break;
      case 77: /* ccons ::= PRIMARY KEY sortorder onconf autoinc */
{
                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy604->initPk(*(yymsp[-2].minor.yy389), *(yymsp[-1].minor.yy478), *(yymsp[0].minor.yy291));
                                                delete yymsp[-2].minor.yy389;
                                                delete yymsp[0].minor.yy291;
                                                delete yymsp[-1].minor.yy478;
                                                objectForTokens = yygotominor.yy604;
                                            }
        break;
      case 78: /* ccons ::= UNIQUE onconf */
{
                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy604->initUnique(*(yymsp[0].minor.yy478));
                                                delete yymsp[0].minor.yy478;
                                                objectForTokens = yygotominor.yy604;
                                            }
        break;
      case 79: /* ccons ::= CHECK LP expr RP */
{
                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy604->initCheck(yymsp[-1].minor.yy252);
                                                objectForTokens = yygotominor.yy604;
                                            }
        break;
      case 80: /* ccons ::= REFERENCES nm idxlist_opt refargs */
{
                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy604->initFk(*(yymsp[-2].minor.yy259), *(yymsp[-1].minor.yy123), *(yymsp[0].minor.yy324));
                                                delete yymsp[-2].minor.yy259;
                                                delete yymsp[0].minor.yy324;
                                                delete yymsp[-1].minor.yy123;
                                                objectForTokens = yygotominor.yy604;
                                            }
        break;
      case 81: /* ccons ::= defer_subclause */
{
                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy604->initDefer(yymsp[0].minor.yy449->initially, yymsp[0].minor.yy449->deferrable);
                                                delete yymsp[0].minor.yy449;
                                                objectForTokens = yygotominor.yy604;
                                            }
        break;
      case 82: /* ccons ::= COLLATE ids */
{
                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy604->initColl(*(yymsp[0].minor.yy259));
                                                delete yymsp[0].minor.yy259;
                                                objectForTokens = yygotominor.yy604;
                                            }
        break;
      case 83: /* ccons ::= gen_always AS LP expr RP id_opt */
      case 84: /* ccons ::= CONSTRAINT ID_CONSTR */ yytestcase(yyruleno==84);
      case 85: /* ccons ::= COLLATE ID_COLLATE */ yytestcase(yyruleno==85);
      case 86: /* ccons ::= REFERENCES ID_TAB */ yytestcase(yyruleno==86);
{
                                                if (!yymsp[0].minor.yy259->isNull() && yymsp[0].minor.yy259->toLower() != "stored" && yymsp[0].minor.yy259->toLower() != "virtual")
                                                    parserContext->errorAtToken(QString("Invalid generated column type: %1").arg(*(yymsp[0].minor.yy259)));

                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
												yygotominor.yy604->initGeneratedAs(yymsp[-2].minor.yy252, *(yymsp[-5].minor.yy291), *(yymsp[0].minor.yy259));
												delete yymsp[-5].minor.yy291;
												delete yymsp[0].minor.yy259;
												objectForTokens = yygotominor.yy604;
											}
        break;
      case 87: /* ccons ::= CHECK LP RP */
{
                                                yygotominor.yy604 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy604->initCheck();
                                                objectForTokens = yygotominor.yy604;
                                                parserContext->minorErrorAfterLastToken("Syntax error");
                                            }
        break;
      case 88: /* term ::= NULL */
{yygotominor.yy249 = new QVariant();}
        break;
      case 89: /* term ::= INTEGER */
      case 388: /* number ::= INTEGER */ yytestcase(yyruleno==388);
{yygotominor.yy249 = parserContext->handleNumberToken(yymsp[0].minor.yy0->value);}
        break;
      case 90: /* term ::= FLOAT */
      case 389: /* number ::= FLOAT */ yytestcase(yyruleno==389);
{yygotominor.yy249 = new QVariant(QVariant(yymsp[0].minor.yy0->value).toDouble());}
        break;
      case 91: /* term ::= STRING|BLOB */
{
                                                if (yymsp[0].minor.yy0->value.length() >= 3 && yymsp[0].minor.yy0->value.startsWith("x'", Qt::CaseInsensitive))
                                                    yygotominor.yy249 = new QVariant(blobFromLiteral(yymsp[0].minor.yy0->value));
                                                else
                                                    yygotominor.yy249 = new QVariant(stripString(yymsp[0].minor.yy0->value));
                                            }
        break;
      case 92: /* tnm ::= term */
{
												yygotominor.yy350 = new ParserTermOrLiteral(*(yymsp[0].minor.yy249));
												delete yymsp[0].minor.yy249;
											}
        break;
      case 93: /* tnm ::= nm */
{
												yygotominor.yy350 = new ParserTermOrLiteral(*(yymsp[0].minor.yy259));
												delete yymsp[0].minor.yy259;
											}
        break;
      case 98: /* refargs ::= */
{yygotominor.yy324 = new ParserFkConditionList();}
        break;
      case 99: /* refargs ::= refargs refarg */
{
                                                yymsp[-1].minor.yy324->append(yymsp[0].minor.yy607);
                                                yygotominor.yy324 = yymsp[-1].minor.yy324;
                                                DONT_INHERIT_TOKENS("refargs");
                                            }
        break;
      case 100: /* refarg ::= MATCH nm */
{
                                                yygotominor.yy607 = new SqliteForeignKey::Condition(*(yymsp[0].minor.yy259));
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 101: /* refarg ::= ON INSERT refact */
{yygotominor.yy607 = new SqliteForeignKey::Condition(SqliteForeignKey::Condition::INSERT, *(yymsp[0].minor.yy124)); delete yymsp[0].minor.yy124;}
        break;
      case 102: /* refarg ::= ON DELETE refact */
{yygotominor.yy607 = new SqliteForeignKey::Condition(SqliteForeignKey::Condition::DELETE, *(yymsp[0].minor.yy124)); delete yymsp[0].minor.yy124;}
        break;
      case 103: /* refarg ::= ON UPDATE refact */
      case 104: /* refarg ::= MATCH ID_FK_MATCH */ yytestcase(yyruleno==104);
{yygotominor.yy607 = new SqliteForeignKey::Condition(SqliteForeignKey::Condition::UPDATE, *(yymsp[0].minor.yy124)); delete yymsp[0].minor.yy124;}
        break;
      case 105: /* refact ::= SET NULL */
{yygotominor.yy124 = new SqliteForeignKey::Condition::Reaction(SqliteForeignKey::Condition::SET_NULL);}
        break;
      case 106: /* refact ::= SET DEFAULT */
{yygotominor.yy124 = new SqliteForeignKey::Condition::Reaction(SqliteForeignKey::Condition::SET_DEFAULT);}
        break;
      case 107: /* refact ::= CASCADE */
{yygotominor.yy124 = new SqliteForeignKey::Condition::Reaction(SqliteForeignKey::Condition::CASCADE);}
        break;
      case 108: /* refact ::= RESTRICT */
{yygotominor.yy124 = new SqliteForeignKey::Condition::Reaction(SqliteForeignKey::Condition::RESTRICT);}
        break;
      case 109: /* refact ::= NO ACTION */
{yygotominor.yy124 = new SqliteForeignKey::Condition::Reaction(SqliteForeignKey::Condition::NO_ACTION);}
        break;
      case 110: /* defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt */
{
                                                yygotominor.yy449 = new ParserDeferSubClause(SqliteDeferrable::NOT_DEFERRABLE, *(yymsp[0].minor.yy192));
                                                delete yymsp[0].minor.yy192;
                                            }
        break;
      case 111: /* defer_subclause ::= DEFERRABLE init_deferred_pred_opt */
{
                                                yygotominor.yy449 = new ParserDeferSubClause(SqliteDeferrable::DEFERRABLE, *(yymsp[0].minor.yy192));
                                                delete yymsp[0].minor.yy192;
                                            }
        break;
      case 112: /* init_deferred_pred_opt ::= */
{yygotominor.yy192 = new SqliteInitially(SqliteInitially::null);}
        break;
      case 113: /* init_deferred_pred_opt ::= INITIALLY DEFERRED */
{yygotominor.yy192 = new SqliteInitially(SqliteInitially::DEFERRED);}
        break;
      case 114: /* init_deferred_pred_opt ::= INITIALLY IMMEDIATE */
{yygotominor.yy192 = new SqliteInitially(SqliteInitially::IMMEDIATE);}
        break;
      case 115: /* conslist_opt ::= */
{yygotominor.yy373 = new ParserCreateTableConstraintList();}
        break;
      case 116: /* conslist_opt ::= COMMA conslist */
{yygotominor.yy373 = yymsp[0].minor.yy373;}
        break;
      case 117: /* conslist ::= conslist tconscomma tcons */
{
                                                yymsp[0].minor.yy106->afterComma = *(yymsp[-1].minor.yy291);
                                                yymsp[-2].minor.yy373->append(yymsp[0].minor.yy106);
                                                yygotominor.yy373 = yymsp[-2].minor.yy373;
                                                delete yymsp[-1].minor.yy291;
                                                DONT_INHERIT_TOKENS("conslist");
                                            }
        break;
      case 118: /* conslist ::= tcons */
{
                                                yygotominor.yy373 = new ParserCreateTableConstraintList();
                                                yygotominor.yy373->append(yymsp[0].minor.yy106);
                                            }
        break;
      case 121: /* tcons ::= CONSTRAINT nm */
{
                                                yygotominor.yy106 = new SqliteCreateTable::Constraint();
                                                yygotominor.yy106->initNameOnly(*(yymsp[0].minor.yy259));
                                                delete yymsp[0].minor.yy259;
                                                objectForTokens = yygotominor.yy106;
                                            }
        break;
      case 122: /* tcons ::= PRIMARY KEY LP idxlist autoinc RP onconf */
{
                                                yygotominor.yy106 = new SqliteCreateTable::Constraint();
                                                yygotominor.yy106->initPk(*(yymsp[-3].minor.yy123), *(yymsp[-2].minor.yy291), *(yymsp[0].minor.yy478));
                                                delete yymsp[-2].minor.yy291;
                                                delete yymsp[0].minor.yy478;
                                                delete yymsp[-3].minor.yy123;
                                                objectForTokens = yygotominor.yy106;
                                            }
        break;
      case 123: /* tcons ::= UNIQUE LP idxlist RP onconf */
{
                                                yygotominor.yy106 = new SqliteCreateTable::Constraint();
                                                yygotominor.yy106->initUnique(*(yymsp[-2].minor.yy123), *(yymsp[0].minor.yy478));
                                                delete yymsp[0].minor.yy478;
                                                delete yymsp[-2].minor.yy123;
                                                objectForTokens = yygotominor.yy106;
                                            }
        break;
      case 124: /* tcons ::= CHECK LP expr RP onconf */
{
                                                yygotominor.yy106 = new SqliteCreateTable::Constraint();
                                                yygotominor.yy106->initCheck(yymsp[-2].minor.yy252, *(yymsp[0].minor.yy478));
                                                objectForTokens = yygotominor.yy106;
                                            }
        break;
      case 125: /* tcons ::= FOREIGN KEY LP idxlist RP REFERENCES nm idxlist_opt refargs defer_subclause_opt */
      case 126: /* tcons ::= CONSTRAINT ID_CONSTR */ yytestcase(yyruleno==126);
      case 127: /* tcons ::= FOREIGN KEY LP idxlist RP REFERENCES ID_TAB */ yytestcase(yyruleno==127);
{
                                                yygotominor.yy106 = new SqliteCreateTable::Constraint();
                                                yygotominor.yy106->initFk(
                                                    *(yymsp[-6].minor.yy123),
                                                    *(yymsp[-3].minor.yy259),
                                                    *(yymsp[-2].minor.yy123),
                                                    *(yymsp[-1].minor.yy324),
                                                    yymsp[0].minor.yy449->initially,
                                                    yymsp[0].minor.yy449->deferrable
                                                );
                                                delete yymsp[-3].minor.yy259;
                                                delete yymsp[-1].minor.yy324;
                                                delete yymsp[0].minor.yy449;
                                                delete yymsp[-2].minor.yy123;
                                                delete yymsp[-6].minor.yy123;
                                                objectForTokens = yygotominor.yy106;
                                            }
        break;
      case 128: /* tcons ::= CHECK LP RP onconf */
{
                                                yygotominor.yy106 = new SqliteCreateTable::Constraint();
                                                yygotominor.yy106->initCheck();
                                                objectForTokens = yygotominor.yy106;
                                                parserContext->minorErrorAfterLastToken("Syntax error");
                                              yy_destructor(yypParser,228,&yymsp[0].minor);
}
        break;
      case 129: /* defer_subclause_opt ::= */
{yygotominor.yy449 = new ParserDeferSubClause(SqliteDeferrable::null, SqliteInitially::null);}
        break;
      case 130: /* defer_subclause_opt ::= defer_subclause */
{yygotominor.yy449 = yymsp[0].minor.yy449;}
        break;
      case 131: /* onconf ::= */
      case 133: /* orconf ::= */ yytestcase(yyruleno==133);
{yygotominor.yy478 = new SqliteConflictAlgo(SqliteConflictAlgo::null);}
        break;
      case 132: /* onconf ::= ON CONFLICT resolvetype */
      case 134: /* orconf ::= OR resolvetype */ yytestcase(yyruleno==134);
{yygotominor.yy478 = yymsp[0].minor.yy478;}
        break;
      case 135: /* resolvetype ::= raisetype */
      case 136: /* resolvetype ::= IGNORE */ yytestcase(yyruleno==136);
      case 137: /* resolvetype ::= REPLACE */ yytestcase(yyruleno==137);
{yygotominor.yy478 = new SqliteConflictAlgo(sqliteConflictAlgo(yymsp[0].minor.yy0->value));}
        break;
      case 138: /* cmd ::= DROP TABLE ifexists fullname */
{
                                                yygotominor.yy443 = new SqliteDropTable(*(yymsp[-1].minor.yy291), yymsp[0].minor.yy60->name1, yymsp[0].minor.yy60->name2);
                                                delete yymsp[-1].minor.yy291;
                                                delete yymsp[0].minor.yy60;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 139: /* cmd ::= DROP TABLE ifexists nm DOT ID_TAB */
      case 140: /* cmd ::= DROP TABLE ifexists ID_DB|ID_TAB */ yytestcase(yyruleno==140);
      case 147: /* cmd ::= DROP VIEW ifexists nm DOT ID_VIEW */ yytestcase(yyruleno==147);
      case 148: /* cmd ::= DROP VIEW ifexists ID_DB|ID_VIEW */ yytestcase(yyruleno==148);
      case 191: /* singlesrc ::= nm DOT ID_TAB */ yytestcase(yyruleno==191);
      case 192: /* singlesrc ::= ID_DB|ID_TAB */ yytestcase(yyruleno==192);
      case 193: /* singlesrc ::= nm DOT ID_VIEW */ yytestcase(yyruleno==193);
      case 194: /* singlesrc ::= ID_DB|ID_VIEW */ yytestcase(yyruleno==194);
      case 353: /* cmd ::= CREATE uniqueflag INDEX ifnotexists nm DOT ID_IDX_NEW */ yytestcase(yyruleno==353);
      case 354: /* cmd ::= CREATE uniqueflag INDEX ifnotexists ID_DB|ID_IDX_NEW */ yytestcase(yyruleno==354);
      case 367: /* cmd ::= DROP INDEX ifexists nm DOT ID_IDX */ yytestcase(yyruleno==367);
      case 368: /* cmd ::= DROP INDEX ifexists ID_DB|ID_IDX */ yytestcase(yyruleno==368);
      case 378: /* cmd ::= PRAGMA nm DOT ID_PRAGMA */ yytestcase(yyruleno==378);
      case 379: /* cmd ::= PRAGMA ID_DB|ID_PRAGMA */ yytestcase(yyruleno==379);
      case 417: /* cmd ::= DROP TRIGGER ifexists nm DOT ID_TRIG */ yytestcase(yyruleno==417);
      case 418: /* cmd ::= DROP TRIGGER ifexists ID_DB|ID_TRIG */ yytestcase(yyruleno==418);
      case 428: /* cmd ::= REINDEX nm DOT ID_TAB|ID_IDX */ yytestcase(yyruleno==428);
      case 429: /* cmd ::= REINDEX ID_DB|ID_IDX|ID_TAB */ yytestcase(yyruleno==429);
      case 432: /* cmd ::= ANALYZE nm DOT ID_TAB|ID_IDX */ yytestcase(yyruleno==432);
      case 433: /* cmd ::= ANALYZE ID_DB|ID_IDX|ID_TAB */ yytestcase(yyruleno==433);
      case 438: /* cmd ::= ALTER TABLE nm DOT ID_TAB */ yytestcase(yyruleno==438);
      case 439: /* cmd ::= ALTER TABLE ID_DB|ID_TAB */ yytestcase(yyruleno==439);
      case 445: /* create_vtab ::= CREATE VIRTUAL TABLE ifnotexists nm DOT ID_TAB_NEW */ yytestcase(yyruleno==445);
      case 446: /* create_vtab ::= CREATE VIRTUAL TABLE ifnotexists ID_DB|ID_TAB_NEW */ yytestcase(yyruleno==446);
{  yy_destructor(yypParser,203,&yymsp[-2].minor);
}
        break;
      case 143: /* cmd ::= CREATE temp VIEW ifnotexists fullname idxlist_opt AS select */
{
                                                yygotominor.yy443 = new SqliteCreateView(*(yymsp[-6].minor.yy346), *(yymsp[-4].minor.yy291), yymsp[-3].minor.yy60->name1, yymsp[-3].minor.yy60->name2, yymsp[0].minor.yy453, *(yymsp[-2].minor.yy123));
                                                delete yymsp[-6].minor.yy346;
                                                delete yymsp[-4].minor.yy291;
                                                delete yymsp[-3].minor.yy60;
                                                delete yymsp[-2].minor.yy123;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 146: /* cmd ::= DROP VIEW ifexists fullname */
{
                                                yygotominor.yy443 = new SqliteDropView(*(yymsp[-1].minor.yy291), yymsp[0].minor.yy60->name1, yymsp[0].minor.yy60->name2);
                                                delete yymsp[-1].minor.yy291;
                                                delete yymsp[0].minor.yy60;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 149: /* cmd ::= select_stmt */
      case 238: /* cmd ::= delete_stmt */ yytestcase(yyruleno==238);
      case 249: /* cmd ::= update_stmt */ yytestcase(yyruleno==249);
      case 270: /* cmd ::= insert_stmt */ yytestcase(yyruleno==270);
{
                                                yygotominor.yy443 = yymsp[0].minor.yy443;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 150: /* select_stmt ::= select */
{
                                                yygotominor.yy443 = yymsp[0].minor.yy453;
                                                // since it's used in trigger:
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 151: /* select ::= with selectnowith */
{
                                                yygotominor.yy453 = yymsp[0].minor.yy453;
                                                yymsp[0].minor.yy453->setWith(yymsp[-1].minor.yy641);
                                                objectForTokens = yygotominor.yy453;
                                            }
        break;
      case 152: /* selectnowith ::= oneselect */
{
                                                yygotominor.yy453 = SqliteSelect::append(yymsp[0].minor.yy450);
                                                objectForTokens = yygotominor.yy453;
                                            }
        break;
      case 153: /* selectnowith ::= selectnowith multiselect_op oneselect */
{
                                                yygotominor.yy453 = SqliteSelect::append(yymsp[-2].minor.yy453, *(yymsp[-1].minor.yy382), yymsp[0].minor.yy450);
                                                delete yymsp[-1].minor.yy382;
                                                objectForTokens = yygotominor.yy453;
                                            }
        break;
      case 154: /* selectnowith ::= values */
{
                                                yygotominor.yy453 = SqliteSelect::append(*(yymsp[0].minor.yy546));
                                                delete yymsp[0].minor.yy546;
                                                objectForTokens = yygotominor.yy453;
                                            }
        break;
      case 155: /* selectnowith ::= selectnowith COMMA values */
{
                                                yygotominor.yy453 = SqliteSelect::append(yymsp[-2].minor.yy453, SqliteSelect::CompoundOperator::UNION_ALL, *(yymsp[0].minor.yy546));
                                                delete yymsp[0].minor.yy546;
                                                objectForTokens = yygotominor.yy453;
                                            }
        break;
      case 156: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt */
{
                                                yygotominor.yy450 = new SqliteSelect::Core(
                                                        *(yymsp[-7].minor.yy346),
                                                        *(yymsp[-6].minor.yy633),
                                                        yymsp[-5].minor.yy91,
                                                        yymsp[-4].minor.yy252,
                                                        *(yymsp[-3].minor.yy351),
                                                        yymsp[-2].minor.yy252,
                                                        *(yymsp[-1].minor.yy543),
                                                        yymsp[0].minor.yy444
                                                    );
                                                delete yymsp[-6].minor.yy633;
                                                delete yymsp[-7].minor.yy346;
                                                delete yymsp[-3].minor.yy351;
                                                delete yymsp[-1].minor.yy543;
                                                objectForTokens = yygotominor.yy450;
                                            }
        break;
      case 157: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt window_clause orderby_opt limit_opt */
{
                                                yygotominor.yy450 = new SqliteSelect::Core(
                                                        *(yymsp[-8].minor.yy346),
                                                        *(yymsp[-7].minor.yy633),
                                                        yymsp[-6].minor.yy91,
                                                        yymsp[-5].minor.yy252,
                                                        *(yymsp[-4].minor.yy351),
                                                        yymsp[-3].minor.yy252,
                                                        *(yymsp[-2].minor.yy639),
                                                        *(yymsp[-1].minor.yy543),
                                                        yymsp[0].minor.yy444
                                                    );
                                                delete yymsp[-7].minor.yy633;
                                                delete yymsp[-8].minor.yy346;
                                                delete yymsp[-4].minor.yy351;
                                                delete yymsp[-1].minor.yy543;
                                                delete yymsp[-2].minor.yy639;
                                                objectForTokens = yygotominor.yy450;
                                            }
        break;
      case 158: /* values ::= VALUES LP nexprlist RP */
{
                                                yygotominor.yy546 = new ParserExprNestedList();
                                                yygotominor.yy546->append(*(yymsp[-1].minor.yy351));
                                                delete yymsp[-1].minor.yy351;
                                            }
        break;
      case 159: /* values ::= values COMMA LP exprlist RP */
{
                                                yymsp[-4].minor.yy546->append(*(yymsp[-1].minor.yy351));
                                                yygotominor.yy546 = yymsp[-4].minor.yy546;
                                                delete yymsp[-1].minor.yy351;
                                                DONT_INHERIT_TOKENS("values");
                                            }
        break;
      case 160: /* multiselect_op ::= UNION */
{yygotominor.yy382 = new SqliteSelect::CompoundOperator(SqliteSelect::CompoundOperator::UNION);}
        break;
      case 161: /* multiselect_op ::= UNION ALL */
{yygotominor.yy382 = new SqliteSelect::CompoundOperator(SqliteSelect::CompoundOperator::UNION_ALL);}
        break;
      case 162: /* multiselect_op ::= EXCEPT */
{yygotominor.yy382 = new SqliteSelect::CompoundOperator(SqliteSelect::CompoundOperator::EXCEPT);}
        break;
      case 163: /* multiselect_op ::= INTERSECT */
{yygotominor.yy382 = new SqliteSelect::CompoundOperator(SqliteSelect::CompoundOperator::INTERSECT);}
        break;
      case 164: /* distinct ::= DISTINCT */
{yygotominor.yy346 = new int(1);}
        break;
      case 165: /* distinct ::= ALL */
{yygotominor.yy346 = new int(2);}
        break;
      case 167: /* sclp ::= selcollist COMMA */
{yygotominor.yy633 = yymsp[-1].minor.yy633;}
        break;
      case 168: /* sclp ::= */
      case 247: /* returning ::= */ yytestcase(yyruleno==247);
{yygotominor.yy633 = new ParserResultColumnList();}
        break;
      case 169: /* selcollist ::= sclp expr as */
{
                                                SqliteSelect::Core::ResultColumn* obj =
                                                    new SqliteSelect::Core::ResultColumn(
                                                        yymsp[-1].minor.yy252,
                                                        yymsp[0].minor.yy460 ? yymsp[0].minor.yy460->asKw : false,
                                                        yymsp[0].minor.yy460 ? yymsp[0].minor.yy460->name : QString()
                                                    );

                                                yymsp[-2].minor.yy633->append(obj);
                                                yygotominor.yy633 = yymsp[-2].minor.yy633;
                                                delete yymsp[0].minor.yy460;
                                                objectForTokens = obj;
                                                DONT_INHERIT_TOKENS("sclp");
                                            }
        break;
      case 170: /* selcollist ::= sclp STAR */
{
                                                SqliteSelect::Core::ResultColumn* obj =
                                                    new SqliteSelect::Core::ResultColumn(true);

                                                yymsp[-1].minor.yy633->append(obj);
                                                yygotominor.yy633 = yymsp[-1].minor.yy633;
                                                objectForTokens = obj;
                                                DONT_INHERIT_TOKENS("sclp");
                                            }
        break;
      case 171: /* selcollist ::= sclp tnm DOT STAR */
{
                                                SqliteSelect::Core::ResultColumn* obj =
                                                    new SqliteSelect::Core::ResultColumn(
                                                        true,
                                                        yymsp[-2].minor.yy350->toName()
                                                    );
													
												if (!yymsp[-2].minor.yy350->isName())
													parserContext->errorAtToken("Syntax error <expected name, not literal value>", -3);
													
                                                yymsp[-3].minor.yy633->append(obj);
                                                yygotominor.yy633 = yymsp[-3].minor.yy633;
                                                delete yymsp[-2].minor.yy350;
                                                objectForTokens = obj;
                                                DONT_INHERIT_TOKENS("sclp");
                                            }
        break;
      case 172: /* selcollist ::= sclp */
      case 173: /* selcollist ::= sclp ID_TAB DOT STAR */ yytestcase(yyruleno==173);
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy633 = yymsp[0].minor.yy633;
                                            }
        break;
      case 174: /* as ::= AS nm */
{
                                                yygotominor.yy460 = new ParserStubAlias(*(yymsp[0].minor.yy259), true);
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 175: /* as ::= ids */
      case 176: /* as ::= AS ID_ALIAS */ yytestcase(yyruleno==176);
      case 177: /* as ::= ID_ALIAS */ yytestcase(yyruleno==177);
{
                                                yygotominor.yy460 = new ParserStubAlias(*(yymsp[0].minor.yy259), false);
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 178: /* as ::= */
{yygotominor.yy460 = nullptr;}
        break;
      case 179: /* from ::= */
{yygotominor.yy91 = nullptr;}
        break;
      case 180: /* from ::= FROM joinsrc */
{yygotominor.yy91 = yymsp[0].minor.yy91;}
        break;
      case 181: /* joinsrc ::= singlesrc seltablist */
{
                                                yygotominor.yy91 = new SqliteSelect::Core::JoinSource(
                                                        yymsp[-1].minor.yy361,
                                                        *(yymsp[0].minor.yy11)
                                                    );
                                                delete yymsp[0].minor.yy11;
                                                objectForTokens = yygotominor.yy91;
                                            }
        break;
      case 182: /* joinsrc ::= */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy91 = new SqliteSelect::Core::JoinSource();
                                                objectForTokens = yygotominor.yy91;
                                            }
        break;
      case 183: /* seltablist ::= seltablist joinop singlesrc joinconstr_opt */
{
                                                SqliteSelect::Core::JoinSourceOther* src =
                                                    new SqliteSelect::Core::JoinSourceOther(yymsp[-2].minor.yy521, yymsp[-1].minor.yy361, yymsp[0].minor.yy335);

                                                yymsp[-3].minor.yy11->append(src);
                                                yygotominor.yy11 = yymsp[-3].minor.yy11;
                                                objectForTokens = src;
                                                DONT_INHERIT_TOKENS("seltablist");
                                            }
        break;
      case 184: /* seltablist ::= */
{
                                                yygotominor.yy11 = new ParserOtherSourceList();
                                            }
        break;
      case 185: /* singlesrc ::= nm dbnm as indexed_opt */
{
                                                yygotominor.yy361 = new SqliteSelect::Core::SingleSource(
                                                        *(yymsp[-3].minor.yy259),
                                                        *(yymsp[-2].minor.yy259),
                                                        yymsp[-1].minor.yy460 ? yymsp[-1].minor.yy460->asKw : false,
                                                        yymsp[-1].minor.yy460 ? yymsp[-1].minor.yy460->name : QString(),
                                                        yymsp[0].minor.yy312 ? yymsp[0].minor.yy312->notIndexedKw : false,
                                                        yymsp[0].minor.yy312 ? yymsp[0].minor.yy312->indexedBy : QString()
                                                    );
                                                delete yymsp[-3].minor.yy259;
                                                delete yymsp[-2].minor.yy259;
                                                delete yymsp[-1].minor.yy460;
                                                if (yymsp[0].minor.yy312)
                                                    delete yymsp[0].minor.yy312;
                                                objectForTokens = yygotominor.yy361;
                                            }
        break;
      case 186: /* singlesrc ::= LP select RP as */
{
                                                yygotominor.yy361 = new SqliteSelect::Core::SingleSource(
                                                        yymsp[-2].minor.yy453,
                                                        yymsp[0].minor.yy460 ? yymsp[0].minor.yy460->asKw : false,
                                                        yymsp[0].minor.yy460 ? yymsp[0].minor.yy460->name : QString()
                                                    );
                                                delete yymsp[0].minor.yy460;
                                                objectForTokens = yygotominor.yy361;
                                            }
        break;
      case 187: /* singlesrc ::= LP joinsrc RP as */
{
                                                yygotominor.yy361 = new SqliteSelect::Core::SingleSource(
                                                        yymsp[-2].minor.yy91,
                                                        yymsp[0].minor.yy460 ? yymsp[0].minor.yy460->asKw : false,
                                                        yymsp[0].minor.yy460 ? yymsp[0].minor.yy460->name : QString()
                                                    );
                                                delete yymsp[0].minor.yy460;
                                                objectForTokens = yygotominor.yy361;
                                            }
        break;
      case 188: /* singlesrc ::= nm dbnm LP exprlist RP as */
{
                                                yygotominor.yy361 = new SqliteSelect::Core::SingleSource(
                                                        *(yymsp[-5].minor.yy259),
                                                        *(yymsp[-4].minor.yy259),
                                                        yymsp[0].minor.yy460 ? yymsp[0].minor.yy460->asKw : false,
                                                        yymsp[0].minor.yy460 ? yymsp[0].minor.yy460->name : QString(),
                                                        *(yymsp[-2].minor.yy351)
                                                    );
                                                delete yymsp[-5].minor.yy259;
                                                delete yymsp[-4].minor.yy259;
                                                delete yymsp[0].minor.yy460;
                                                if (yymsp[-2].minor.yy351)
                                                    delete yymsp[-2].minor.yy351;

                                                objectForTokens = yygotominor.yy361;
                                            }
        break;
      case 189: /* singlesrc ::= */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy361 = new SqliteSelect::Core::SingleSource();
                                                objectForTokens = yygotominor.yy361;
                                            }
        break;
      case 190: /* singlesrc ::= nm DOT */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy361 = new SqliteSelect::Core::SingleSource();
                                                yygotominor.yy361->database = *(yymsp[-1].minor.yy259);
                                                delete yymsp[-1].minor.yy259;
                                                objectForTokens = yygotominor.yy361;
                                            }
        break;
      case 195: /* joinconstr_opt ::= ON expr */
{
                                                yygotominor.yy335 = new SqliteSelect::Core::JoinConstraint(yymsp[0].minor.yy252);
                                                objectForTokens = yygotominor.yy335;
                                            }
        break;
      case 196: /* joinconstr_opt ::= USING LP idlist RP */
{
                                                yygotominor.yy335 = new SqliteSelect::Core::JoinConstraint(*(yymsp[-1].minor.yy215));
                                                delete yymsp[-1].minor.yy215;
                                                objectForTokens = yygotominor.yy335;
                                            }
        break;
      case 197: /* joinconstr_opt ::= */
{yygotominor.yy335 = nullptr;}
        break;
      case 198: /* dbnm ::= */
      case 363: /* collate ::= */ yytestcase(yyruleno==363);
      case 449: /* vtabarg ::= */ yytestcase(yyruleno==449);
      case 453: /* anylist ::= */ yytestcase(yyruleno==453);
{yygotominor.yy259 = new QString();}
        break;
      case 200: /* fullname ::= nm */
{
                                                yygotominor.yy60 = new ParserFullName();
                                                yygotominor.yy60->name1 = *(yymsp[0].minor.yy259);
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 201: /* fullname ::= nm DOT nm */
{
                                                yygotominor.yy60 = new ParserFullName();
                                                yygotominor.yy60->name1 = *(yymsp[-2].minor.yy259);
                                                yygotominor.yy60->name2 = *(yymsp[0].minor.yy259);
                                                delete yymsp[-2].minor.yy259;
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 202: /* xfullname ::= nm */
{
                                                yygotominor.yy116 = new ParserXFullName();
                                                yygotominor.yy116->name1 = *(yymsp[0].minor.yy259);
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 203: /* xfullname ::= nm DOT nm */
{
                                                yygotominor.yy116 = new ParserXFullName();
                                                yygotominor.yy116->name1 = *(yymsp[-2].minor.yy259);
                                                yygotominor.yy116->name2 = *(yymsp[0].minor.yy259);
                                                delete yymsp[-2].minor.yy259;
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 204: /* xfullname ::= nm DOT nm AS nm */
{
                                                yygotominor.yy116 = new ParserXFullName();
                                                yygotominor.yy116->name1 = *(yymsp[-4].minor.yy259);
                                                yygotominor.yy116->name2 = *(yymsp[-2].minor.yy259);
                                                yygotominor.yy116->alias = *(yymsp[0].minor.yy259);
                                                delete yymsp[-4].minor.yy259;
                                                delete yymsp[-2].minor.yy259;
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 205: /* xfullname ::= nm AS nm */
{
                                                yygotominor.yy116 = new ParserXFullName();
                                                yygotominor.yy116->name1 = *(yymsp[-2].minor.yy259);
                                                yygotominor.yy116->alias = *(yymsp[0].minor.yy259);
                                                delete yymsp[-2].minor.yy259;
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 206: /* xfullname ::= nm DOT nm AS ID_ALIAS */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy116 = new ParserXFullName();
                                                yygotominor.yy116->name1 = *(yymsp[-4].minor.yy259);
                                                yygotominor.yy116->name2 = *(yymsp[-2].minor.yy259);
                                                delete yymsp[-4].minor.yy259;
                                                delete yymsp[-2].minor.yy259;
                                            }
        break;
      case 207: /* xfullname ::= nm AS ID_ALIAS */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy116 = new ParserXFullName();
                                                yygotominor.yy116->name1 = *(yymsp[-2].minor.yy259);
                                                delete yymsp[-2].minor.yy259;
                                            }
        break;
      case 208: /* joinop ::= COMMA */
{
                                                yygotominor.yy521 = new SqliteSelect::Core::JoinOp(true);
                                                objectForTokens = yygotominor.yy521;
                                            }
        break;
      case 209: /* joinop ::= JOIN */
{
                                                yygotominor.yy521 = new SqliteSelect::Core::JoinOp(false);
                                                objectForTokens = yygotominor.yy521;
                                            }
        break;
      case 210: /* joinop ::= JOIN_KW JOIN */
{
                                                yygotominor.yy521 = new SqliteSelect::Core::JoinOp(yymsp[-1].minor.yy0->value);
                                                objectForTokens = yygotominor.yy521;
                                            }
        break;
      case 211: /* joinop ::= JOIN_KW nm JOIN */
{
                                                yygotominor.yy521 = new SqliteSelect::Core::JoinOp(yymsp[-2].minor.yy0->value, *(yymsp[-1].minor.yy259));
                                                delete yymsp[-1].minor.yy259;
                                                objectForTokens = yygotominor.yy521;
                                            }
        break;
      case 212: /* joinop ::= JOIN_KW nm nm JOIN */
      case 213: /* joinop ::= ID_JOIN_OPTS */ yytestcase(yyruleno==213);
{
                                                yygotominor.yy521 = new SqliteSelect::Core::JoinOp(yymsp[-3].minor.yy0->value, *(yymsp[-2].minor.yy259), *(yymsp[-1].minor.yy259));
                                                delete yymsp[-2].minor.yy259;
                                                objectForTokens = yygotominor.yy521;
                                            }
        break;
      case 214: /* indexed_opt ::= */
{yygotominor.yy312 = nullptr;}
        break;
      case 215: /* indexed_opt ::= indexed_by */
{yygotominor.yy312 = yymsp[0].minor.yy312;}
        break;
      case 216: /* indexed_by ::= INDEXED BY nm */
{
                                                yygotominor.yy312 = new ParserIndexedBy(*(yymsp[0].minor.yy259));
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 217: /* indexed_by ::= NOT INDEXED */
{yygotominor.yy312 = new ParserIndexedBy(true);}
        break;
      case 218: /* indexed_by ::= INDEXED BY ID_IDX */
{parserContext->minorErrorBeforeNextToken("Syntax error");}
        break;
      case 219: /* orderby_opt ::= */
{yygotominor.yy543 = new ParserOrderByList();}
        break;
      case 220: /* orderby_opt ::= ORDER BY sortlist */
{yygotominor.yy543 = yymsp[0].minor.yy543;}
        break;
      case 221: /* sortlist ::= sortlist COMMA expr sortorder nulls */
{
                                                SqliteOrderBy* obj = new SqliteOrderBy(yymsp[-2].minor.yy252, *(yymsp[-1].minor.yy389), *(yymsp[0].minor.yy99));
                                                yymsp[-4].minor.yy543->append(obj);
                                                yygotominor.yy543 = yymsp[-4].minor.yy543;
                                                delete yymsp[-1].minor.yy389;
												delete yymsp[0].minor.yy99;
                                                objectForTokens = obj;
                                                DONT_INHERIT_TOKENS("sortlist");
                                            }
        break;
      case 222: /* sortlist ::= expr sortorder nulls */
{
                                                SqliteOrderBy* obj = new SqliteOrderBy(yymsp[-2].minor.yy252, *(yymsp[-1].minor.yy389), *(yymsp[0].minor.yy99));
                                                yygotominor.yy543 = new ParserOrderByList();
                                                yygotominor.yy543->append(obj);
                                                delete yymsp[-1].minor.yy389;
												delete yymsp[0].minor.yy99;
                                                objectForTokens = obj;
                                            }
        break;
      case 223: /* sortorder ::= ASC */
{yygotominor.yy389 = new SqliteSortOrder(SqliteSortOrder::ASC);}
        break;
      case 224: /* sortorder ::= DESC */
{yygotominor.yy389 = new SqliteSortOrder(SqliteSortOrder::DESC);}
        break;
      case 225: /* sortorder ::= */
{yygotominor.yy389 = new SqliteSortOrder(SqliteSortOrder::null);}
        break;
      case 226: /* nulls ::= NULLS FIRST */
{yygotominor.yy99 = new SqliteNulls(SqliteNulls::FIRST);}
        break;
      case 227: /* nulls ::= NULLS LAST */
{yygotominor.yy99 = new SqliteNulls(SqliteNulls::LAST);}
        break;
      case 228: /* nulls ::= */
{yygotominor.yy99 = new SqliteNulls(SqliteNulls::null);}
        break;
      case 229: /* groupby_opt ::= */
      case 348: /* exprlist ::= */ yytestcase(yyruleno==348);
{yygotominor.yy351 = new ParserExprList();}
        break;
      case 230: /* groupby_opt ::= GROUP BY nexprlist */
      case 347: /* exprlist ::= nexprlist */ yytestcase(yyruleno==347);
{yygotominor.yy351 = yymsp[0].minor.yy351;}
        break;
      case 231: /* groupby_opt ::= GROUP BY */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy351 = new ParserExprList();
                                            }
        break;
      case 232: /* having_opt ::= */
      case 244: /* where_opt ::= */ yytestcase(yyruleno==244);
      case 344: /* case_else ::= */ yytestcase(yyruleno==344);
      case 346: /* case_operand ::= */ yytestcase(yyruleno==346);
      case 372: /* vinto ::= */ yytestcase(yyruleno==372);
      case 406: /* when_clause ::= */ yytestcase(yyruleno==406);
      case 421: /* key_opt ::= */ yytestcase(yyruleno==421);
{yygotominor.yy252 = nullptr;}
        break;
      case 233: /* having_opt ::= HAVING expr */
      case 245: /* where_opt ::= WHERE expr */ yytestcase(yyruleno==245);
      case 335: /* expr ::= exprx */ yytestcase(yyruleno==335);
      case 343: /* case_else ::= ELSE expr */ yytestcase(yyruleno==343);
      case 345: /* case_operand ::= exprx */ yytestcase(yyruleno==345);
      case 371: /* vinto ::= INTO expr */ yytestcase(yyruleno==371);
      case 407: /* when_clause ::= WHEN expr */ yytestcase(yyruleno==407);
      case 422: /* key_opt ::= KEY expr */ yytestcase(yyruleno==422);
{yygotominor.yy252 = yymsp[0].minor.yy252;}
        break;
      case 234: /* limit_opt ::= */
{yygotominor.yy444 = nullptr;}
        break;
      case 235: /* limit_opt ::= LIMIT expr */
{
                                                yygotominor.yy444 = new SqliteLimit(yymsp[0].minor.yy252);
                                                objectForTokens = yygotominor.yy444;
                                            }
        break;
      case 236: /* limit_opt ::= LIMIT expr OFFSET expr */
{
                                                yygotominor.yy444 = new SqliteLimit(yymsp[-2].minor.yy252, yymsp[0].minor.yy252, true);
                                                objectForTokens = yygotominor.yy444;
                                            }
        break;
      case 237: /* limit_opt ::= LIMIT expr COMMA expr */
{
                                                yygotominor.yy444 = new SqliteLimit(yymsp[-2].minor.yy252, yymsp[0].minor.yy252, false);
                                                objectForTokens = yygotominor.yy444;
                                            }
        break;
      case 239: /* delete_stmt ::= with DELETE FROM xfullname indexed_opt where_opt returning orderby_opt limit_opt */
{
                                                if (yymsp[-4].minor.yy312)
                                                {
                                                    if (!yymsp[-4].minor.yy312->indexedBy.isNull())
                                                    {
                                                        yygotominor.yy443 = new SqliteDelete(
                                                                yymsp[-5].minor.yy116->name1,
                                                                yymsp[-5].minor.yy116->name2,
                                                                yymsp[-5].minor.yy116->alias,
                                                                yymsp[-4].minor.yy312->indexedBy,
                                                                yymsp[-3].minor.yy252,
                                                                yymsp[-8].minor.yy641,
                                                                *(yymsp[-2].minor.yy633),
                                                                *(yymsp[-1].minor.yy543),
                                                                yymsp[0].minor.yy444
                                                            );
                                                    }
                                                    else
                                                    {
                                                        yygotominor.yy443 = new SqliteDelete(
                                                                yymsp[-5].minor.yy116->name1,
                                                                yymsp[-5].minor.yy116->name2,
                                                                yymsp[-5].minor.yy116->alias,
                                                                yymsp[-4].minor.yy312->notIndexedKw,
                                                                yymsp[-3].minor.yy252,
                                                                yymsp[-8].minor.yy641,
                                                                *(yymsp[-2].minor.yy633),
                                                                *(yymsp[-1].minor.yy543),
                                                                yymsp[0].minor.yy444
                                                            );
                                                    }
                                                    delete yymsp[-4].minor.yy312;
                                                }
                                                else
                                                {
                                                    yygotominor.yy443 = new SqliteDelete(
                                                            yymsp[-5].minor.yy116->name1,
                                                            yymsp[-5].minor.yy116->name2,
                                                            yymsp[-5].minor.yy116->alias,
                                                            false,
                                                            yymsp[-3].minor.yy252,
                                                            yymsp[-8].minor.yy641,
                                                            *(yymsp[-2].minor.yy633),
                                                            *(yymsp[-1].minor.yy543),
                                                            yymsp[0].minor.yy444
                                                        );
                                                }
                                                delete yymsp[-5].minor.yy116;
                                                delete yymsp[-2].minor.yy633;
                                                delete yymsp[-1].minor.yy543;
                                                // since it's used in trigger:
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 240: /* delete_stmt ::= with DELETE FROM */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                SqliteDelete* q = new SqliteDelete();
                                                q->with = yymsp[-2].minor.yy641;
                                                yygotominor.yy443 = q;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 241: /* delete_stmt ::= with DELETE FROM nm DOT */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                SqliteDelete* q = new SqliteDelete();
                                                q->with = yymsp[-4].minor.yy641;
                                                q->database = *(yymsp[-1].minor.yy259);
                                                yygotominor.yy443 = q;
                                                objectForTokens = yygotominor.yy443;
                                                delete yymsp[-1].minor.yy259;
                                            }
        break;
      case 242: /* delete_stmt ::= with DELETE FROM nm DOT ID_TAB */
      case 253: /* update_stmt ::= with UPDATE orconf nm DOT ID_TAB */ yytestcase(yyruleno==253);
{  yy_destructor(yypParser,249,&yymsp[-5].minor);
  yy_destructor(yypParser,203,&yymsp[-2].minor);
}
        break;
      case 243: /* delete_stmt ::= with DELETE FROM ID_DB|ID_TAB */
      case 254: /* update_stmt ::= with UPDATE orconf ID_DB|ID_TAB */ yytestcase(yyruleno==254);
{  yy_destructor(yypParser,249,&yymsp[-3].minor);
}
        break;
      case 246: /* where_opt ::= WHERE */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy252 = new SqliteExpr();
                                            }
        break;
      case 248: /* returning ::= RETURNING selcollist */
{yygotominor.yy633 = yymsp[0].minor.yy633;}
        break;
      case 250: /* update_stmt ::= with UPDATE orconf xfullname indexed_opt SET setlist from where_opt returning orderby_opt limit_opt */
{
                                                yygotominor.yy443 = new SqliteUpdate(
                                                        *(yymsp[-9].minor.yy478),
                                                        yymsp[-8].minor.yy116->name1,
                                                        yymsp[-8].minor.yy116->name2,
                                                        yymsp[-8].minor.yy116->alias,
                                                        yymsp[-7].minor.yy312 ? yymsp[-7].minor.yy312->notIndexedKw : false,
                                                        yymsp[-7].minor.yy312 ? yymsp[-7].minor.yy312->indexedBy : QString(),
                                                        *(yymsp[-5].minor.yy321),
                                                        yymsp[-4].minor.yy91,
                                                        yymsp[-3].minor.yy252,
                                                        yymsp[-11].minor.yy641,
                                                        *(yymsp[-2].minor.yy633),
                                                        *(yymsp[-1].minor.yy543),
                                                        yymsp[0].minor.yy444
                                                    );
                                                delete yymsp[-9].minor.yy478;
                                                delete yymsp[-8].minor.yy116;
                                                delete yymsp[-5].minor.yy321;
                                                delete yymsp[-2].minor.yy633;
                                                delete yymsp[-1].minor.yy543;
                                                if (yymsp[-7].minor.yy312)
                                                    delete yymsp[-7].minor.yy312;
                                                // since it's used in trigger:
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 251: /* update_stmt ::= with UPDATE orconf */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                SqliteUpdate* q = new SqliteUpdate();
                                                q->with = yymsp[-2].minor.yy641;
                                                yygotominor.yy443 = q;
                                                objectForTokens = yygotominor.yy443;
                                                delete yymsp[0].minor.yy478;
                                            }
        break;
      case 252: /* update_stmt ::= with UPDATE orconf nm DOT */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                SqliteUpdate* q = new SqliteUpdate();
                                                q->with = yymsp[-4].minor.yy641;
                                                q->database = *(yymsp[-1].minor.yy259);
                                                yygotominor.yy443 = q;
                                                objectForTokens = yygotominor.yy443;
                                                delete yymsp[-2].minor.yy478;
                                                delete yymsp[-1].minor.yy259;
                                            }
        break;
      case 255: /* setlist ::= setlist COMMA nm EQ expr */
{
                                                yymsp[-4].minor.yy321->append(ParserSetValue(*(yymsp[-2].minor.yy259), yymsp[0].minor.yy252));
                                                yygotominor.yy321 = yymsp[-4].minor.yy321;
                                                delete yymsp[-2].minor.yy259;
                                            }
        break;
      case 256: /* setlist ::= setlist COMMA LP idlist RP EQ expr */
{
                                                yymsp[-6].minor.yy321->append(ParserSetValue(*(yymsp[-3].minor.yy215), yymsp[0].minor.yy252));
                                                yygotominor.yy321 = yymsp[-6].minor.yy321;
                                                delete yymsp[-3].minor.yy215;
                                            }
        break;
      case 257: /* setlist ::= nm EQ expr */
{
                                                yygotominor.yy321 = new ParserSetValueList();
                                                yygotominor.yy321->append(ParserSetValue(*(yymsp[-2].minor.yy259), yymsp[0].minor.yy252));
                                                delete yymsp[-2].minor.yy259;
                                            }
        break;
      case 258: /* setlist ::= LP idlist RP EQ expr */
{
                                                yygotominor.yy321 = new ParserSetValueList();
                                                yygotominor.yy321->append(ParserSetValue(*(yymsp[-3].minor.yy215), yymsp[0].minor.yy252));
                                                delete yymsp[-3].minor.yy215;
                                            }
        break;
      case 259: /* setlist ::= */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy321 = new ParserSetValueList();
                                            }
        break;
      case 260: /* setlist ::= setlist COMMA */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy321 = yymsp[-1].minor.yy321;
                                            }
        break;
      case 261: /* setlist ::= setlist COMMA ID_COL */
      case 262: /* setlist ::= ID_COL */ yytestcase(yyruleno==262);
{  yy_destructor(yypParser,282,&yymsp[-2].minor);
}
        break;
      case 263: /* idlist_opt ::= */
{yygotominor.yy215 = new QStringList();}
        break;
      case 264: /* idlist_opt ::= LP idlist RP */
{yygotominor.yy215 = yymsp[-1].minor.yy215;}
        break;
      case 265: /* idlist ::= idlist COMMA nm */
{
                                                yygotominor.yy215 = yymsp[-2].minor.yy215;
                                                *(yygotominor.yy215) << *(yymsp[0].minor.yy259);
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 266: /* idlist ::= nm */
{
                                                yygotominor.yy215 = new QStringList();
                                                *(yygotominor.yy215) << *(yymsp[0].minor.yy259);
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 267: /* idlist ::= */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy215 = new QStringList();
                                            }
        break;
      case 268: /* idlist ::= idlist COMMA ID_COL */
      case 269: /* idlist ::= ID_COL */ yytestcase(yyruleno==269);
{  yy_destructor(yypParser,274,&yymsp[-2].minor);
}
        break;
      case 271: /* insert_stmt ::= with insert_cmd INTO xfullname idlist_opt select upsert returning */
{
                                                yygotominor.yy443 = new SqliteInsert(
                                                        yymsp[-6].minor.yy584->replace,
                                                        yymsp[-6].minor.yy584->orConflict,
                                                        yymsp[-4].minor.yy116->name1,
                                                        yymsp[-4].minor.yy116->name2,
                                                        yymsp[-4].minor.yy116->alias,
                                                        *(yymsp[-3].minor.yy215),
                                                        yymsp[-2].minor.yy453,
                                                        yymsp[-7].minor.yy641,
                                                        yymsp[-1].minor.yy500,
                                                        *(yymsp[0].minor.yy633)
                                                    );
                                                delete yymsp[-4].minor.yy116;
                                                delete yymsp[-6].minor.yy584;
                                                delete yymsp[-3].minor.yy215;
                                                delete yymsp[0].minor.yy633;
                                                // since it's used in trigger:
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 272: /* insert_stmt ::= with insert_cmd INTO xfullname idlist_opt DEFAULT VALUES returning */
{
                                                yygotominor.yy443 = new SqliteInsert(
                                                        yymsp[-6].minor.yy584->replace,
                                                        yymsp[-6].minor.yy584->orConflict,
                                                        yymsp[-4].minor.yy116->name1,
                                                        yymsp[-4].minor.yy116->name2,
                                                        yymsp[-4].minor.yy116->alias,
                                                        *(yymsp[-3].minor.yy215),
                                                        yymsp[-7].minor.yy641,
                                                        *(yymsp[0].minor.yy633)
                                                    );
                                                delete yymsp[-4].minor.yy116;
                                                delete yymsp[-6].minor.yy584;
                                                delete yymsp[-3].minor.yy215;
                                                delete yymsp[0].minor.yy633;
                                                // since it's used in trigger:
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 273: /* insert_stmt ::= with insert_cmd INTO xfullname LP idlist rp_opt */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy443 = new SqliteInsert(
                                                        yymsp[-5].minor.yy584->replace,
                                                        yymsp[-5].minor.yy584->orConflict,
                                                        yymsp[-3].minor.yy116->name1,
                                                        yymsp[-3].minor.yy116->name2,
                                                        yymsp[-3].minor.yy116->alias,
                                                        *(yymsp[-1].minor.yy215),
                                                        yymsp[-6].minor.yy641,
                                                        QList<SqliteResultColumn*>()
                                                    );
                                                objectForTokens = yygotominor.yy443;
                                                delete yymsp[-3].minor.yy116;
                                                delete yymsp[-1].minor.yy215;
                                                delete yymsp[-5].minor.yy584;
                                                delete yymsp[0].minor.yy291;
                                            }
        break;
      case 274: /* insert_stmt ::= with insert_cmd INTO */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                SqliteInsert* q = new SqliteInsert();
                                                q->replaceKw = yymsp[-1].minor.yy584->replace;
                                                q->onConflict = yymsp[-1].minor.yy584->orConflict;
                                                q->with = yymsp[-2].minor.yy641;
                                                yygotominor.yy443 = q;
                                                objectForTokens = yygotominor.yy443;
                                                delete yymsp[-1].minor.yy584;
                                            }
        break;
      case 275: /* insert_stmt ::= with insert_cmd INTO nm DOT */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                SqliteInsert* q = new SqliteInsert();
                                                q->replaceKw = yymsp[-3].minor.yy584->replace;
                                                q->onConflict = yymsp[-3].minor.yy584->orConflict;
                                                q->with = yymsp[-4].minor.yy641;
                                                q->database = *(yymsp[-1].minor.yy259);
                                                yygotominor.yy443 = q;
                                                objectForTokens = yygotominor.yy443;
                                                delete yymsp[-3].minor.yy584;
                                                delete yymsp[-1].minor.yy259;
                                            }
        break;
      case 276: /* insert_stmt ::= with insert_cmd INTO ID_DB|ID_TAB */
{  yy_destructor(yypParser,249,&yymsp[-3].minor);
  yy_destructor(yypParser,285,&yymsp[-2].minor);
}
        break;
      case 277: /* insert_stmt ::= with insert_cmd INTO nm DOT ID_TAB */
{  yy_destructor(yypParser,249,&yymsp[-5].minor);
  yy_destructor(yypParser,285,&yymsp[-4].minor);
  yy_destructor(yypParser,203,&yymsp[-2].minor);
}
        break;
      case 278: /* insert_cmd ::= INSERT orconf */
{
                                                yygotominor.yy584 = new ParserStubInsertOrReplace(false, *(yymsp[0].minor.yy478));
                                                delete yymsp[0].minor.yy478;
                                            }
        break;
      case 279: /* insert_cmd ::= REPLACE */
{yygotominor.yy584 = new ParserStubInsertOrReplace(true);}
        break;
      case 280: /* upsert ::= */
{
                                                yygotominor.yy500 = nullptr;
                                            }
        break;
      case 281: /* upsert ::= ON CONFLICT LP sortlist RP where_opt DO UPDATE SET setlist where_opt */
{
                                                yygotominor.yy500 = new SqliteUpsert(*(yymsp[-7].minor.yy543), yymsp[-5].minor.yy252, *(yymsp[-1].minor.yy321), yymsp[0].minor.yy252);
                                                delete yymsp[-7].minor.yy543;
                                                delete yymsp[-1].minor.yy321;
                                                objectForTokens = yygotominor.yy500;
                                            }
        break;
      case 282: /* upsert ::= ON CONFLICT LP sortlist RP where_opt DO NOTHING */
{
                                                yygotominor.yy500 = new SqliteUpsert(*(yymsp[-4].minor.yy543), yymsp[-2].minor.yy252);
                                                delete yymsp[-4].minor.yy543;
                                                objectForTokens = yygotominor.yy500;
                                            }
        break;
      case 283: /* upsert ::= ON CONFLICT DO NOTHING */
{
                                                yygotominor.yy500 = new SqliteUpsert();
                                                objectForTokens = yygotominor.yy500;
                                            }
        break;
      case 284: /* exprx ::= expr not_opt IN ID_DB */
{  yy_destructor(yypParser,227,&yymsp[-3].minor);
}
        break;
      case 285: /* exprx ::= expr not_opt IN nm DOT ID_TAB */
      case 286: /* exprx ::= ID_DB|ID_TAB|ID_COL|ID_FN */ yytestcase(yyruleno==286);
{  yy_destructor(yypParser,227,&yymsp[-5].minor);
  yy_destructor(yypParser,203,&yymsp[-2].minor);
}
        break;
      case 287: /* exprx ::= tnm DOT ID_TAB|ID_COL */
{  yy_destructor(yypParser,235,&yymsp[-2].minor);
}
        break;
      case 288: /* exprx ::= tnm DOT nm DOT ID_COL */
{  yy_destructor(yypParser,235,&yymsp[-4].minor);
  yy_destructor(yypParser,203,&yymsp[-2].minor);
}
        break;
      case 289: /* exprx ::= expr COLLATE ID_COLLATE */
      case 290: /* exprx ::= RAISE LP raisetype COMMA ID_ERR_MSG RP */ yytestcase(yyruleno==290);
{  yy_destructor(yypParser,227,&yymsp[-2].minor);
}
        break;
      case 291: /* exprx ::= CTIME_KW */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initCTime(yymsp[0].minor.yy0->value);
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 292: /* exprx ::= LP nexprlist RP */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initRowValue(*(yymsp[-1].minor.yy351));
                                                delete yymsp[-1].minor.yy351;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 293: /* exprx ::= tnm */
{
                                                yygotominor.yy252 = new SqliteExpr();
												if (yymsp[0].minor.yy350->isLiteral())
													yygotominor.yy252->initLiteral(yymsp[0].minor.yy350->toLiteral());
												else
													yygotominor.yy252->initId(yymsp[0].minor.yy350->toName());
													//parserContext->errorBeforeLastToken("Syntax error <expected literal value>");

                                                delete yymsp[0].minor.yy350;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 294: /* exprx ::= tnm DOT nm */
{
                                                yygotominor.yy252 = new SqliteExpr();
												if (yymsp[-2].minor.yy350->isName())
													yygotominor.yy252->initId(yymsp[-2].minor.yy350->toName(), *(yymsp[0].minor.yy259));
												else
													parserContext->errorAtToken("Syntax error <expected name>", -3);

                                                delete yymsp[-2].minor.yy350;
                                                delete yymsp[0].minor.yy259;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 295: /* exprx ::= tnm DOT */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                objectForTokens = yygotominor.yy252;
                                                if (yymsp[-1].minor.yy350->isName())
                                                {
                                                    yygotominor.yy252->initId(yymsp[-1].minor.yy350->toName(), QString());
                                                    parserContext->minorErrorAfterLastToken("Syntax error <expr>");
                                                }
                                                else
                                                    parserContext->errorAtToken("Syntax error <expected name>", -3);

                                                delete yymsp[-1].minor.yy350;
                                            }
        break;
      case 296: /* exprx ::= tnm DOT nm DOT nm */
{
                                                yygotominor.yy252 = new SqliteExpr();
												if (yymsp[-4].minor.yy350->isName())
													yygotominor.yy252->initId(yymsp[-4].minor.yy350->toName(), *(yymsp[-2].minor.yy259), *(yymsp[0].minor.yy259));
												else
													parserContext->errorAtToken("Syntax error <expected name>", -5);

                                                delete yymsp[-4].minor.yy350;
                                                delete yymsp[-2].minor.yy259;
                                                delete yymsp[0].minor.yy259;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 297: /* exprx ::= tnm DOT nm DOT */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                objectForTokens = yygotominor.yy252;
                                                if (yymsp[-3].minor.yy350->isName())
                                                {
                                                    yygotominor.yy252->initId(yymsp[-3].minor.yy350->toName(), *(yymsp[-1].minor.yy259), QString());
                                                    parserContext->minorErrorAfterLastToken("Syntax error <expr>");
                                                }
                                                else
                                                    parserContext->errorAtToken("Syntax error <expected name>", -5);

                                                delete yymsp[-3].minor.yy350;
                                                delete yymsp[-1].minor.yy259;
                                            }
        break;
      case 298: /* exprx ::= VARIABLE */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initBindParam(yymsp[0].minor.yy0->value);
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 299: /* exprx ::= expr COLLATE ids */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initCollate(yymsp[-2].minor.yy252, *(yymsp[0].minor.yy259));
                                                delete yymsp[0].minor.yy259;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 300: /* exprx ::= CAST LP expr AS typetoken RP */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initCast(yymsp[-3].minor.yy252, yymsp[-1].minor.yy477);
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 301: /* exprx ::= id LP distinct exprlist RP */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initFunction(stripObjName(*(yymsp[-4].minor.yy259)), *(yymsp[-2].minor.yy346), *(yymsp[-1].minor.yy351));
                                                delete yymsp[-4].minor.yy259;
                                                delete yymsp[-2].minor.yy346;
                                                delete yymsp[-1].minor.yy351;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 302: /* exprx ::= id LP STAR RP */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initFunction(stripObjName(*(yymsp[-3].minor.yy259)), true);
                                                delete yymsp[-3].minor.yy259;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 303: /* exprx ::= expr AND expr */
      case 304: /* exprx ::= expr OR expr */ yytestcase(yyruleno==304);
      case 305: /* exprx ::= expr LT|GT|GE|LE expr */ yytestcase(yyruleno==305);
      case 306: /* exprx ::= expr EQ|NE expr */ yytestcase(yyruleno==306);
      case 307: /* exprx ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr */ yytestcase(yyruleno==307);
      case 308: /* exprx ::= expr PLUS|MINUS expr */ yytestcase(yyruleno==308);
      case 309: /* exprx ::= expr STAR|SLASH|REM expr */ yytestcase(yyruleno==309);
      case 310: /* exprx ::= expr CONCAT expr */ yytestcase(yyruleno==310);
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initBinOp(yymsp[-2].minor.yy252, yymsp[-1].minor.yy0->value, yymsp[0].minor.yy252);
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 311: /* exprx ::= expr not_opt likeop expr */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initLike(yymsp[-3].minor.yy252, *(yymsp[-2].minor.yy291), *(yymsp[-1].minor.yy100), yymsp[0].minor.yy252);
                                                delete yymsp[-2].minor.yy291;
                                                delete yymsp[-1].minor.yy100;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 312: /* exprx ::= expr not_opt likeop expr ESCAPE expr */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initLike(yymsp[-5].minor.yy252, *(yymsp[-4].minor.yy291), *(yymsp[-3].minor.yy100), yymsp[-2].minor.yy252, yymsp[0].minor.yy252);
                                                delete yymsp[-4].minor.yy291;
                                                delete yymsp[-3].minor.yy100;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 313: /* exprx ::= expr ISNULL|NOTNULL */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initNull(yymsp[-1].minor.yy252, yymsp[0].minor.yy0->value);
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 314: /* exprx ::= expr NOT NULL */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initNull(yymsp[-2].minor.yy252, "NOT NULL");
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 315: /* exprx ::= expr IS not_opt expr */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initIs(yymsp[-3].minor.yy252, *(yymsp[-1].minor.yy291), yymsp[0].minor.yy252);
                                                delete yymsp[-1].minor.yy291;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 316: /* exprx ::= expr IS NOT DISTINCT FROM expr */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initDistinct(yymsp[-5].minor.yy252, true, yymsp[0].minor.yy252);
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 317: /* exprx ::= expr IS DISTINCT FROM expr */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initDistinct(yymsp[-4].minor.yy252, false, yymsp[0].minor.yy252);
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 318: /* exprx ::= NOT expr */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initUnaryOp(yymsp[0].minor.yy252, yymsp[-1].minor.yy0->value);
                                            }
        break;
      case 319: /* exprx ::= BITNOT expr */
      case 321: /* exprx ::= PLUS expr */ yytestcase(yyruleno==321);
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initUnaryOp(yymsp[0].minor.yy252, yymsp[-1].minor.yy0->value);
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 320: /* exprx ::= MINUS expr */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                if (yymsp[0].minor.yy252->mode == SqliteExpr::Mode::LITERAL_VALUE &&
                                                    parserContext->isCandidateForMaxNegativeNumber() &&
                                                    yymsp[0].minor.yy252->literalValue == static_cast<qint64>(0L))
                                                {
                                                    yygotominor.yy252->initLiteral(std::numeric_limits<qint64>::min());
                                                    delete yymsp[0].minor.yy252;
                                                }
                                                else
                                                {
                                                    yygotominor.yy252->initUnaryOp(yymsp[0].minor.yy252, yymsp[-1].minor.yy0->value);
                                                }
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 322: /* exprx ::= expr PTR expr */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initPtrOp(yymsp[-2].minor.yy252, yymsp[-1].minor.yy0->value, yymsp[0].minor.yy252);
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 323: /* exprx ::= expr not_opt BETWEEN expr AND expr */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initBetween(yymsp[-5].minor.yy252, *(yymsp[-4].minor.yy291), yymsp[-2].minor.yy252, yymsp[0].minor.yy252);
                                                delete yymsp[-4].minor.yy291;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 324: /* exprx ::= expr not_opt IN LP exprlist RP */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initIn(yymsp[-5].minor.yy252, *(yymsp[-4].minor.yy291), *(yymsp[-1].minor.yy351));
                                                delete yymsp[-4].minor.yy291;
                                                delete yymsp[-1].minor.yy351;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 325: /* exprx ::= LP select RP */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initSubSelect(yymsp[-1].minor.yy453);
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 326: /* exprx ::= expr not_opt IN LP select RP */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initIn(yymsp[-5].minor.yy252, *(yymsp[-4].minor.yy291), yymsp[-1].minor.yy453);
                                                delete yymsp[-4].minor.yy291;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 327: /* exprx ::= expr not_opt IN nm dbnm */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initIn(yymsp[-4].minor.yy252, *(yymsp[-3].minor.yy291), *(yymsp[-1].minor.yy259), *(yymsp[0].minor.yy259));
                                                delete yymsp[-3].minor.yy291;
                                                delete yymsp[-1].minor.yy259;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 328: /* exprx ::= EXISTS LP select RP */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initExists(yymsp[-1].minor.yy453);
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 329: /* exprx ::= CASE case_operand case_exprlist case_else END */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initCase(yymsp[-3].minor.yy252, *(yymsp[-2].minor.yy351), yymsp[-1].minor.yy252);
                                                delete yymsp[-2].minor.yy351;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 330: /* exprx ::= RAISE LP IGNORE RP */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initRaise(yymsp[-1].minor.yy0->value);
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 331: /* exprx ::= RAISE LP raisetype COMMA nm RP */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initRaise(yymsp[-3].minor.yy0->value, *(yymsp[-1].minor.yy259));
                                                delete yymsp[-1].minor.yy259;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 332: /* exprx ::= id LP distinct exprlist RP filter_over */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initWindowFunction(stripObjName(*(yymsp[-5].minor.yy259)), *(yymsp[-3].minor.yy346), *(yymsp[-2].minor.yy351), yymsp[0].minor.yy247);
                                                delete yymsp[-5].minor.yy259;
                                                delete yymsp[-3].minor.yy346;
                                                delete yymsp[-2].minor.yy351;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 333: /* exprx ::= id LP STAR RP filter_over */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                yygotominor.yy252->initWindowFunction(stripObjName(*(yymsp[-4].minor.yy259)), yymsp[0].minor.yy247);
                                                delete yymsp[-4].minor.yy259;
                                                objectForTokens = yygotominor.yy252;
                                            }
        break;
      case 334: /* expr ::= */
{
                                                yygotominor.yy252 = new SqliteExpr();
                                                objectForTokens = yygotominor.yy252;
                                                parserContext->minorErrorAfterLastToken("Syntax error <expr>");
                                            }
        break;
      case 340: /* likeop ::= LIKE_KW|MATCH */
{yygotominor.yy100 = new SqliteExpr::LikeOp(SqliteExpr::likeOp(yymsp[0].minor.yy0->value));}
        break;
      case 341: /* case_exprlist ::= case_exprlist WHEN expr THEN expr */
{
                                                yymsp[-4].minor.yy351->append(yymsp[-2].minor.yy252);
                                                yymsp[-4].minor.yy351->append(yymsp[0].minor.yy252);
                                                yygotominor.yy351 = yymsp[-4].minor.yy351;
                                            }
        break;
      case 342: /* case_exprlist ::= WHEN expr THEN expr */
{
                                                yygotominor.yy351 = new ParserExprList();
                                                yygotominor.yy351->append(yymsp[-2].minor.yy252);
                                                yygotominor.yy351->append(yymsp[0].minor.yy252);
                                            }
        break;
      case 349: /* nexprlist ::= nexprlist COMMA expr */
{
                                                yymsp[-2].minor.yy351->append(yymsp[0].minor.yy252);
                                                yygotominor.yy351 = yymsp[-2].minor.yy351;
                                                DONT_INHERIT_TOKENS("nexprlist");
                                            }
        break;
      case 350: /* nexprlist ::= exprx */
{
                                                yygotominor.yy351 = new ParserExprList();
                                                yygotominor.yy351->append(yymsp[0].minor.yy252);
                                            }
        break;
      case 351: /* cmd ::= CREATE uniqueflag INDEX ifnotexists nm dbnm ON nm LP sortlist RP where_opt */
{
                                                yygotominor.yy443 = new SqliteCreateIndex(
                                                        *(yymsp[-10].minor.yy291),
                                                        *(yymsp[-8].minor.yy291),
                                                        *(yymsp[-7].minor.yy259),
                                                        *(yymsp[-6].minor.yy259),
                                                        *(yymsp[-4].minor.yy259),
                                                        *(yymsp[-2].minor.yy543),
                                                        yymsp[0].minor.yy252
                                                    );
                                                delete yymsp[-8].minor.yy291;
                                                delete yymsp[-10].minor.yy291;
                                                delete yymsp[-7].minor.yy259;
                                                delete yymsp[-6].minor.yy259;
                                                delete yymsp[-4].minor.yy259;
                                                delete yymsp[-2].minor.yy543;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 352: /* cmd ::= CREATE uniqueflag INDEX ifnotexists nm dbnm ON ID_TAB */
{  yy_destructor(yypParser,203,&yymsp[-3].minor);
}
        break;
      case 357: /* idxlist_opt ::= */
{yygotominor.yy123 = new ParserIndexedColumnList();}
        break;
      case 358: /* idxlist_opt ::= LP idxlist RP */
{yygotominor.yy123 = yymsp[-1].minor.yy123;}
        break;
      case 359: /* idxlist ::= idxlist COMMA idxlist_single */
{
                                                yymsp[-2].minor.yy123->append(yymsp[0].minor.yy608);
                                                yygotominor.yy123 = yymsp[-2].minor.yy123;
                                                DONT_INHERIT_TOKENS("idxlist");
                                            }
        break;
      case 360: /* idxlist ::= idxlist_single */
{
                                                yygotominor.yy123 = new ParserIndexedColumnList();
                                                yygotominor.yy123->append(yymsp[0].minor.yy608);
                                            }
        break;
      case 361: /* idxlist_single ::= nm collate sortorder */
      case 362: /* idxlist_single ::= ID_COL */ yytestcase(yyruleno==362);
{
                                                SqliteIndexedColumn* obj =
                                                    new SqliteIndexedColumn(
                                                        *(yymsp[-2].minor.yy259),
                                                        *(yymsp[-1].minor.yy259),
                                                        *(yymsp[0].minor.yy389)
                                                    );
                                                yygotominor.yy608 = obj;
                                                delete yymsp[0].minor.yy389;
                                                delete yymsp[-2].minor.yy259;
                                                delete yymsp[-1].minor.yy259;
                                                objectForTokens = yygotominor.yy608;
                                            }
        break;
      case 366: /* cmd ::= DROP INDEX ifexists fullname */
{
                                                yygotominor.yy443 = new SqliteDropIndex(*(yymsp[-1].minor.yy291), yymsp[0].minor.yy60->name1, yymsp[0].minor.yy60->name2);
                                                delete yymsp[-1].minor.yy291;
                                                delete yymsp[0].minor.yy60;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 369: /* cmd ::= VACUUM vinto */
{
                                                yygotominor.yy443 = new SqliteVacuum(yymsp[0].minor.yy252);
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 370: /* cmd ::= VACUUM nm vinto */
{
                                                yygotominor.yy443 = new SqliteVacuum(*(yymsp[-1].minor.yy259), yymsp[0].minor.yy252);
                                                delete yymsp[-1].minor.yy259;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 373: /* cmd ::= PRAGMA nm dbnm */
{
                                                yygotominor.yy443 = new SqlitePragma(*(yymsp[-1].minor.yy259), *(yymsp[0].minor.yy259));
                                                delete yymsp[-1].minor.yy259;
                                                delete yymsp[0].minor.yy259;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 374: /* cmd ::= PRAGMA nm dbnm EQ nmnum */
      case 376: /* cmd ::= PRAGMA nm dbnm EQ minus_num */ yytestcase(yyruleno==376);
{
                                                yygotominor.yy443 = new SqlitePragma(*(yymsp[-3].minor.yy259), *(yymsp[-2].minor.yy259), *(yymsp[0].minor.yy249), true);
                                                delete yymsp[-3].minor.yy259;
                                                delete yymsp[-2].minor.yy259;
                                                delete yymsp[0].minor.yy249;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 375: /* cmd ::= PRAGMA nm dbnm LP nmnum RP */
      case 377: /* cmd ::= PRAGMA nm dbnm LP minus_num RP */ yytestcase(yyruleno==377);
{
                                                yygotominor.yy443 = new SqlitePragma(*(yymsp[-4].minor.yy259), *(yymsp[-3].minor.yy259), *(yymsp[-1].minor.yy249), false);
                                                delete yymsp[-4].minor.yy259;
                                                delete yymsp[-3].minor.yy259;
                                                delete yymsp[-1].minor.yy249;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 381: /* nmnum ::= nm */
{
                                                yygotominor.yy249 = new QVariant(*(yymsp[0].minor.yy259));
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 382: /* nmnum ::= ON */
      case 383: /* nmnum ::= DELETE */ yytestcase(yyruleno==383);
      case 384: /* nmnum ::= DEFAULT */ yytestcase(yyruleno==384);
{yygotominor.yy249 = new QVariant(yymsp[0].minor.yy0->value);}
        break;
      case 387: /* minus_num ::= MINUS number */
{
                                                if (yymsp[0].minor.yy249->type() == QVariant::Double)
                                                    *(yymsp[0].minor.yy249) = -(yymsp[0].minor.yy249->toDouble());
                                                else if (yymsp[0].minor.yy249->type() == QVariant::LongLong)
                                                {
                                                    if (parserContext->isCandidateForMaxNegativeNumber())
                                                        *(yymsp[0].minor.yy249) = std::numeric_limits<qint64>::min();
                                                    else
                                                        *(yymsp[0].minor.yy249) = -(yymsp[0].minor.yy249->toLongLong());
                                                }
                                                else
                                                    Q_ASSERT_X(true, "producing minus number", "QVariant is neither of Double or LongLong.");

                                                yygotominor.yy249 = yymsp[0].minor.yy249;
                                            }
        break;
      case 390: /* cmd ::= CREATE temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON nm foreach_clause when_clause BEGIN trigger_cmd_list END */
{
                                                yygotominor.yy443 = new SqliteCreateTrigger(
                                                        *(yymsp[-13].minor.yy346),
                                                        *(yymsp[-11].minor.yy291),
                                                        *(yymsp[-10].minor.yy259),
                                                        *(yymsp[-9].minor.yy259),
                                                        *(yymsp[-5].minor.yy259),
                                                        *(yymsp[-8].minor.yy372),
                                                        yymsp[-7].minor.yy331,
                                                        *(yymsp[-4].minor.yy323),
                                                        yymsp[-3].minor.yy252,
                                                        *(yymsp[-1].minor.yy330),
                                                        3
                                                    );
                                                delete yymsp[-11].minor.yy291;
                                                delete yymsp[-13].minor.yy346;
                                                delete yymsp[-8].minor.yy372;
                                                delete yymsp[-4].minor.yy323;
                                                delete yymsp[-10].minor.yy259;
                                                delete yymsp[-5].minor.yy259;
                                                delete yymsp[-9].minor.yy259;
                                                delete yymsp[-1].minor.yy330;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 391: /* cmd ::= CREATE temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON nm foreach_clause when_clause */
{
                                                QList<SqliteQuery *> CL;

                                                yygotominor.yy443 = new SqliteCreateTrigger(
                                                        *(yymsp[-10].minor.yy346),
                                                        *(yymsp[-8].minor.yy291),
                                                        *(yymsp[-7].minor.yy259),
                                                        *(yymsp[-6].minor.yy259),
                                                        *(yymsp[-2].minor.yy259),
                                                        *(yymsp[-5].minor.yy372),
                                                        yymsp[-4].minor.yy331,
                                                        *(yymsp[-1].minor.yy323),
                                                        yymsp[0].minor.yy252,
                                                        CL,
                                                        3
                                                    );
                                                delete yymsp[-8].minor.yy291;
                                                delete yymsp[-10].minor.yy346;
                                                delete yymsp[-5].minor.yy372;
                                                delete yymsp[-1].minor.yy323;
                                                delete yymsp[-7].minor.yy259;
                                                delete yymsp[-2].minor.yy259;
                                                delete yymsp[-6].minor.yy259;
                                                objectForTokens = yygotominor.yy443;
                                                parserContext->minorErrorAfterLastToken("Syntax error");
                                            }
        break;
      case 392: /* cmd ::= CREATE temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON nm foreach_clause when_clause BEGIN trigger_cmd_list */
{
                                                yygotominor.yy443 = new SqliteCreateTrigger(
													*(yymsp[-12].minor.yy346),
													*(yymsp[-10].minor.yy291),
													*(yymsp[-9].minor.yy259),
													*(yymsp[-8].minor.yy259),
													*(yymsp[-4].minor.yy259),
													*(yymsp[-7].minor.yy372),
													yymsp[-6].minor.yy331,
													*(yymsp[-3].minor.yy323),
													yymsp[-2].minor.yy252,
													*(yymsp[0].minor.yy330),
													3
                                                );
                                                delete yymsp[-10].minor.yy291;
                                                delete yymsp[-12].minor.yy346;
                                                delete yymsp[-7].minor.yy372;
                                                delete yymsp[-3].minor.yy323;
                                                delete yymsp[-9].minor.yy259;
                                                delete yymsp[-4].minor.yy259;
                                                delete yymsp[-8].minor.yy259;
                                                delete yymsp[0].minor.yy330;
                                                objectForTokens = yygotominor.yy443;
                                                parserContext->minorErrorAfterLastToken("Syntax error");
                                            }
        break;
      case 393: /* cmd ::= CREATE temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON ID_TAB */
{  yy_destructor(yypParser,205,&yymsp[-8].minor);
  yy_destructor(yypParser,203,&yymsp[-5].minor);
  yy_destructor(yypParser,301,&yymsp[-3].minor);
  yy_destructor(yypParser,302,&yymsp[-2].minor);
}
        break;
      case 396: /* trigger_time ::= BEFORE */
{yygotominor.yy372 = new SqliteCreateTrigger::Time(SqliteCreateTrigger::Time::BEFORE);}
        break;
      case 397: /* trigger_time ::= AFTER */
{yygotominor.yy372 = new SqliteCreateTrigger::Time(SqliteCreateTrigger::Time::AFTER);}
        break;
      case 398: /* trigger_time ::= INSTEAD OF */
{yygotominor.yy372 = new SqliteCreateTrigger::Time(SqliteCreateTrigger::Time::INSTEAD_OF);}
        break;
      case 399: /* trigger_time ::= */
{yygotominor.yy372 = new SqliteCreateTrigger::Time(SqliteCreateTrigger::Time::null);}
        break;
      case 400: /* trigger_event ::= DELETE */
{
                                                yygotominor.yy331 = new SqliteCreateTrigger::Event(SqliteCreateTrigger::Event::DELETE);
                                                objectForTokens = yygotominor.yy331;
                                            }
        break;
      case 401: /* trigger_event ::= INSERT */
{
                                                yygotominor.yy331 = new SqliteCreateTrigger::Event(SqliteCreateTrigger::Event::INSERT);
                                                objectForTokens = yygotominor.yy331;
                                            }
        break;
      case 402: /* trigger_event ::= UPDATE */
{
                                                yygotominor.yy331 = new SqliteCreateTrigger::Event(SqliteCreateTrigger::Event::UPDATE);
                                                objectForTokens = yygotominor.yy331;
                                            }
        break;
      case 403: /* trigger_event ::= UPDATE OF idlist */
{
                                                yygotominor.yy331 = new SqliteCreateTrigger::Event(*(yymsp[0].minor.yy215));
                                                delete yymsp[0].minor.yy215;
                                                objectForTokens = yygotominor.yy331;
                                            }
        break;
      case 404: /* foreach_clause ::= */
{yygotominor.yy323 = new SqliteCreateTrigger::Scope(SqliteCreateTrigger::Scope::null);}
        break;
      case 405: /* foreach_clause ::= FOR EACH ROW */
{yygotominor.yy323 = new SqliteCreateTrigger::Scope(SqliteCreateTrigger::Scope::FOR_EACH_ROW);}
        break;
      case 408: /* trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI */
{
                                                yymsp[-2].minor.yy330->append(yymsp[-1].minor.yy443);
                                                yygotominor.yy330 = yymsp[-2].minor.yy330;
                                                DONT_INHERIT_TOKENS("trigger_cmd_list");
                                            }
        break;
      case 409: /* trigger_cmd_list ::= trigger_cmd SEMI */
{
                                                yygotominor.yy330 = new ParserQueryList();
                                                yygotominor.yy330->append(yymsp[-1].minor.yy443);
                                            }
        break;
      case 410: /* trigger_cmd_list ::= SEMI */
{
                                                yygotominor.yy330 = new ParserQueryList();
                                                parserContext->minorErrorAfterLastToken("Syntax error");
                                            }
        break;
      case 415: /* raisetype ::= ROLLBACK|ABORT|FAIL */
{yygotominor.yy0 = yymsp[0].minor.yy0;}
        break;
      case 416: /* cmd ::= DROP TRIGGER ifexists fullname */
{
                                                yygotominor.yy443 = new SqliteDropTrigger(*(yymsp[-1].minor.yy291), yymsp[0].minor.yy60->name1, yymsp[0].minor.yy60->name2);
                                                delete yymsp[-1].minor.yy291;
                                                delete yymsp[0].minor.yy60;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 419: /* cmd ::= ATTACH database_kw_opt expr AS expr key_opt */
{
                                                yygotominor.yy443 = new SqliteAttach(*(yymsp[-4].minor.yy291), yymsp[-3].minor.yy252, yymsp[-1].minor.yy252, yymsp[0].minor.yy252);
                                                delete yymsp[-4].minor.yy291;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 420: /* cmd ::= DETACH database_kw_opt expr */
{
                                                yygotominor.yy443 = new SqliteDetach(*(yymsp[-1].minor.yy291), yymsp[0].minor.yy252);
                                                delete yymsp[-1].minor.yy291;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 425: /* cmd ::= REINDEX */
{yygotominor.yy443 = new SqliteReindex();}
        break;
      case 426: /* cmd ::= REINDEX nm dbnm */
      case 427: /* cmd ::= REINDEX ID_COLLATE */ yytestcase(yyruleno==427);
{
                                                yygotominor.yy443 = new SqliteReindex(*(yymsp[-1].minor.yy259), *(yymsp[0].minor.yy259));
                                                delete yymsp[-1].minor.yy259;
                                                delete yymsp[0].minor.yy259;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 430: /* cmd ::= ANALYZE */
{
                                                yygotominor.yy443 = new SqliteAnalyze();
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 431: /* cmd ::= ANALYZE nm dbnm */
{
                                                yygotominor.yy443 = new SqliteAnalyze(*(yymsp[-1].minor.yy259), *(yymsp[0].minor.yy259));
                                                delete yymsp[-1].minor.yy259;
                                                delete yymsp[0].minor.yy259;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 434: /* cmd ::= ALTER TABLE fullname RENAME TO nm */
{
                                                yygotominor.yy443 = new SqliteAlterTable(
                                                        yymsp[-3].minor.yy60->name1,
                                                        yymsp[-3].minor.yy60->name2,
                                                        *(yymsp[0].minor.yy259)
                                                    );
                                                delete yymsp[0].minor.yy259;
                                                delete yymsp[-3].minor.yy60;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 435: /* cmd ::= ALTER TABLE fullname ADD kwcolumn_opt column */
{
                                                yygotominor.yy443 = new SqliteAlterTable(
                                                        yymsp[-3].minor.yy60->name1,
                                                        yymsp[-3].minor.yy60->name2,
                                                        *(yymsp[-1].minor.yy291),
                                                        yymsp[0].minor.yy567
                                                    );
                                                delete yymsp[-1].minor.yy291;
                                                delete yymsp[-3].minor.yy60;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 436: /* cmd ::= ALTER TABLE fullname DROP kwcolumn_opt nm */
{
                                                yygotominor.yy443 = new SqliteAlterTable(
                                                        yymsp[-3].minor.yy60->name1,
                                                        yymsp[-3].minor.yy60->name2,
                                                        *(yymsp[-1].minor.yy291),
                                                        *(yymsp[0].minor.yy259)
                                                    );
                                                delete yymsp[-1].minor.yy291;
                                                delete yymsp[-3].minor.yy60;
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 437: /* cmd ::= ALTER TABLE fullname RENAME TO ID_TAB_NEW */
{  yy_destructor(yypParser,207,&yymsp[-3].minor);
}
        break;
      case 443: /* create_vtab ::= CREATE VIRTUAL TABLE ifnotexists nm dbnm USING nm */
{
                                                yygotominor.yy443 = new SqliteCreateVirtualTable(
                                                        *(yymsp[-4].minor.yy291),
                                                        *(yymsp[-3].minor.yy259),
                                                        *(yymsp[-2].minor.yy259),
                                                        *(yymsp[0].minor.yy259)
                                                    );
                                                delete yymsp[-4].minor.yy291;
                                                delete yymsp[-3].minor.yy259;
                                                delete yymsp[-2].minor.yy259;
                                                delete yymsp[0].minor.yy259;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 444: /* create_vtab ::= CREATE VIRTUAL TABLE ifnotexists nm dbnm USING nm LP vtabarglist RP */
{
                                                yygotominor.yy443 = new SqliteCreateVirtualTable(
                                                        *(yymsp[-7].minor.yy291),
                                                        *(yymsp[-6].minor.yy259),
                                                        *(yymsp[-5].minor.yy259),
                                                        *(yymsp[-3].minor.yy259),
                                                        *(yymsp[-1].minor.yy215)
                                                    );
                                                delete yymsp[-6].minor.yy259;
                                                delete yymsp[-5].minor.yy259;
                                                delete yymsp[-3].minor.yy259;
                                                delete yymsp[-7].minor.yy291;
                                                delete yymsp[-1].minor.yy215;
                                                objectForTokens = yygotominor.yy443;
                                            }
        break;
      case 447: /* vtabarglist ::= vtabarg */
{
                                                yygotominor.yy215 = new QStringList();
                                                yygotominor.yy215->append((yymsp[0].minor.yy259)->mid(1)); // mid(1) to skip the first whitespace added in vtabarg
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 448: /* vtabarglist ::= vtabarglist COMMA vtabarg */
{
                                                yymsp[-2].minor.yy215->append((yymsp[0].minor.yy259)->mid(1)); // mid(1) to skip the first whitespace added in vtabarg
                                                yygotominor.yy215 = yymsp[-2].minor.yy215;
                                                delete yymsp[0].minor.yy259;
                                                DONT_INHERIT_TOKENS("vtabarglist");
                                            }
        break;
      case 450: /* vtabarg ::= vtabarg vtabargtoken */
{
                                                yymsp[-1].minor.yy259->append(" "+ *(yymsp[0].minor.yy259));
                                                yygotominor.yy259 = yymsp[-1].minor.yy259;
                                                delete yymsp[0].minor.yy259;
                                            }
        break;
      case 451: /* vtabargtoken ::= ANY */
{
                                                yygotominor.yy259 = new QString(yymsp[0].minor.yy0->value);
                                            }
        break;
      case 452: /* vtabargtoken ::= LP anylist RP */
{
                                                yygotominor.yy259 = new QString("(");
                                                yygotominor.yy259->append(*(yymsp[-1].minor.yy259));
                                                yygotominor.yy259->append(")");
                                                delete yymsp[-1].minor.yy259;
                                            }
        break;
      case 454: /* anylist ::= anylist LP anylist RP */
{
                                                yygotominor.yy259 = yymsp[-3].minor.yy259;
                                                yygotominor.yy259->append("(");
                                                yygotominor.yy259->append(*(yymsp[-1].minor.yy259));
                                                yygotominor.yy259->append(")");
                                                delete yymsp[-1].minor.yy259;
                                                DONT_INHERIT_TOKENS("anylist");
                                            }
        break;
      case 455: /* anylist ::= anylist ANY */
{
                                                yygotominor.yy259 = yymsp[-1].minor.yy259;
                                                yygotominor.yy259->append(yymsp[0].minor.yy0->value);
                                                DONT_INHERIT_TOKENS("anylist");
                                            }
        break;
      case 456: /* with ::= */
{yygotominor.yy641 = nullptr;}
        break;
      case 457: /* with ::= WITH wqlist */
{
                                                yygotominor.yy641 = new SqliteWith();
												yygotominor.yy641->cteList = *(yymsp[0].minor.yy332);
												delete yymsp[0].minor.yy332;
                                                objectForTokens = yygotominor.yy641;
                                            }
        break;
      case 458: /* with ::= WITH RECURSIVE wqlist */
{
                                                yygotominor.yy641 = new SqliteWith();
												yygotominor.yy641->cteList = *(yymsp[0].minor.yy332);
                                                yygotominor.yy641->recursive = true;
												delete yymsp[0].minor.yy332;
                                                objectForTokens = yygotominor.yy641;
                                            }
        break;
      case 459: /* wqas ::= AS */
{yygotominor.yy640 = new SqliteWith::CommonTableExpression::AsMode(SqliteWith::CommonTableExpression::ANY);}
        break;
      case 460: /* wqas ::= AS MATERIALIZED */
{yygotominor.yy640 = new SqliteWith::CommonTableExpression::AsMode(SqliteWith::CommonTableExpression::MATERIALIZED);}
        break;
      case 461: /* wqas ::= AS NOT MATERIALIZED */
{yygotominor.yy640 = new SqliteWith::CommonTableExpression::AsMode(SqliteWith::CommonTableExpression::NOT_MATERIALIZED);}
        break;
      case 462: /* wqlist ::= wqcte */
{
												yygotominor.yy332 = new ParserCteList();
                                                yygotominor.yy332->append(yymsp[0].minor.yy446);
                                            }
        break;
      case 463: /* wqlist ::= wqlist COMMA wqcte */
{
                                                yygotominor.yy332 = yymsp[-2].minor.yy332;
                                                yygotominor.yy332->append(yymsp[0].minor.yy446);
                                                DONT_INHERIT_TOKENS("wqlist");
                                            }
        break;
      case 464: /* wqlist ::= ID_TAB_NEW */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                            }
        break;
      case 465: /* wqcte ::= nm idxlist_opt wqas LP select RP */
{
                                                yygotominor.yy446 = new SqliteWith::CommonTableExpression(*(yymsp[-5].minor.yy259), *(yymsp[-4].minor.yy123), yymsp[-1].minor.yy453, *(yymsp[-3].minor.yy640));
                                                delete yymsp[-5].minor.yy259;
                                                delete yymsp[-4].minor.yy123;
                                                delete yymsp[-3].minor.yy640;
												objectForTokens = yygotominor.yy446;
											}
        break;
      case 466: /* windowdefn_list ::= windowdefn */
{
												yygotominor.yy639 = new ParserWindowDefList();
												yygotominor.yy639->append(yymsp[0].minor.yy646);
											}
        break;
      case 467: /* windowdefn_list ::= windowdefn_list COMMA windowdefn */
{
												yymsp[-2].minor.yy639->append(yymsp[0].minor.yy646);
												yygotominor.yy639 = yymsp[-2].minor.yy639;
												DONT_INHERIT_TOKENS("windowdefn_list");
											}
        break;
      case 468: /* windowdefn ::= nm AS LP window RP */
{
												yygotominor.yy646 = new SqliteWindowDefinition(*(yymsp[-4].minor.yy259), yymsp[-1].minor.yy234);
												delete yymsp[-4].minor.yy259;
												objectForTokens = yygotominor.yy646;
											}
        break;
      case 469: /* window ::= PARTITION BY nexprlist orderby_opt frame_opt */
{
												yygotominor.yy234 = new SqliteWindowDefinition::Window();
												yygotominor.yy234->initPartitionBy(QString(), *(yymsp[-2].minor.yy351), *(yymsp[-1].minor.yy543), yymsp[0].minor.yy41);
												delete yymsp[-2].minor.yy351;
												delete yymsp[-1].minor.yy543;
												objectForTokens = yygotominor.yy234;
											}
        break;
      case 470: /* window ::= nm PARTITION BY nexprlist orderby_opt frame_opt */
{
												yygotominor.yy234 = new SqliteWindowDefinition::Window();
												yygotominor.yy234->initPartitionBy(*(yymsp[-5].minor.yy259), *(yymsp[-2].minor.yy351), *(yymsp[-1].minor.yy543), yymsp[0].minor.yy41);
												delete yymsp[-2].minor.yy351;
												delete yymsp[-5].minor.yy259;
												delete yymsp[-1].minor.yy543;
												objectForTokens = yygotominor.yy234;
											}
        break;
      case 471: /* window ::= ORDER BY sortlist frame_opt */
{
												yygotominor.yy234 = new SqliteWindowDefinition::Window();
												yygotominor.yy234->initOrderBy(QString(), *(yymsp[-1].minor.yy543), yymsp[0].minor.yy41);
												delete yymsp[-1].minor.yy543;
												objectForTokens = yygotominor.yy234;
											}
        break;
      case 472: /* window ::= nm ORDER BY sortlist frame_opt */
{
												yygotominor.yy234 = new SqliteWindowDefinition::Window();
												yygotominor.yy234->initOrderBy(*(yymsp[-4].minor.yy259), *(yymsp[-1].minor.yy543), yymsp[0].minor.yy41);
												delete yymsp[-1].minor.yy543;
												delete yymsp[-4].minor.yy259;
												objectForTokens = yygotominor.yy234;
											}
        break;
      case 473: /* window ::= frame_opt */
{
												yygotominor.yy234 = new SqliteWindowDefinition::Window();
												yygotominor.yy234->init(QString(), yymsp[0].minor.yy41);
												objectForTokens = yygotominor.yy234;
											}
        break;
      case 474: /* window ::= nm frame_opt */
{
												yygotominor.yy234 = new SqliteWindowDefinition::Window();
												yygotominor.yy234->init(QString(), yymsp[0].minor.yy41);
												delete yymsp[-1].minor.yy259;
												objectForTokens = yygotominor.yy234;
											}
        break;
      case 475: /* frame_opt ::= */
{yygotominor.yy41 = nullptr;}
        break;
      case 476: /* frame_opt ::= range_or_rows frame_bound_s frame_exclude_opt */
{
												yygotominor.yy41 = new SqliteWindowDefinition::Window::Frame(*(yymsp[-2].minor.yy358), yymsp[-1].minor.yy81, nullptr, *(yymsp[0].minor.yy603));
												delete yymsp[-2].minor.yy358;
												delete yymsp[0].minor.yy603;
												objectForTokens = yygotominor.yy41;
											}
        break;
      case 477: /* frame_opt ::= range_or_rows BETWEEN frame_bound_s AND frame_bound_e frame_exclude_opt */
{
												yygotominor.yy41 = new SqliteWindowDefinition::Window::Frame(*(yymsp[-5].minor.yy358), yymsp[-3].minor.yy81, yymsp[-1].minor.yy81, *(yymsp[0].minor.yy603));
												delete yymsp[-5].minor.yy358;
												delete yymsp[0].minor.yy603;
												objectForTokens = yygotominor.yy41;
											}
        break;
      case 478: /* range_or_rows ::= RANGE|ROWS|GROUPS */
{
												yygotominor.yy358 = new SqliteWindowDefinition::Window::Frame::RangeOrRows(
													SqliteWindowDefinition::Window::Frame::toRangeOrRows(yymsp[0].minor.yy0->value)
													);
											}
        break;
      case 479: /* frame_bound_s ::= frame_bound */
      case 481: /* frame_bound_e ::= frame_bound */ yytestcase(yyruleno==481);
{
												yygotominor.yy81 = yymsp[0].minor.yy81;
												objectForTokens = yygotominor.yy81;
											}
        break;
      case 480: /* frame_bound_s ::= UNBOUNDED PRECEDING */
      case 482: /* frame_bound_e ::= UNBOUNDED FOLLOWING */ yytestcase(yyruleno==482);
      case 484: /* frame_bound ::= CURRENT ROW */ yytestcase(yyruleno==484);
{
												yygotominor.yy81 = new SqliteWindowDefinition::Window::Frame::Bound(nullptr, yymsp[-1].minor.yy0->value + " " + yymsp[0].minor.yy0->value);
												objectForTokens = yygotominor.yy81;
											}
        break;
      case 483: /* frame_bound ::= expr PRECEDING|FOLLOWING */
{
												yygotominor.yy81 = new SqliteWindowDefinition::Window::Frame::Bound(yymsp[-1].minor.yy252, yymsp[0].minor.yy0->value);
												objectForTokens = yygotominor.yy81;
											}
        break;
      case 485: /* frame_exclude_opt ::= */
{
												yygotominor.yy603 = new SqliteWindowDefinition::Window::Frame::Exclude(
													SqliteWindowDefinition::Window::Frame::Exclude::null
													);
											}
        break;
      case 486: /* frame_exclude_opt ::= EXCLUDE frame_exclude */
{
												yygotominor.yy603 = yymsp[0].minor.yy603;
											}
        break;
      case 487: /* frame_exclude ::= NO OTHERS */
{
												yygotominor.yy603 = new SqliteWindowDefinition::Window::Frame::Exclude(
													SqliteWindowDefinition::Window::Frame::Exclude::NO_OTHERS
													);
											}
        break;
      case 488: /* frame_exclude ::= CURRENT ROW */
{
												yygotominor.yy603 = new SqliteWindowDefinition::Window::Frame::Exclude(
													SqliteWindowDefinition::Window::Frame::Exclude::CURRENT_ROW
													);
											}
        break;
      case 489: /* frame_exclude ::= GROUP */
{
												yygotominor.yy603 = new SqliteWindowDefinition::Window::Frame::Exclude(
													SqliteWindowDefinition::Window::Frame::Exclude::GROUP
													);
											}
        break;
      case 490: /* frame_exclude ::= TIES */
{
												yygotominor.yy603 = new SqliteWindowDefinition::Window::Frame::Exclude(
													SqliteWindowDefinition::Window::Frame::Exclude::TIES
													);
											}
        break;
      case 491: /* window_clause ::= WINDOW windowdefn_list */
{
												yygotominor.yy639 = yymsp[0].minor.yy639;
											}
        break;
      case 492: /* filter_over ::= filter_clause over_clause */
{
												yygotominor.yy247 = new SqliteFilterOver(yymsp[-1].minor.yy657, yymsp[0].minor.yy288);
												objectForTokens = yygotominor.yy247;
											}
        break;
      case 493: /* filter_over ::= over_clause */
{
												yygotominor.yy247 = new SqliteFilterOver(nullptr, yymsp[0].minor.yy288);
												objectForTokens = yygotominor.yy247;
											}
        break;
      case 494: /* filter_over ::= filter_clause */
{
												yygotominor.yy247 = new SqliteFilterOver(yymsp[0].minor.yy657, nullptr);
												objectForTokens = yygotominor.yy247;
											}
        break;
      case 495: /* over_clause ::= OVER LP window RP */
{
												yygotominor.yy288 = new SqliteFilterOver::Over(yymsp[-1].minor.yy234);
												objectForTokens = yygotominor.yy288;
											}
        break;
      case 496: /* over_clause ::= OVER nm */
{
												yygotominor.yy288 = new SqliteFilterOver::Over(*(yymsp[0].minor.yy259));
												delete yymsp[0].minor.yy259;
												objectForTokens = yygotominor.yy288;
											}
        break;
      case 497: /* filter_clause ::= FILTER LP WHERE expr RP */
{
												yygotominor.yy657 = new SqliteFilterOver::Filter(yymsp[-1].minor.yy252);
												objectForTokens = yygotominor.yy657;
                                            }
        break;
      default:
      /* (0) input ::= cmdlist */ yytestcase(yyruleno==0);
        break;
      };
  }
  assert( yyruleno>=0 && yyruleno<(int)(sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0])) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;

  // Store tokens for the rule in parser context
  QList<Token*> allTokens;
  QList<Token*> allTokensWithAllInherited;
  QString keyForTokensMap;
  int tokensMapKeyCnt;
  if (parserContext->setupTokens)
  {
      if (objectForTokens)
      {
          // In case this is a list with recurrent references we need
          // to clear tokens before adding the new and extended list.
          objectForTokens->tokens.clear();
      }

      QList<Token*> tokens;
      for (int i = yypParser->yyidx - yysize + 1; i <= yypParser->yyidx; i++)
      {
          tokens.clear();
          const char* fieldName = yyTokenName[yypParser->yystack[i].major];

          // Adding token being subject of this reduction. It's usually not includes in the inherited tokens,
          // although if inheriting from simple statements, like "FAIL" or "ROLLBACK", this tends to be redundant with the inherited tokens.
          // That's why we're checking if it's not contained in the inherited tokens and add it only then.
          if (parserContext->isManagedToken(yypParser->yystack[i].minor.yy0) && !yypParser->yystack[i].tokens->contains(yypParser->yystack[i].minor.yy0))
              tokens += yypParser->yystack[i].minor.yy0;

          tokens += *(yypParser->yystack[i].tokens);

          if (!noTokenInheritanceFields.contains(fieldName))
          {
              if (objectForTokens)
              {
                  keyForTokensMap = fieldName;
                  tokensMapKeyCnt = 2;
                  while (objectForTokens->tokensMap.contains(keyForTokensMap))
                      keyForTokensMap = fieldName + QString::number(tokensMapKeyCnt++);

                  objectForTokens->tokensMap[keyForTokensMap] = parserContext->getTokenPtrList(tokens);
              }

              allTokens += tokens;
          }
          else
          {
              // If field is mentioned only once, then only one occurance of it will be ignored.
              // Second one should be inherited. See "anylist" definition for explanation why.
              noTokenInheritanceFields.removeOne(fieldName);
          }
          allTokensWithAllInherited += tokens;
      }
      if (objectForTokens)
      {
          objectForTokens->tokens += parserContext->getTokenPtrList(allTokens);
      }
  }

  // Clear token lists
  for (int i = yypParser->yyidx - yysize + 1; i <= yypParser->yyidx; i++)
  {
      delete yypParser->yystack[i].tokens;
      yypParser->yystack[i].tokens = nullptr;
  }

  yypParser->yyidx -= yysize;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact < YYNSTATE ){
#ifdef NDEBUG
    /* If we are not debugging and the reduce action popped at least
    ** one element off the stack, then we can push the new element back
    ** onto the stack here, and skip the stack overflow test in yy_shift().
    ** That gives a significant speed improvement. */
    if( yysize ){
      yypParser->yyidx++;
      yymsp -= yysize-1;
      yymsp->stateno = (YYACTIONTYPE)yyact;
      yymsp->major = (YYCODETYPE)yygoto;
      yymsp->minor = yygotominor;
      if (parserContext->setupTokens)
          *(yypParser->yystack[yypParser->yyidx].tokens) = allTokens;
    }else
#endif
    {
      yy_shift(yypParser,yyact,yygoto,&yygotominor);
      if (parserContext->setupTokens && yypParser->yyidx >= 0)
      {
          QList<Token*>* tokensPtr = yypParser->yystack[yypParser->yyidx].tokens;
          *tokensPtr = allTokensWithAllInherited + *tokensPtr;
      }
    }
  }else{
    assert( yyact == YYNSTATE + YYNRULE + 1 );
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  sqlite3_parseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
  sqlite3_parseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  YYMINORTYPE yyminor            /* The minor type of the error token */
){
  sqlite3_parseARG_FETCH;
#define TOKEN (yyminor.yy0)

    UNUSED_PARAMETER(yymajor);
    parserContext->error(TOKEN, QObject::tr("Syntax error"));
    //qDebug() << "near " << TOKEN->toString() << ": syntax error";
  sqlite3_parseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  sqlite3_parseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
  sqlite3_parseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "sqlite3_parseAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void sqlite3_parse(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  sqlite3_parseTOKENTYPE yyminor       /* The value for the token */
  sqlite3_parseARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  int yyact;            /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  /* (re)initialize the parser, if necessary */
  yypParser = (yyParser*)yyp;
  if( yypParser->yyidx<0 ){
#if YYSTACKDEPTH<=0
    if( yypParser->yystksz <=0 ){
      /*memset(&yyminorunion, 0, sizeof(yyminorunion));*/
      yyminorunion = yyzerominor;
      yyStackOverflow(yypParser, &yyminorunion);
      return;
    }
#endif
    yypParser->yyidx = 0;
    yypParser->yyerrcnt = -1;
    yypParser->yystack[0].stateno = 0;
    yypParser->yystack[0].major = 0;
    yypParser->yystack[0].tokens = new QList<Token*>();
  }
  yyminorunion.yy0 = yyminor;
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  sqlite3_parseARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput %s [%s] (lemon type: %s)\n",
            yyTracePrompt,
            yyminor->value.toLatin1().data(),
            yyminor->typeString().toLatin1().data(),
            yyTokenName[yymajor]);  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact<YYNSTATE ){
      yy_shift(yypParser,yyact,yymajor,&yyminorunion);
      yypParser->yyerrcnt--;
      yymajor = YYNOCODE;
    }else if( yyact < YYNSTATE + YYNRULE ){
      yy_reduce(yypParser,yyact-YYNSTATE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yymx = yypParser->yystack[yypParser->yyidx].major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor,&yyminorunion);
        yymajor = YYNOCODE;
      }else{
         while(
          yypParser->yyidx >= 0 &&
          yymx != YYERRORSYMBOL &&
          (yyact = yy_find_reduce_action(
                        yypParser->yystack[yypParser->yyidx].stateno,
                        YYERRORSYMBOL)) >= YYNSTATE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yyidx < 0 || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          YYMINORTYPE u2;
          u2.YYERRSYMDT = 0;
          yy_shift(yypParser,yyact,YYERRORSYMBOL,&u2);
        }
      }
      yypParser->yyerrcnt = 1; // not 3 valid tokens, but 1
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor,yyminorunion);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;

#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yypParser->yyerrcnt = 1; // not 3 valid tokens, but 1
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yyidx>=0 );
  return;
}

int sqlite3ParserFallback(int iToken) {
    return yyFallback[iToken];
}
